**********************************************************************    A  10
C     *                                                              *    A  20
C     *     SOLUTE TRANSPORT AND DISPERSION IN A POROUS MEDIUM       *    A  30
C     *      NUMERICAL SOLUTION --- METHOD OF CHARACTERISTICS        *    A  40
C     *      PROGRAMMED BY J. D. BREDEHOEFT AND L. F. KONIKOW        *    A  50
C     *        S.I.P. ROUTINE ADAPTED BY RICHARD HEALY -- 1979       *    A  53
C     *         S.I.P. - REVISED  SEPTEMBER  1982 & FEB. 1987        *    A  54
C     *               REVISED APRIL 1979, MARCH 1980                 *    A  55
C     *               REVISED DECEMBER 1980                          *    A  56
C     *               REVISED AUGUST 1981, JUNE 1982                 *    A  57
C     *               REVISED OCTOBER 1983                           *    A  58
C     * REV. JUNE-AUG. 1984 BY W. SANFORD TO ALLOW 16 PTS. PER NODE  *    A  59
C     *  REV. MAY-AUG. 1985 BY L. KONIKOW AND M. PERSON TO INCLUDE:  *    A  59R
C     *       DECAY AND EQUILIBRIUM SORPTION-DESORPTION REACTIONS    *    A  60R
C     *                                                              *   SA  61
C     * REV. JULY-DEC.1985 TO ALLOW SECONDARY SUBGRID FOR TRANSPORT  *   SA  62
C     *               REVISED JULY 1986                              *    A  63
C     *               REVISED MARCH 1987 BY D.J. GOODE               *    A  64
C     *               REVISED MAY 1987 BY D.J. GOODE                 *    A  67
C     *               REVISED JANUARY 1988                           *    A  68A
C     *               REVISED NOVEMBER 1988                          *    A  68B
C     *    REV. MARCH 1989 BY D.J. GOODE FOR NONLINEAR EQUILIBRIUM   *    A  68C
C     *     SORPTION AND ION-EXCHANGE FOR MONO AND DIVALENT IONS     *    A  68D
C     *                                                              *    A  69R
C     ****************************************************************    A  70
C     *     Modified to allow multispecies solute-transport with     *    A  71b
C     *                       biodegradation                         *    A  72b
C     *      BIOMOC, A multispecies solute-transport model with      *    A  73b
C     *                       biodegradation                         *    A  74b
C     *      USGS Water Resources Investigations Report 97-4022      *    A  75b
C     *               by H.I. Essaid and B.A. Bekins                 *    A  76b
C     ****************************************************************    A  77b
      INCLUDE 'dims.inc'                                                  A  78b
      DOUBLE PRECISION DMIN1,DEXP,DLOG,DABS                               A  80
      DOUBLE PRECISION TMRX,VPRM,HI,HR,HC,HK,WT,REC,RECH,TIM,AOPT,TITLE   A  90
      DOUBLE PRECISION XDEL,YDEL,S,AREA,SUMT,RHO,PARAM,TEST,TOL,PINT,     A 100
     1                 HMIN,PYR,ANFCTR                                    A 102
      DOUBLE PRECISION TINIT,TIMX                                         A 104
      DOUBLE PRECISION TINT                                               A 111
      DOUBLE PRECISION TMSUM,TDEL                                         A 114
      DOUBLE PRECISION TOTLQ,TOTLQI,TPIN,TPOUT                            A 117
      DOUBLE PRECISION HMAX                                               A 117A
      DOUBLE PRECISION DXINV,DYINV,ARINV,PORINV                           A 118
      double precision bioloss,biogain,up,uptake                          A 118b
      real ncinhib                                                        A 118c
      character*15 fname(5),fcname(15),fpname(4)                          A 118d
      integer fnum,fcnum,fpnum                                            A 118e
      INTEGER PTID                                                        A 119
      COMMON /PRMJ/ NTIM,NPMP,NPNT,NITP,N,NX,NY,NP(NPS),NREC,INT,NNX,     A 120b
     &              NNY,                                                  A 121b
     1              NUMOBS,NMOV,IMOV,NPMAX,ITMAX,NZCRIT,IPRNT,NPTPND,     A 131
     2              NPNTMV,NPNTVL,NPNTD,NPNCHV,NPDELC,ICHK,nsol,npop,     A 142b
     3              npset,nconc(NPS),imob(NPS)                            A 143b
      COMMON /PRMC/ NODEID(NXD,NYD),NPCELL(NXC,NYC,NPS),                  A 144b
     &              NPOLD(NXC,NYC,NPS),                                  SA 147b
     1              LIMBO(1000,NPS),IXOBS(NOB),IYOBS(NOB)                 A 148b
      COMMON /HEDA/ THCK(NXD,NYD),TMWL(NOB,500),TMOBS(500)               SA 171b
      COMMON /HEDB/ TMRX(NXD,NYD,2),VPRM(NXD,NYD),HI(NXD,NYD),           SA 181b
     1              HR(NXD,NYD),HC(NXD,NYD),HK(NXD,NYD),WT(NXD,NYD),     SA 185b
     2REC(NXD,NYD),RECH(NXD,NYD),TIM(500),AOPT(20),TITLE(010),XDEL,YDEL, SA 191b
     3              S,AREA,SUMT,RHO,PARAM,TEST(NPS),TOL,PINT,HMIN,PYR,    A 192b
     4              ANFCTR                                                A 201
      COMMON /HEDC/ MX,MY,MMX,MMY,NMX,NMY,MCHK                           SA 205
      COMMON /HEDD/ TINIT,TIMX                                            A 207
      COMMON /XINV/ DXINV,DYINV,ARINV,PORINV                              A 208
      COMMON /BALM/ TOTLQ,TOTLQI,TPIN,TPOUT,HMAX                          A 209A
      COMMON /CHMA/ PART(NPC,NPTS,NPS),CONC(NXC,NYC,NSL),                 A 210b
     &              TMCN(NOB,500,NSL),                                    A 211b
     &              partxy(2,NPTS,NPS),                                   A 212b
     &              VX(NXD,NYD),tmz(NOB,500,NMC),                         A 213b
     1              VY(NXD,NYD),CONINT(NXC,NYC,NSL),CNRECH(NXC,NYC,NSL),  A 214b
     &              POROS,                                               SA 215b
     2              SUMTCH,BETA,TIMV,STORM(NSL),STORMI(NSL),CMSIN(NSL),   A 216b
     &              CMSOUT(NSL),FLMIN(NSL),                               A 220b
     3              FLMOT(NSL),SUMIO(NSL),CELDIS,DLTRAT,CSTORM(NSL)       A 221b
      COMMON /CHMC/ SUMC(NXC,NYC,NSL),VXBDY(NXD,NYD),VYBDY(NXD,NYD)      SA 222b
      COMMON /CHMP/ PTID(NPTS,NPS)                                        A 223b
      COMMON /CHMR/ RF(NPS),DK(NPS),RHOB,THALF(NPS),DECAY(NPS),           A 224b
     &              ADSORB(NSL),degloss(NSL),deggain(NSL),                A 225b
     &              SORBI(NSL),DMASS1(NSL),CSTM2(NSL),                    A 226b
     1              EKF(NPS),XNF(NPS),XNFM1(NPS),FCTRF(NPS),EKL(NPS),     A 227b
     &              CEC(NPS),                                             A 228b
     &              EKLCEC(NPS),FCTRL(NPS),CINMAX(NPS),                   A 229b
     2              RF2MIN(NPS),RF2MAX(NPS),CZERO(NPS),IREACT(NPS),       A 230b
     &              EK(NPS),                                              A 231b
     &              EKCEC(NPS),FCTRE(NPS),CTOT(NPS),C3,C4(NPS),C5(NPS),   A 232b
     &              C6(NPS)                                               A 233b
      COMMON /CHMR2/ CRETRD(NXC,NYC,NSL),CRDCOF(NXC,NYC,NSL),             A 234b
     &              CELDCY(NXC,NYC,NSL)                                   A 238b
      COMMON /DIFUS/ DISP(NXC,NYC,4)                                      A 239b
      common /inbio/ ibio,nproc,nsproc(NPR),iz(NPR),nzinhib,ncomp(NPR),   A 240b
     &               nnc(NPR),nhal(NPR),kscomp(NPR,NMC),ksnc(NPR,NMC),    A 241b
     &               kshal(NPR,NMC),ksproc(NPR,NSL),numnut,ksnut(NSL)     A 242b
      common /rbio/  z(NXC,NYC,NMC),vmax(NPR),                            A 243b
     &               yield(NPR),                                          A 244b
     &               upcoef(NPR,NSL),hfk(NPR,NSL),faccomp(NPR,NMC),       A 245b
     &               facnc(NPR,NMC),                                      A 246b
     &               fachal(NPR,NMC),death(NMC),yieldnut(NSL),            A 247b
     &               compinhib(NPR),ncinhib(NPR),                         A 248b
     &               zinhibfac(NMC),                                      A 249b
     &               halinhib(NPR),grow(NMC),zinit(NXC,NYC,NMC),          A 250b
     &               hfknut(NSL),relcoef(NSL),zinhib(NMC)                 A 251b
      common /dbio/  bioloss(NXC,NYC,NSL), biogain(NXC,NYC,NSL),          A
     &               up(NPR), uptake(NPR,NSL)                             A
      COMMON /CHMB1/CNCNC(NXC,NYC,NSL),CNOLD(NXC,NYC,NSL),                A 252b
     &               CAVG(NXC,NYC,NSL)                                    A 253b
      data fname/'bioobs1.out','bioobs2.out','bioobs3.out',               A 254b
     &'bioobs4.out','bioobs5.out'/                                        A 255b
      data fcname/'biocon1.out','biocon2.out','biocon3.out',              A 256b
     &'biocon4.out','biocon5.out','biocon6.out','biocon7.out',            A 257b
     &'biocon8.out','biocon9.out','biocon10.out','biocon11.out',          A 258b
     &'biocon12.out','biocon13.out','biocon14.out','biocon15.out'/        A 259b
      data fpname/'biopop1.out','biopop2.out','biopop3.out',              A 260b
     &'biopop4.out'/                                                      A 261b
C     ***************************************************************     A 262b
C      ---LOAD DATA---                                                    A 263b
cdg  open files internally                                                A 264b
      open(5,file='input.dat',status='old')                               A 265b
      open(6,file='biomoc.out',status='unknown')                          A 266b
      open(10,file='bioprof.out',status='unknown')                        A 268b
      IHEAD=8                                                             A 269b
      open(IHEAD,file='biohead.out',status='unknown')                     A 270b
cdg  end                                                                  A 271b
      ntime=0                                                             A 272b
      INT=0                                                               A 273b
      TMSUM=0.D0                                                          A 274b
      CALL PARLOD                                                         A 275b
      write(10,429)                                                       A 276b
 429  format(' Col.', '  Solute Conc. (mg/L) C1 to Cnsol,',               A 277b
     1'  Biomass Conc. (mg/L) X1 to Xnpop')                               A 278b
      do 10 i=1,numobs                                                    A 279b
        fnum=11+i                                                         A 280b
        open(fnum,file=fname(i),status='unknown')                         A 281b
      JX=IXOBS(i)                                                         A 282b
      JY=IYOBS(i)                                                         A 283b
      WRITE (fnum,430) i,IXOBS(i),IYOBS(i)                                A 284b
  10  continue                                                            A 285b
  430 FORMAT (1H0,22HOBS.WELL NO.    X    Y,//4X,I3,7X,I4,1X,I4//         A 286b
     &2X,1HN,2X,'TIME (DAYS)',2X,'Solute Conc. (mg/L) C1 to Cnsol,',      A 287b
     1'  Biomass Conc. (mg/L) X1 to Xnpop')                               A 288b
      do 11 i=1,nsol                                                      A 289b
         fcnum=20+i                                                       A 290b
         open(fcnum,file=fcname(i),status='unknown')                      A 291b
  11  continue                                                            A 292b
      do 12 i=1,npop                                                      A 293b
         fpnum=40+i                                                       A 294b
         open(fpnum,file=fpname(i),status='unknown')                      A 295b
  12  continue                                                            A 296b
c     ***************************************************************     A 297b
      do 50 kp=1,npset                                                    A 299b
      CALL GENPT(kp)                                                      A 300b
  50  continue                                                            A 301b
C     ***************************************************************     A 302b
C     ---START COMPUTATIONS---                                            A 303b
C        ---COMPUTE ONE PUMPING PERIOD---                                 A 310
      DO 150 INT=1,NPMP                                                   A 320
      IF (INT.GT.1) TMSUM=TMSUM+PYR                                       A 325
      IF (INT.GT.1) CALL PARLOD                                           A 330
      REMN=1.0                                                            A 338
C        ---COMPUTE ONE TIME STEP---                                      A 340
      DO 130 N=1,NTIM                                                     A 350
      IPRNT=0                                                             A 360
C        ---LOAD NEW DELTA T---                                           A 370
      TINT=SUMT-TMSUM                                                     A 381
      TDEL=DMIN1(TIM(N),PYR-TINT)                                         A 390
      SUMT=SUMT+TDEL                                                      A 400
      TIM(N)=TDEL                                                         A 410
      IF (NPNT.GT.0) REMN=MOD(N,NPNT)                                     A 421
      IF (SUMT.GE.(PYR+TMSUM)) IPRNT=1                                    A 425
C     ***************************************************************     A 430
      CALL ITERAT                                                         A 440
      IF (REMN.EQ.0.0.OR.N.EQ.NTIM.OR.IPRNT.EQ.1) CALL OUTPT              A 452
      kv=1                                                                A 453b
      rmin=10000.                                                         A 454b
      do 101 kp=1,npset                                                   A 455b
        if(imob(kp).eq.0)then                                             A 456b
          rfkv=rf(kp)*rf2min(kp)                                          A 457b
          if(rfkv.lt.rmin)then                                            A 458b
            rmin=rfkv                                                     A 459b
            kv=kp                                                         A 460b
          end if                                                          A 461b
        end if                                                            A 462b
 101  continue                                                            A 463b
        CALL VELO(kv)                                                     A 460b
  102 CALL MOVE                                                           A 471
C     ***************************************************************     A 480
      IF (SUMT.GE.(PYR+TMSUM)) GO TO 140                                  A 621
  130 CONTINUE                                                            A 630
C     ***************************************************************     A 640
  140 CONTINUE                                                            A 660
  150 CONTINUE                                                            A 690
C     ***************************************************************     A 700
cdg      ENDFILE(6)                                                       A 701b
cdg      IF (NPNCHV.EQ.0) GO TO 155                                       A 702b
cdg      ENDFILE(7)                                                       A 703b
cdg  155 CONTINUE                                                         A 704b
cdg  print final head and concentrations                                  A 705b
      DUMHED=-999.0                                                       A 706b
      DO 192 IY=1,NY                                                      A 707b
      DO 191 IX=1,NX                                                      A 708b
  191 IF(THCK(IX,IY).EQ.0.0) HK(IX,IY)=DUMHED                             A 709b
  192 WRITE(IHEAD,1921) (HK(IX,IY),IX=1,NX)                               A 710b
      DUMCON=-999.0                                                       A 711b
      do 194 ks=1,nsol                                                    A 712b
        iconc=20+ks                                                       A 713b
        write(iconc,*)'ks=',ks                                            A 714b
      DO 194 IY=1,NMY                                                     A 715b
      IIY=IY+MY-1                                                         A 716b
      DO 193 IX=1,NMX                                                     A 717b
  193 IF(THCK(IX+MX-1,IIY).EQ.0.0) CONC(IX,IY,ks)=DUMCON                  A 718b
  194 WRITE(ICONC,1921) (CONC(IX,IY,ks),IX=1,NMX)                         A 719b
 1921 FORMAT(1P8E12.4)                                                    A 720b
      do 196 kb=1,npop                                                    A 721b
        iconc=40+kb                                                       A 722b
        write(iconc,*)'kb=',kb                                            A 723b
      DO 196 IY=1,NMY                                                     A 724b
      IIY=IY+MY-1                                                         A 725b
      DO 195 IX=1,NMX                                                     A 726b
  195 IF(THCK(IX+MX-1,IIY).EQ.0.0) z(IX,IY,kb)=DUMCON                     A 727b
  196 WRITE(ICONC,1921) (z(IX,IY,kb),IX=1,NMX)                            A 728b
      STOP                                                                A 729b
C     ***************************************************************     A 730b
      END                                                                 A 731b
      SUBROUTINE PARLOD                                                   B  10
      INCLUDE 'dims.inc'                                                  B  11b
      DOUBLE PRECISION DMIN1,DEXP,DLOG,DABS                               B  20
      DOUBLE PRECISION TMRX,VPRM,HI,HR,HC,HK,WT,REC,RECH,TIM,AOPT,TITLE   B  30
      DOUBLE PRECISION XDEL,YDEL,S,AREA,SUMT,RHO,PARAM,TEST,TOL,PINT,     B  40
     1                 HMIN,PYR,ANFCTR                                    B  42
      DOUBLE PRECISION FCTR,TIMX,TINIT,PIES,YNS,XNS,RAT,HMX,HMY           B  50
      DOUBLE PRECISION ANTIM                                              B  54
      DOUBLE PRECISION DXINV,DYINV,ARINV,PORINV                           B  57
      DOUBLE PRECISION TOTLQ,TOTLQI,TPIN,TPOUT                            B  62
      double precision bioloss,biogain,up,uptake                          B  62b
      real ncinhib                                                        B  63b
      DOUBLE PRECISION HMAX                                               B  64B
      INTEGER OVERRD                                                      B  65
      CHARACTER*26 REACTN(9)                                              B  67R
      COMMON /PRMJ/ NTIM,NPMP,NPNT,NITP,N,NX,NY,NP(NPS),NREC,INT,NNX,     B  68b
     &              NNY,                                                  B  71b
     1              NUMOBS,NMOV,IMOV,NPMAX,ITMAX,NZCRIT,IPRNT,NPTPND,     B  81
     2              NPNTMV,NPNTVL,NPNTD,NPNCHV,NPDELC,ICHK,nsol,npop,     B  92b
     3              npset,nconc(NPS),imob(NPS)                            B  93b
      COMMON /PRMC/ NODEID(NXD,NYD),NPCELL(NXC,NYC,NPS),                  B  94b
     &              NPOLD(NXC,NYC,NPS),                                   B  95b
     1              LIMBO(1000,NPS),IXOBS(NOB),IYOBS(NOB)                 B  96b
      COMMON /HEDA/ THCK(NXD,NYD),TMWL(NOB,500),TMOBS(500)                B  97b
      COMMON /HEDB/ TMRX(NXD,NYD,2),VPRM(NXD,NYD),HI(NXD,NYD),            B  98b
     1              HR(NXD,NYD),HC(NXD,NYD),HK(NXD,NYD),WT(NXD,NYD),      B  99b
     2REC(NXD,NYD),RECH(NXD,NYD),TIM(500),AOPT(20),TITLE(010),XDEL,YDEL,  B 100b
     3              S,AREA,SUMT,RHO,PARAM,TEST(NPS),TOL,PINT,HMIN,PYR,    B 102b
     4              ANFCTR                                                B 104b
      COMMON /HEDC/ MX,MY,MMX,MMY,NMX,NMY,MCHK                            B 106b
      COMMON /HEDD/ TINIT,TIMX                                            B 108b
      COMMON /XINV/ DXINV,DYINV,ARINV,PORINV                              B 110b
      COMMON /BALM/ TOTLQ,TOTLQI,TPIN,TPOUT,HMAX                          B 112b
      COMMON /CHMA/ PART(NPC,NPTS,NPS),CONC(NXC,NYC,NSL),                 B 114b
     &              TMCN(NOB,500,NSL),                                    B 116b
     &              partxy(2,NPTS,NPS),                                   B 118b
     &              VX(NXD,NYD),tmz(NOB,500,NMC),                         B 120b
     1              VY(NXD,NYD),CONINT(NXC,NYC,NSL),CNRECH(NXC,NYC,NSL),  B 122b
     &              POROS,                                                B 124b
     2              SUMTCH,BETA,TIMV,STORM(NSL),STORMI(NSL),CMSIN(NSL),   B 126b
     &              CMSOUT(NSL),FLMIN(NSL),                               B 128b
     3              FLMOT(NSL),SUMIO(NSL),CELDIS,DLTRAT,CSTORM(NSL)       B 130b
      COMMON /CHMC/ SUMC(NXC,NYC,NSL),VXBDY(NXD,NYD),VYBDY(NXD,NYD)       B 132b
      COMMON /CHMR/ RF(NPS),DK(NPS),RHOB,THALF(NPS),DECAY(NPS),           B 134b
     &              ADSORB(NSL),degloss(NSL),deggain(NSL),                B 136b
     &              SORBI(NSL),DMASS1(NSL),CSTM2(NSL),                    B 138b
     1              EKF(NPS),XNF(NPS),XNFM1(NPS),FCTRF(NPS),EKL(NPS),     B 140b
     &              CEC(NPS),                                             B 142b
     &              EKLCEC(NPS),FCTRL(NPS),CINMAX(NPS),                   B 144b
     2              RF2MIN(NPS),RF2MAX(NPS),CZERO(NPS),IREACT(NPS),       B 146b
     &              EK(NPS),                                              B 148b
     &              EKCEC(NPS),FCTRE(NPS),CTOT(NPS),C3,C4(NPS),C5(NPS),   B 150b
     &              C6(NPS)                                               B 152b
      common /inbio/ ibio,nproc,nsproc(NPR),iz(NPR),nzinhib,ncomp(NPR),   B 154b
     &               nnc(NPR),nhal(NPR),kscomp(NPR,NMC),ksnc(NPR,NMC),    B 156b
     &               kshal(NPR,NMC),ksproc(NPR,NSL),numnut,ksnut(NSL)     B 158b
      common /rbio/  z(NXC,NYC,NMC),vmax(NPR),                            B 160b
     &               yield(NPR),                                          B 162b
     &               upcoef(NPR,NSL),hfk(NPR,NSL),faccomp(NPR,NMC),       B 164b
     &               facnc(NPR,NMC),                                      B 166b
     &               fachal(NPR,NMC),death(NMC),yieldnut(NSL),            B 168b
     &               compinhib(NPR),ncinhib(NPR),                         B 170b
     &               zinhibfac(NMC),                                      B 172b
     &               halinhib(NPR),grow(NMC),zinit(NXC,NYC,NMC),          B 174b
     &               hfknut(NSL),relcoef(NSL),zinhib(NMC)                 B 176b
      common /dbio/  bioloss(NXC,NYC,NSL), biogain(NXC,NYC,NSL),          B
     &               up(NPR), uptake(NPR,NSL)                             B
      dimension  CNREC(NSL),fctr2(NSL)                                    B 178b
      DATA REACTN/                  'NONE                      ',         B 213R
     1 'LINEAR SORPTION           ','FREUNDLICH SORPTION       ',         B 214R
     2 'LANGMUIR SORPTION         ','MONOVALENT ION EXCHANGE   ',         B 215R
     3 'DIVALENT ION EXCHANGE     ','MONO-DIVALENT ION EXCHANGE',         B 216R
     4 'DI-MONOVALENT ION EXCHANGE','DECAY ONLY                '/         B 217R
C     ***************************************************************     B 220
      IF (INT.GT.1) GO TO 10                                              B 230
      WRITE (6,750)                                                       B 240
      READ (5,720) TITLE                                                  B 250
      WRITE (6,730) TITLE                                                 B 260
C     ***************************************************************     B 270
C     ---INITIALIZE TEST AND CONTROL VARIABLES---                         B 280
      RHOB=0.0                                                            B 296R
c      TEST=0.D0                                                          B 300b
      TOTLQ=0.D0                                                          B 310
      TOTLQI=0.D0                                                         B 315
      TPIN=0.D0                                                           B 317
      TPOUT=0.D0                                                          B 318
      SUMT=0.D0                                                           B 320
      SUMTCH=0.0                                                          B 330
      INT=0                                                               B 340
      IPRNT=0                                                             B 350
      MX=1                                                               SB 353
      MY=1                                                               SB 354
      MCHK=0                                                             SB 355
      NCA2=0                                                             SB 356
      NCA=0                                                               B 360
      N=0                                                                 B 370
      IMOV=0                                                              B 380
      NMOV=0                                                              B 390
      ICHK=0                                                              B 395
C     ***************************************************************     B 400
C     ---LOAD CONTROL PARAMETERS---                                       B 401b
      READ (5,*) NTIM,NPMP,NX,NY,NPMAX,NPNT,NITP,NUMOBS,ITMAX,NREC,NPT    B 402b
     1PND,NCODES,NPNTMV,NPNTVL,NPNTD,NPDELC,NPNCHV,ibio,nsol,npop,        B 403b
     &npset                                                               B 404b
      do 7, kp=1,npset                                                    B 405b
        read(5,740)ireact(kp),nconc(kp),imob(kp)                          B 406b
   7  continue                                                            B 407b
      do 1 ks=1,nsol                                                      B 408b
      STORMI(ks)=0.0                                                      B 409b
      SORBI(ks)=0                                                         B 410b
      DMASS1(ks)=0.0                                                      B 411b
      degloss(ks)=0.0                                                     B 412b
      deggain(ks)=0.0                                                     B 413b
 1    continue                                                            B 414b
      do 4 kp=1,npset                                                     B 415b
      TEST(kp)=0.D0                                                       B 416b
      DK(kp)=0.0                                                          B 417b
      CINMAX(kp)=0.0                                                      B 418b
      EKF(kp)=0.0                                                         B 419b
      EKL(kp)=0.0                                                         B 420b
      EK(kp)=0.0                                                          B 421b
      XNF(kp)=1.0                                                         B 422b
      CEC(kp)=0.0                                                         B 423b
      CTOT(kp)=0.0                                                        B 424b
      RF2MIN(kp)=1.0                                                      B 425b
      RF2MAX(kp)=1.0                                                      B 426b
      RF(kp)=1.0                                                          B 427b
      DECAY(kp)=0.0                                                       B 428b
      THALF(kp)=0.0                                                       B 429b
 4    continue                                                            B 430b
      NMX=NX                                                             SB 432
      NMY=NY                                                             SB 433
      MMX=NX-1                                                           SB 434
      MMY=NY-1                                                           SB 435
C        ---READ UPPER LEFT AND LOWER RIGHT NODAL COORDS. OF             SB 436
C           TRANSPORT SUBGRID, IN FREE FORMAT, IF NX.LT.0---             SB 437
      IF (NX.GT.0) GO TO 5                                               SB 438A
      NX=-NX                                                             SB 438B
      MCHK=1                                                             SB 438C
      READ (5,*) MX,MY,MMX,MMY                                           SB 438D
      NMX=MMX-MX+1                                                       SB 439A
      NMY=MMY-MY+1                                                       SB 439B
    5 CONTINUE                                                           SB 439H
      READ (5,800) PINT,TOL,POROS,BETA,S,TIMX,TINIT,XDEL,YDEL,DLTRAT,CEL  B 440
     1DIS,ANFCTR                                                          B 450
      HMAX=1.D0                                                           B 453
C        ---READ REACTION TERMS IN FREE FORMAT---                         B 454R
      do 2 kp=1,npset                                                     B 455b
      IF (IREACT(kp).EQ.1) READ (5,*) DK(kp),RHOB,THALF(kp)               B 456b
      IF (IREACT(kp).LT.-1.OR.IREACT(kp).GT.7) IREACT(kp)=0               B 457b
      IF (IREACT(kp).EQ.-1) READ (5,*) THALF(kp)                          B 458b
      IF (IREACT(kp).EQ.2) READ (5,*) RHOB,EKF(kp),XNF(kp),THALF(kp)      B 459b
      IF (IREACT(kp).EQ.3) READ (5,*) RHOB,EKL(kp),CEC(kp),THALF(kp)      B 461b
      IF (IREACT(kp).GE.4) READ (5,*) RHOB,EK(kp),CEC(kp),CTOT(kp),       B 460b
     &   THALF(kp)                                                        B 462b
      XNFM1(kp)=XNF(kp)-1.                                                B 463b
      FCTRF(kp)=RHOB*EKF(kp)*XNF(kp)/POROS                                B 464b
      EKLCEC(kp)=EKL(kp)*CEC(kp)                                          B 465b
      FCTRL(kp)=RHOB*EKLCEC(kp)/POROS                                     B 466b
      EKCEC(kp)=EK(kp)*CEC(kp)                                            B 467b
      IF (CTOT(kp).GT.0.0) FCTRE(kp)=RHOB*EKCEC(kp)/(POROS*CTOT(kp))      B 468b
      C3=RHOB/POROS                                                       B 469b
      C4(kp)=EKCEC(kp)                                                    B 470b
      C5(kp)=C4(kp)*CEC(kp)                                               B 471b
      C6(kp)=CTOT(kp)*CTOT(kp)                                            B 472b
C      CZERO IS THE MINIMUM CONC. LEVEL FOR NONLINEAR RETARDATION         B 473b
      CZERO(kp)=0.9E-15                                                   B 474b
      CALL RETRD2(1.E-15,RF2MAX(kp),RDCOEF,kp)                            B 475b
      CZERO(kp)=1.E-15                                                    B 476b
      NNX=NX-1                                                            B 477b
      NNY=NY-1                                                            B 480
      NP(kp)=NPMAX                                                        B 490b
      DXINV=1.D0/XDEL                                                     B 500
      DYINV=1.D0/YDEL                                                     B 510
      ARINV=DXINV*DYINV                                                   B 520
      PORINV=1.D0/POROS                                                   B 530
      RF(kp)=1.0+(DK(kp)*RHOB/POROS)                                      B 532b
      IF (THALF(kp).GT.0.0) DECAY(kp)=ALOG(2.0)/THALF(kp)                 B 534b
 2    continue                                                            B 535b
C     ---PRINT CONTROL PARAMETERS---                                      B 540
      WRITE (6,755)                                                      SB 545
      WRITE (6,760)                                                       B 550
      WRITE (6,770) NX,NY,XDEL,YDEL                                       B 560
      IF (MCHK.GT.0) WRITE (6,775) NMX,NMY,MX,MY,MMX,MMY                 SB 565
      WRITE (6,780) NTIM,NPMP,PINT,TIMX,TINIT                             B 570
      WRITE (6,790) S,POROS,BETA,DLTRAT,ANFCTR,nsol,npop,ibio             B 580b
     &,npset                                                              B 581b
      do 6, kp=1,npset                                                    B 582b
        write(6,791)kp,nconc(kp)                                          B 583b
        if(imob(kp).gt.0)write(6,792)kp                                   B 584b
  6   continue                                                            B 585b
      WRITE (6,870) NITP,TOL,ITMAX,CELDIS,NPMAX,NPTPND                    B 590
      IF (NPTPND.NE.4.AND.NPTPND.NE.5.AND.NPTPND.NE.8.AND.NPTPND.NE.9.    B 601
     1.AND.NPTPND.NE.16.AND.NPTPND.NE.1) WRITE(6,880)                     B 612
      IF (NPTPND.EQ.1) WRITE (6,882)                                      B 614
      IF((NX.EQ.3.OR.NY.EQ.3).AND.NPTPND.NE.1) WRITE(6,883)               B 614A
      IF (NITP.NE.10) WRITE (6,886)                                       B 616
      WRITE (6,888)                                                      SB 617
      WRITE (6,890) NPNT,NPNTMV,NPNTVL,NPNTD,NUMOBS,NREC,NCODES,NPNCHV,N  B 620
     1PDELC                                                               B 621b
      do 3 kp=1,npset                                                     B 622b
      write(6,901)kp                                                      B 623b
      IF (IREACT(kp).EQ.-1) THEN                                          B 624b
       WRITE (6,891) REACTN(9)                                            B 625b
       IREACT(kp)=0                                                       B 626b
      ELSE                                                                B 632D
       WRITE (6,891) REACTN(IREACT(kp)+1)                                 B 632b
      END IF                                                              B 632F
      IF (IREACT(kp).GE.1) THEN                                           B 633b
       WRITE (6,892) RHOB                                                 B 634R
       IF (IREACT(kp).EQ.1) THEN                                          B 636b
        WRITE (6,893) DK(kp),RF(kp)                                       B 637b
       ELSE                                                               B 638R
        IF (IREACT(kp).EQ.2) WRITE (6,894) EKF(kp),XNF(kp)                B 639b
        IF (IREACT(kp).EQ.3) WRITE (6,895) EKL(kp),CEC(kp)                B 641b
        IF (IREACT(kp).GE.4) WRITE (6,896) EK(kp),CEC(kp),CTOT(kp)        B 642b
        IF (BETA.EQ.0.0) WRITE (6,897)                                    B 643R
       END IF                                                             B 644R
      END IF                                                              B 645R
      IF (DECAY(kp).NE.0.0) WRITE (6,898) THALF(kp),DECAY(kp)             B 646b
 3    continue                                                            B 647b
      GO TO 20                                                            B 650
C     ***************************************************************     B 660
C     ---READ DATA TO REVISE TIME STEPS AND STRESSES FOR SUBSEQUENT       B 670
C        PUMPING PERIODS---                                               B 680
   10 READ (5,1060) ICHK                                                  B 690
      IF (ICHK.LE.0) WRITE (6,1110) INT                                   B 695
      IF (ICHK.LE.0) GO TO 20                                             B 701
C     ---REINITIALIZE REC AND CNRECH IN REC CELLS---                      B 702
C        AND RESET MINIMUM RETARDATION                                    B 703A
      kp=1                                                                B 703b
      sumnc=nconc(1)                                                      B 704b
      do 11 ks=1,nsol                                                     B 705b
        if(ks.gt.sumnc)then                                               B 706b
          kp=kp+1                                                         B 707b
          sumnc=sumnc+nconc(kp)                                           B 708b
        end if                                                            B 709b
      IF (NREC.GT.0.OR.(IREACT(kp).GE.2.AND.IREACT(kp).LE.7)) THEN        B 710b
       CINMAX(kp)=0.0                                                     B 711b
       DO 12 IY=2,NNY                                                     B 704A
       DO 12 IX=2,NNX                                                     B 704B
       JX=IX-MX+1                                                        SB 704C
       JY=IY-MY+1                                                        SB 704D
       IF (REC(IX,IY).NE.0.0) THEN                                        B 704E
        REC(IX,IY)=0.D0                                                   B 705B
        IF (JX.GT.0.AND.JX.LE.NMX.AND.JY.GT.0.AND.JY.LE.NMY)             SB 707A
     1      CNRECH(JX,JY,ks)=0.0                                         SB 707b
       END IF                                                             B 707C
       IF (JX.GT.0.AND.JX.LE.NMX.AND.JY.GT.0.AND.JY.LE.NMY) THEN         SB 707D
        IF (CONC(JX,JY,ks).GT.CINMAX(kp)) CINMAX(kp)=CONC(JX,JY,ks)      SB 708b
        IF ((VPRM(IX,IY).NE.0.0.OR.RECH(JX,JY).LT.0.0)                   SB 707F
     1         .AND.CNRECH(JX,JY,ks).GT.CINMAX(kp))  CINMAX(kp)=          B 708b
     &         CNRECH(JX,JY,ks)                                          SB 708b
       END IF                                                             B 707H
   12  CONTINUE                                                           B 708
       CALL RETRD2(CINMAX(kp),RF2MIN(kp),RDCOEF,kp)                       B 712b
       IF (IREACT(kp).EQ.2.AND.XNFM1(kp).GT.0.0) RF2MIN(kp)=RF2MAX(kp)    B 713b
      END IF                                                              B 709
 11   continue                                                            B 714b
      READ (5,1070) NTIM,NPNT,NITP,ITMAX,NREC,NPNTMV,NPNTVL,NPNTD,NPDELC  B 710
     1,NPNCHV,PINT,TIMX,TINIT                                             B 720
      WRITE (6,1080) INT                                                  B 730
      WRITE (6,1090) NTIM,NPNT,NITP,ITMAX,NREC,NPNTMV,NPNTVL,NPNTD,NPDEL  B 740
     1C,NPNCHV,PINT,TIMX,TINIT                                            B 750
C     ***************************************************************     B 760
C     ---LIST TIME INCREMENTS---                                          B 770
   20 DO 30 J=1,100                                                       B 780
      TIM(J)=0.D0                                                         B 790
   30 CONTINUE                                                            B 800
      PYR=PINT*86400.D0*365.25D0                                          B 805
      TIM(1)=TINIT                                                        B 810
      IF (NPNTMV.EQ.0) NPNTMV=999                                         B 815
      IF (S.GT.0.0) THEN                                                  B 821
      DO 40 K=2,NTIM                                                      B 830
   40 TIM(K)=TIMX*TIM(K-1)                                                B 840
      WRITE (6,470)                                                       B 850
      WRITE (6,490) (TIM(K),K=1,NTIM)                                     B 861
      IF (TINIT.GT.PYR) WRITE (6,475)                                     B 865
      ELSE                                                                B 871
   50 ANTIM=NTIM                                                          B 882
      DO 55 K=1,NTIM                                                      B 884
   55 TIM(K)=PYR/ANTIM                                                    B 886
       WRITE (6,480)                                                      B 891
       WRITE (6,490) (TIM(K),K=1,NTIM)                                    B 892
      END IF                                                              B 893
C     ***************************************************************     B 900
C     ---INITIALIZE MATRICES---                                           B 910
   60 IF (INT.GT.1) GO TO 100                                             B 920
      DO 70 IY=1,NY                                                       B 930
      DO 70 IX=1,NX                                                       B 940
      VPRM(IX,IY)=0.D0                                                    B 950
      THCK(IX,IY)=0.0                                                     B 970
      RECH(IX,IY)=0.D0                                                    B 980
      REC(IX,IY)=0.D0                                                     B1000
      NODEID(IX,IY)=0                                                     B1010
      TMRX(IX,IY,1)=0.D0                                                  B1020
      TMRX(IX,IY,2)=0.D0                                                  B1030
      HI(IX,IY)=0.D0                                                      B1040
      HR(IX,IY)=0.D0                                                      B1050
      HK(IX,IY)=0.D0                                                      B1070
      WT(IX,IY)=0.D0                                                      B1080
      VX(IX,IY)=0.0                                                       B1090
      VY(IX,IY)=0.0                                                       B1100
      VXBDY(IX,IY)=0.0                                                    B1110
      VYBDY(IX,IY)=0.0                                                    B1120
   70 CONTINUE                                                            B1160
      do 75 ks=1,nsol                                                     B1161b
      cnrec(ks)=0.0                                                       B1162b
      DO 75 IY=1,NMY                                                     SB1161
      DO 75 IX=1,NMX                                                     SB1162
      CNRECH(IX,IY,ks)=0.0                                               SB1163b
      CONC(IX,IY,ks)=0.0                                                 SB1164b
      CONINT(IX,IY,ks)=0.0                                               SB1165b
      SUMC(IX,IY,ks)=0.0                                                 SB1166b
      bioloss(ix,iy,ks)=0.0                                               B1163b
      biogain(ix,iy,ks)=0.0                                               B1164b
   75 CONTINUE                                                           SB1168
      do 76 kp=1,npset                                                    B1165b
      do 76 iy=1,nmy                                                      B1166b
      do 76 ix=1,nmx                                                      B1167b
        NPCELL(IX,IY,kp)=0                                               SB1167b
c        if(imob(kp).gt.0)npcell(ix,iy,kp)=nptpnd                         B1168b
   76 continue                                                            B1169b
      do 77 kp=1,npop                                                     B1170b
      do 77 iy=1,nmy                                                      B1171b
      do 77 ix=1,nmx                                                      B1172b
      z(ix,iy,kp)=0.0                                                     B1173b
   77 continue                                                            B1174b
C     ****************************************************************    B1175b
C     ---READ OBSERVATION WELL LOCATIONS---                               B1180
      IF (NUMOBS.LE.0) GO TO 100                                          B1190
      WRITE (6,755)                                                       B1195
      WRITE (6,900)                                                       B1200
      DO 80 J=1,NUMOBS                                                    B1210
      READ (5,700) IX,IY                                                  B1220
      WRITE (6,810) J,IX,IY                                               B1230
      IXOBS(J)=IX                                                         B1240
   80 IYOBS(J)=IY                                                         B1250
      DO 90 I=1,NUMOBS                                                    B1260
      DO 90 J=1,50                                                        B1270
      TMWL(I,J)=0.0                                                       B1280
        do 91, kb=1,npop                                                  B1281b
          tmz(i,j,kb)=0.0                                                 B1282b
   91   continue                                                          B1283b
      do 90 ks=1,nsol                                                     B1284b
   90 TMCN(I,J,ks)=0.0                                                    B1290b
C     ****************************************************************    B1300
C     ---READ PUMPAGE DATA -- (X-Y COORDINATES AND RATE IN CFS)---        B1310
C        ---SIGNS : WITHDRAWAL = POS.;  INJECTION = NEG.---               B1320
C        ---IF INJ. WELL, ALSO READ CONCENTRATION OF INJECTED WATER---    B1330
  100 IF (NREC.LE.0) GO TO 120                                            B1340
      IF (INT.GT.1.AND.ICHK.LE.0) THEN                                    B1346A
       do 101 kp=1,npset                                                  B1341b
       IF (IREACT(kp).GE.2.AND.IREACT(kp).LE.7) WRITE (6,899) kp,         B1342b
     &    RF2MIN(kp)                                                      B1346b
 101  continue                                                            B1347b
       RETURN                                                             B1346C
      END IF                                                              B1346D
      WRITE (6,755)                                                       B1347
      WRITE (6,910)                                                       B1350
      DO 110 I=1,NREC                                                     B1360
      READ (5,710) IX,IY,FCTR,(CNREC(ks),ks=1,nsol)                       B1370b
      JX=IX-MX+1                                                         SB1372
      JY=IY-MY+1                                                         SB1373
      IF (JX.LT.1.OR.JY.LT.1.OR.JX.GT.NMX.OR.JY.GT.NMY) GO TO 105        SB1374
      kp=1                                                                B1375b
      sumnc=nconc(1)                                                      B1376b
      do 102 ks=1,nsol                                                    B1377b
        if(ks.gt.sumnc)then                                               B1378b
          kp=kp+1                                                         B1379b
          sumnc=sumnc+nconc(kp)                                           B1380b
        end if                                                            B1381b
      IF (FCTR.LT.0.0) CNRECH(JX,JY,ks)=CNREC(ks)                        SB1382b
      IF (FCTR.LT.0.0.AND.CNREC(ks).GT.CINMAX(kp)) CINMAX(kp)=CNREC(ks)   B1384b
 102  continue                                                            B1385b
  105 REC(IX,IY)=FCTR                                                    SB1392
  110 WRITE (6,820) IX,IY,REC(IX,IY),(CNREC(ks),ks=1,nsol)               SB1402b
      do 111 kp=1,npset                                                  SB1403b
      CALL RETRD2(CINMAX(kp),RF2MIN(kp),RDCOEF,kp)                        B1404b
      IF (IREACT(kp).EQ.2.AND.XNFM1(kp).GT.0.0) RF2MIN(kp)=RF2MAX(kp)     B1405b
 111  continue                                                            B1406b
C     ****************************************************************    B1410
  120 IF (INT.GT.1) THEN                                                  B1421R
      do 112 kp=1,npset                                                   B1421b
       IF (IREACT(kp).GE.2.AND.IREACT(kp).LE.7) WRITE(6,899) kp,          B1422b
     &    RF2MIN(kp)                                                      B1423b
 112  continue                                                            B1424b
       RETURN                                                             B1423R
      END IF                                                              B1424R
      AREA=XDEL*YDEL                                                      B1430
      WRITE (6,755)                                                       B1435
      WRITE (6,690) AREA                                                  B1440
      WRITE (6,600)                                                       B1450
      WRITE (6,610) XDEL                                                  B1460
      WRITE (6,610) YDEL                                                  B1470
C     ****************************************************************    B1480
C     ---READ TRANSMISSIVITY IN L**2/SEC INTO VPRM ARRAY---               B1490
C        ---FCTR = TRANSMISSIVITY MULTIPLIER  --->  L**2/SEC---           B1500
      WRITE (6,530)                                                       B1510
      WRITE (6,755)                                                       B1515
      READ (5,550) INPUT,FCTR                                             B1520
      DO 160 IY=1,NY                                                      B1530
      IF (INPUT.EQ.1) READ (5,565) (VPRM(IX,IY),IX=1,NX)                  B1540
      DO 150 IX=1,NX                                                      B1550
      IF (INPUT.NE.1) GO TO 130                                           B1560
      VPRM(IX,IY)=VPRM(IX,IY)*FCTR                                        B1570
      GO TO 140                                                           B1580
  130 VPRM(IX,IY)=FCTR                                                    B1590
  140 IF (IX.EQ.1.OR.IX.EQ.NX) VPRM(IX,IY)=0.D0                           B1600
      IF (IY.EQ.1.OR.IY.EQ.NY) VPRM(IX,IY)=0.D0                           B1610
  150 CONTINUE                                                            B1620
  160 WRITE (6,840) (VPRM(IX,IY),IX=1,NX)                                 B1631
C     ****************************************************************    B1640
C     ---SET UP COEFFICIENT MATRIX --- BLOCK-CENTERED GRID---             B1650
C     ---AVERAGE TRANSMISSIVITY --- HARMONIC MEAN---                      B1660
      IF (ANFCTR.NE.0.0) GO TO 170                                        B1670
      WRITE (6,1050)                                                      B1680
      ANFCTR=1.D0                                                         B1690
  170 PIES=3.1415927D0*3.1415927D0/2.D0                                   B1700
      YNS=NY*NY                                                           B1710
      XNS=NX*NX                                                           B1720
      HMIN=2.D0                                                           B1730
      DO 180 IY=2,NNY                                                     B1740
      DO 180 IX=2,NNX                                                     B1750
      IF (VPRM(IX,IY).EQ.0.0) GO TO 180                                   B1760
      TMRX(IX,IY,1)=2.D0*VPRM(IX,IY)*VPRM(IX+1,IY)/                       B1771
     1                 ((VPRM(IX,IY)+VPRM(IX+1,IY))*XDEL)                 B1781
      TMRX(IX,IY,2)=2.D0*VPRM(IX,IY)*VPRM(IX,IY+1)/                       B1791
     1                 ((VPRM(IX,IY)+VPRM(IX,IY+1))*YDEL)                 B1801
C        ---ADJUST COEFFICIENT FOR ANISOTROPY---                          B1810
      TMRX(IX,IY,2)=TMRX(IX,IY,2)*ANFCTR                                  B1820
C        ---COMPUTE MINIMUM ITERATION PARAMETER (HMIN)---                 B1830
      IF (TMRX(IX,IY,1).EQ.0.0) GO TO 180                                 B1840
      IF (TMRX(IX,IY,2).EQ.0.0) GO TO 180                                 B1850
      RAT=TMRX(IX,IY,1)*YDEL/(TMRX(IX,IY,2)*XDEL)                         B1860
      HMX=PIES/(XNS*(1.D0+RAT))                                           B1870
      HMY=PIES/(YNS*(1.D0+(1.D0/RAT)))                                    B1880
      IF (HMX.LT.HMIN) HMIN=HMX                                           B1890
      IF (HMY.LT.HMIN) HMIN=HMY                                           B1900
  180 CONTINUE                                                            B1910
      IF (NX.GT.3.AND.NY.GT.3) GO TO 185                                  B1912
      HMX=PIES/XNS                                                        B1913
      HMY=PIES/YNS                                                        B1914
      HMIN=DMIN1(HMIN,HMX,HMY)                                            B1915
  185 CONTINUE                                                            B1916
C     ****************************************************************    B1920
C     ---READ AQUIFER THICKNESS---                                        B1930
      WRITE (6,510)                                                       B1940
      WRITE (6,755)                                                       B1945
      READ (5,550) INPUT,FCTR                                             B1950
      DO 210 IY=1,NY                                                      B1960
      IF (INPUT.EQ.1) READ (5,540) (THCK(IX,IY),IX=1,NX)                  B1970
      DO 200 IX=1,NX                                                      B1980
      IF (INPUT.NE.1) GO TO 190                                           B1990
      THCK(IX,IY)=THCK(IX,IY)*FCTR                                        B2000
      GO TO 200                                                           B2010
  190 IF (VPRM(IX,IY).NE.0.0) THCK(IX,IY)=FCTR                            B2020
  200 CONTINUE                                                            B2030
      WRITE (6,500) (THCK(IX,IY),IX=1,NX)                                 B2041
C     ---STORE THICKNESS*POROSITY IN THCK ARRAY---                        B2043
      DO 205 IX=1,NX                                                      B2044
  205 THCK(IX,IY)=THCK(IX,IY)*POROS                                       B2045
  210 CONTINUE                                                            B2046
C     ****************************************************************    B2050
C     ---READ DIFFUSE RECHARGE AND DISCHARGE---                           B2060
      WRITE (6,830)                                                       B2070
      WRITE (6,755)                                                       B2075
      READ (5,550) INPUT,FCTR                                             B2080
      DO 240 IY=1,NY                                                      B2090
      IF (INPUT.EQ.1) READ (5,560) (RECH(IX,IY),IX=1,NX)                  B2100
      DO 230 IX=1,NX                                                      B2110
      IF (INPUT.NE.1) GO TO 220                                           B2120
      RECH(IX,IY)=RECH(IX,IY)*FCTR                                        B2130
      GO TO 230                                                           B2140
  220 IF (THCK(IX,IY).NE.0.0) RECH(IX,IY)=FCTR                            B2150
  230 CONTINUE                                                            B2160
  240 WRITE (6,840) (RECH(IX,IY),IX=1,NX)                                 B2170
C     ****************************************************************    B2180
C     ---COMPUTE HYDRAULIC CONDUCTIVITY FROM TRANSMISSIVITY---            B2191
C     ---COUNT NO. OF CELLS IN AQUIFER---                                 B2200
C     ---SET NZCRIT = 2% OF THE NO. OF CELLS IN THE AQUIFER---            B2210
      DO 250 IX=1,NX                                                      B2220
      DO 250 IY=1,NY                                                      B2230
      IF (THCK(IX,IY).EQ.0.0) GO TO 250                                   B2240
      VPRM(IX,IY)=(VPRM(IX,IY)*POROS)/THCK(IX,IY)                         B2251
      NCA=NCA+1                                                           B2260
      IF (MCHK.EQ.0) GO TO 250                                           SB2262
      IF (IX.LT.MX.OR.IX.GT.MMX) GO TO 250                               SB2263
      IF (IY.LT.MY.OR.IY.GT.MMY) GO TO 250                               SB2264
      NCA2=NCA2+1                                                        SB2265
  250 CONTINUE                                                            B2271
C                                                                         B2280
      AAQ=NCA*AREA                                                        B2290
      NZCRIT=(NCA+25)/50                                                  B2300
      IF (MCHK.GT.0) NZCRIT=(NCA2+25)/50                                 SB2301
      IF (NZCRIT.EQ.0) NZCRIT=1                                          SB2305
      WRITE (6,620)                                                       B2310
      WRITE (6,755)                                                       B2315
      DO 260 IY=1,NY                                                      B2320
      WRITE (6,840) (VPRM(IX,IY),IX=1,NX)                                 B2322
      DO 260 IX=1,NX                                                      B2324
  260 VPRM(IX,IY)=0.D0                                                    B2326
      IF (MCHK.EQ.0) GO TO 265                                           SB2332
      AAQ2=NCA2*AREA                                                     SB2333
      WRITE (6,633)                                                      SB2334
      WRITE (6,635) NCA,AAQ                                              SB2335
      WRITE (6,634)                                                      SB2336
      WRITE (6,630) NCA2,AAQ2,NZCRIT                                     SB2337
      GO TO 267                                                          SB2338
  265 CONTINUE                                                           SB2339
      WRITE (6,630) NCA,AAQ,NZCRIT                                        B2340
  267 CONTINUE                                                           SB2345
C     ****************************************************************    B2350
C     ---READ NODE IDENTIFICATION CARDS---                                B2360
C        ---SET VERT. PERM., SOURCE CONC., AND DIFFUSE RECHARGE---        B2370
C           ---SPECIFY CODES TO FIT YOUR NEEDS---                         B2380
      WRITE (6,570)                                                       B2390
      READ (5,550) INPUT,FCTR                                             B2400
      DO 280 IY=1,NY                                                      B2410
      IF (INPUT.EQ.1) READ (5,640) (NODEID(IX,IY),IX=1,NX)                B2420
      DO 270 IX=1,NX                                                      B2430
  270 IF (INPUT.NE.1.AND.THCK(IX,IY).NE.0.0) NODEID(IX,IY)=FCTR           B2440
      WRITE (6,580) (NODEID(IX,IY),IX=1,NX)                               B2450
  280 continue                                                            B2451b
      WRITE (6,920) NCODES                                                B2460
      IF (NCODES.LE.0) GO TO 310                                          B2470
      WRITE (6,930)                                                       B2480
      DO 300 IJ=1,NCODES                                                  B2490
      READ (5,850) ICODE,FCTR1,FCTR2(1),FCTR3,OVERRD,(fctr2(ks),          B2491b
     &ks=2,nsol)                                                          B2492b
      DO 290 IX=1,NX                                                      B2510
      DO 290 IY=1,NY                                                      B2520
      IF (NODEID(IX,IY).NE.ICODE) GO TO 290                               B2530
      VPRM(IX,IY)=FCTR1                                                   B2540
      JX=IX-MX+1                                                         SB2544
      JY=IY-MY+1                                                         SB2545
      IF (JX.LT.1.OR.JY.LT.1.OR.JX.GT.NMX.OR.JY.GT.NMY) GO TO 285        SB2546
      do 282 ks=1,nsol                                                    B2547b
        CNRECH(JX,JY,ks)=FCTR2(ks)                                       SB2551b
  282 continue                                                            B2548b
      ks=0                                                                B2549b
      do 281 kp=1,npset                                                   B2550b
      do 281 kps=1,nconc(kp)                                              B2551b
        ks=ks+1                                                           B2552b
      IF (FCTR2(ks).GT.CINMAX(kp)) CINMAX(kp)=FCTR2(ks)                   B2553b
 281  continue                                                            B2554b
  285 CONTINUE                                                           SB2555
      IF (OVERRD.NE.0) RECH(IX,IY)=FCTR3                                  B2560
  290 CONTINUE                                                            B2570
      WRITE (6,860) ICODE,FCTR1,(FCTR2(ks),ks=1,nsol)                     B2580b
  300 IF (OVERRD.NE.0) WRITE (6,1100) FCTR3                               B2590
  310 WRITE (6,590)                                                       B2600
      WRITE (6,755)                                                       B2615
      DO 320 IY=1,NY                                                      B2610
  320 WRITE (6,840) (VPRM(IX,IY),IX=1,NX)                                 B2621
C     ***************************************************************     B2630
C     ---READ WATER-TABLE ELEVATION---                                    B2640
      WRITE (6,670)                                                       B2650
      WRITE (6,755)                                                       B2655
      READ (5,550) INPUT,FCTR                                             B2660
      DO 350 IY=1,NY                                                      B2670
c      IF (INPUT.EQ.1) READ (5,660) (WT(IX,IY),IX=1,NX)                   B2680b
      IF (INPUT.EQ.1) READ (5,661) (WT(IX,IY),IX=1,NX)                    B2681b
  661 FORMAT (1X,10F12.0)                                                 B2682b
      DO 340 IX=1,NX                                                      B2690
      IF (INPUT.NE.1) GO TO 330                                           B2700
      WT(IX,IY)=WT(IX,IY)*FCTR                                            B2710
      GO TO 340                                                           B2720
  330 IF (THCK(IX,IY).NE.0.0) WT(IX,IY)=FCTR                              B2730
  340 CONTINUE                                                            B2740
      WRITE (6,680) (WT(IX,IY),IX=1,NX)                                   B2750
  350 continue                                                            B2751b
C     ****************************************************************    B2760
C     ---SET INITIAL HEADS---                                             B2770
      DO 360 IX=1,NX                                                      B2780
      DO 360 IY=1,NY                                                      B2790
      HI(IX,IY)=WT(IX,IY)                                                 B2800
      HR(IX,IY)=HI(IX,IY)                                                 B2820
  360 HK(IX,IY)=HI(IX,IY)                                                 B2830
C                                                                         B2840
      CALL OUTPT                                                          B2850
C     ***************************************************************     B2860
C     ---COMPUTE ITERATION PARAMETERS---                                  B2870
      DO 370 ID=1,20                                                      B2880
      AOPT(ID)=0.D0                                                       B2890
  370 CONTINUE                                                            B2900
C     ****************************************************************    B2990
C     ---READ INITIAL CONCENTRATIONS AND COMPUTE INITIAL MASS STORED---   B3000
C        ---IF USING SMALLER SUBGRID FOR TRANSPORT, READ INITIAL         SB3005
C           CONCENTRATION ARRAY FOR SUBGRID NODES ONLY---                SB3006
      kp=1                                                                B3001b
      sumnc=nconc(1)                                                      B3002b
      do 401 ks=1,nsol                                                    B3003b
        if(ks.gt.sumnc)then                                               B3004b
          kp=kp+1                                                         B3005b
          sumnc=sumnc+nconc(kp)                                           B3006b
        end if                                                            B3007b
      READ (5,550) INPUT,FCTR                                             B3010
      CFCTR2=DK(kp)*RHOB/POROS                                            B3016b
      DO 420 IY=1,NMY                                                    SB3021
      JY=IY+MY-1                                                         SB3025
      IF (INPUT.EQ.1) READ (5,660) (CONC(IX,IY,ks),IX=1,NMX)             SB3031b
      DO 410 IX=1,NMX                                                    SB3041
      JX=IX+MX-1                                                         SB3045
      IF (INPUT.NE.1) GO TO 390                                           B3050
      CONC(IX,IY,ks)=CONC(IX,IY,ks)*FCTR                                  B3060b
      GO TO 400                                                           B3070
  390 IF (THCK(JX,JY).NE.0.0) CONC(IX,IY,ks)=FCTR                        SB3081b
  400 CONINT(IX,IY,ks)=CONC(IX,IY,ks)                                     B3090b
      CFCTR=CONINT(IX,IY,ks)*THCK(JX,JY)*AREA                            SB3093b
      SORBI(ks)=SORBI(ks)+CFCTR*CFCTR2                                    B3094b
      IF (IREACT(kp).GE.2)                                                B3095b
     1    SORBI(ks)=SORBI(ks)+RHOB/POROS*AREA*THCK(JX,JY)*                B3096b
     &    SORB2(CONINT(IX,IY,ks),kp)                                     SB3097b
      IF (CONINT(IX,IY,ks).GT.CINMAX(kp)) CINMAX(kp)=CONINT(IX,IY,ks)     B3098b
  410 STORMI(ks)=STORMI(ks)+CFCTR                                         B3099b
  420 CONTINUE                                                            B3110
      CALL RETRD2(CINMAX(kp),RF2MIN(kp),RDCOEF,kp)                        B3111b
      IF (IREACT(kp).EQ.2.AND.XNFM1(kp).GT.0.0) RF2MIN(kp)=RF2MAX(kp)     B3112b
      IF (IREACT(kp).GE.2.AND.IREACT(kp).LE.7) WRITE (6,899) kp,          B3113b
     &   RF2MIN(kp)                                                       B3114b
 401  continue                                                            B3115b
C     ****************************************************************    B3116b
        if(ibio.gt.0)then                                                 B3117b
C     ---read in biodegradation info                                      B3118b
        read(5,*)nproc                                                    B3119b
c                                                                         B3120b
        do 505 iproc=1,nproc                                              B3121b
        read(5,*) nsproc(iproc),vmax(iproc),iz(iproc),yield(iproc),       B3122b
     &ncomp(iproc),nnc(iproc),nhal(iproc)                                 B3123b
        read(5,*) (ksproc(iproc,is),hfk(iproc,is),is=1,nsproc(iproc))     B3124b
        if(ncomp(iproc).gt.0)read(5,*) (kscomp(iproc,nc),                 B3125b
     &faccomp(iproc,nc),nc=1,ncomp(iproc))                                B3126b
        if(nnc(iproc).gt.0)read(5,*) (ksnc(iproc,nc),facnc(iproc,nc),     B3127b
     &nc=1,nnc(iproc))                                                    B3128b
        if(nhal(iproc).gt.0)read(5,*) (kshal(iproc,nc),                   B3129b
     &fachal(iproc,nc),nc=1,nhal(iproc))                                  B3130b
        read(5,*) (upcoef(iproc,ks),ks=1,nsol)                            B3131b
505       continue                                                        B3132b
c                                                                         B3133b
        read(5,*) numnut                                                  B3134b
        if(numnut.gt.0)read(5,*) (ksnut(inn),yieldnut(inn),               B3135b
     &hfknut(inn),relcoef(inn),inn=1,numnut)                              B3136b
c                                                                         B3137b
        read(5,*) (death(j),j=1,npop)                                     B3138b
        read(5,*) nzinhib,(zinhibfac(ib),ib=1,npop)                       B3139b
        do 393 ib=1,npop                                                  B3140b
        if(nzinhib.gt.0)then                                              B3141b
          zinhibfac(ib)=1./zinhibfac(ib)                                  B3142b
        else                                                              B3143b
          zinhibfac(ib)=0.0                                               B3144b
        end if                                                            B3145b
393     continue                                                          B3146b
c                                                                         B3147b
      do 424 kb=1,npop                                                    B3148b
      READ (5,550) INPUT,FCTR                                             B3149b
      DO 424 IY=1,NMY                                                    SB3021b
      JY=IY+MY-1                                                         SB3025b
      IF (INPUT.EQ.1) READ (5,660) (z(IX,IY,kb),IX=1,NMX)                SB3031b
      DO 424 IX=1,NMX                                                    SB3041b
      JX=IX+MX-1                                                         SB3045b
      IF (INPUT.NE.1) GO TO 394                                           B3050b
      z(IX,IY,kb)=z(IX,IY,kb)*FCTR                                        B3060b
      GO TO 424                                                           B3070b
  394 IF (THCK(JX,JY).NE.0.0) z(IX,IY,kb)=FCTR                           SB3081b
  424 CONTINUE                                                            B3110b
c                                                                         B3111b
      write(6,426)                                                        B3112b
      do 427 kb=1,npop                                                    B3113b
        write(6,428)kb                                                    B3114b
      do 427 iy=1,nmy                                                     B3115b
        write(6,429)(z(ix,iy,kb),ix=1,nmx)                                B3116b
      do 427 ix=1,nmx                                                     B3117b
        zinit(ix,iy,kb)=z(ix,iy,kb)                                       B3118b
 427  continue                                                            B3119b
c                                                                         B3120b
 426  format(/' Initial microbial mass:')                                 B3121b
 428  format(/' Population',i3)                                           B3122b
 429  format(10E10.3)                                                     B3123b
c                                                                         B3124b
        write(6,522)nproc                                                 B3125b    
522     format(/10x,'There are ',i3, '  degradation processes active')    B3126b
c                                                                         B3127b
      do 526 iproc=1,nproc                                                B3128b
                write(6,512)iproc,(ksproc(iproc,is),is=1,                 B3129b
     &                      nsproc(iproc))                                B3130b
 512  format(/10x,'Process ',i3,' depends on solutes ',15i4)              B3131b
                write(6,513)(hfk(iproc,is),is=1,nsproc(iproc))            B3132b
 513  format(10x,'With half saturation constants of ',(10G11.3))          B3133b
                write(6,514)vmax(iproc),iz(iproc),yield(iproc)            B3134b
 514  format(10x,'Maximum uptake rate =',G11.3/10x,                       B3135b
     &      'Microbial population ',i3/10x,                               B3136b
     &      'Yield coefficient ',E11.3)                                   B3137b
        if(ncomp(iproc).gt.0)write(6,515)(kscomp(iproc,nc),               B3138b
     &        faccomp(iproc,nc),nc=1,ncomp(iproc))                        B3139b
 515  format(10x,'Competitive inhibition by:',/(14x'Solute ',i3,          B3140b
     &  '  Inhibition constant= ',G11.3))                                 B3141b
        if(nnc(iproc).gt.0)write(6,516)(ksnc(iproc,nc),                   B3142b
     &        facnc(iproc,nc),nc=1,nnc(iproc))                            B3143b
 516  format(10x,'Noncompetitive inhibition by:',/(14x,'Solute ',i3,      B3144b
     &  '  Inhibition constant= ',G11.3))                                 B3145b
        if(nhal(iproc).gt.0)write(6,517)(kshal(iproc,nc),                 B3146b
     &        fachal(iproc,nc),nc=1,nhal(iproc))                          B3147b
 517  format(10x,'Haldane inhibition by:',/(14x'Solute ',i3,              B3148b
     &  '  Inhibition consant= ',G11.3))                                  B3149b
c                                                                         B3150b
        write(6,518)(ks,upcoef(iproc,ks),ks=1,nsol)                       B3151b
 518  format(10x,'Uptake coefficients:  =1 for primary substrate',        B3152b
     &/20x,'>0 for solutes consumed, <0 for solutes produced',/           B3153b
     &20x,'=0 for solutes not involved in process',/(20x,'Solute ',       B3154b
     &i3,' Uptake coefficient = ',E11.3))                                 B3155b
526      continue                                                         B3156b
c                                                                         B3157b
        write(6,519)(ksnut(inn),yieldnut(inn),hfknut(inn),                B3158b
     &relcoef(inn),inn=1,numnut)                                          B3159b
 519  format(/10x,'Solute ',i3,' is a nutrient with a yield ',            B3160b
     &'coefficient of ',G11.3,','/20x'a Kh of ', G11.3,','/20x,           B3161b
     &'and a release coefficient of ', G11.3)                             B3162b
c                                                                         B3163b
        do 609 j=1,npop                                                   B3164b
        write(6,625)j,death(j),nzinhib,zinhibfac(j)                       B3165b
625      format(/5x,'Microbe population',i3,':'/                          B3166b
     &10x,'death rate constant',E14.3,'  nzinhib=',i3,                    B3167b
     &',  zinhibfac=',f5.2)                                               B3168b
609       continue                                                        B3169b
      end if                                                              B3170b
c                                                                         B3171b
C     ****************************************************************    B3120
C     ---CHECK DATA SETS FOR INTERNAL CONSISTENCY---                      B3130
      DO 440 IX=1,NX                                                      B3140
      DO 440 IY=1,NY                                                      B3150
      IF (THCK(IX,IY).GT.0.0) THEN                                        B3161
       IF (IX.EQ.1.OR.IY.EQ.1.OR.IX.EQ.NX.OR.IY.EQ.NY)                    B3162
     1     WRITE (6,935) IX,IY                                            B3163
       GO TO 430                                                          B3164
      END IF                                                              B3165
      IF (TMRX(IX,IY,1).GT.0.0) WRITE (6,940) IX,IY                       B3170
      IF (TMRX(IX,IY,2).GT.0.0) WRITE (6,950) IX,IY                       B3180
      IF (IX.NE.1) THEN                                                   B3182
       IF (TMRX(IX-1,IY,1).GT.0.0) WRITE (6,940) IX,IY                    B3183
      END IF                                                              B3184
      IF (IY.NE.1) THEN                                                   B3185
       IF (TMRX(IX,IY-1,2).GT.0.0) WRITE (6,950) IX,IY                    B3186
      END IF                                                              B3187
      IF (NODEID(IX,IY).GT.0) WRITE (6,960) IX,IY                         B3190
      IF (WT(IX,IY).NE.0.0) WRITE (6,970) IX,IY                           B3200
      IF (RECH(IX,IY).NE.0.0) WRITE (6,980) IX,IY                         B3210
      IF (REC(IX,IY).NE.0.0) WRITE (6,990) IX,IY                          B3220
  430 IF (TMRX(IX,IY,1).GT.0.0.OR.TMRX(IX,IY,2).GT.0.0) GO TO 440         B3231
      IF (IX.NE.1) THEN                                                   B3232
       IF (TMRX(IX-1,IY,1).GT.0.0) GO TO 440                              B3233
      END IF                                                              B3234
      IF (IY.NE.1) THEN                                                   B3235
       IF (TMRX(IX,IY-1,2).GT.0.0) GO TO 440                              B3236
      END IF                                                              B3237
      IF (NODEID(IX,IY).GT.0.0) WRITE (6,1000) IX,IY                      B3240
      IF (WT(IX,IY).NE.0.0) WRITE (6,1010) IX,IY                          B3250
      IF (RECH(IX,IY).NE.0.0) WRITE (6,1020) IX,IY                        B3260
      IF (REC(IX,IY).NE.0.0) WRITE (6,1030) IX,IY                         B3270
      IF (THCK(IX,IY).GT.0.0) WRITE (6,1040) IX,IY                        B3280
  440 CONTINUE                                                            B3290
C     ****************************************************************    B3300
      RETURN                                                              B3310
C     ****************************************************************    B3320
C                                                                         B3330
C                                                                         B3340
C                                                                         B3350
  450 FORMAT (1H1,20HITERATION PARAMETERS)                                B3360
  460 FORMAT (3H   ,1G20.6)                                               B3370
  470 FORMAT (1H1,27HTIME INTERVALS (IN SECONDS))                         B3380
  475 FORMAT (1H0,5X,65H*** WARNING ***   INITIAL TIME STEP IS LONGER TH  B3384
     1AN PUMPING PERIOD/25X,34H***ADJUST EITHER TINIT OR PINT.***/)       B3385
  480 FORMAT (1H1,15X,17HSTEADY-STATE FLOW//5X,55HTIME INTERVALS (IN SEC  B3391
     1) FOR SOLUTE-TRANSPORT SIMULATION)                                  B3401
  490 FORMAT (3H   ,10G12.5)                                              B3410
  500 FORMAT (3H   ,25F5.1)                                              SB3421
  510 FORMAT (1H1,21HAQUIFER THICKNESS (L))                               B3430
  530 FORMAT (1H1,29HTRANSMISSIVITY MAP (L**2/SEC))                       B3450
  540 FORMAT (20G3.0)                                                     B3460
  550 FORMAT (I1,G10.0)                                                   B3470
  560 FORMAT (20G4.1)                                                     B3480
  565 FORMAT (8e10.3)                                                     B3480b
  570 FORMAT (1H1,23HNODE IDENTIFICATION MAP//)                           B3490
  580 FORMAT (1H ,30I3)                                                  SB3501
  590 FORMAT (1H1,'VERTICAL HYDRAULIC CONDUCTIVITY/THICKNESS (L/',        B3511
     1                                                     '(L*SEC))')    B3512
  600 FORMAT (1H0,10X,12HX-Y SPACING:)                                    B3520
  610 FORMAT (1H ,12X,10G12.5)                                            B3530
  620 FORMAT (1H1,'HYDRAULIC CONDUCTIVITY MAP (L/SEC)')                   B3541
  630 FORMAT (1H0,05X,05X,44HNO. OF FINITE-DIFFERENCE CELLS IN AQUIFER = SB3551
     1 ,I8//10X,28HAREA OF AQUIFER IN MODEL  = ,G12.5,7H   L**2////1      B3560
     20X,47HNZCRIT   (MAX. NO. OF CELLS THAT CAN BE VOID OF/20X,56HPARTI  B3570
     3CLES;  IF EXCEEDED, PARTICLES ARE REGENERATED)   = ,I4/)            B3580
  633 FORMAT (1H0,////2X,26HFLOW MODEL (PRIMARY GRID):/)                 SB3582
  634 FORMAT (1H0,///2X,18HTRANSPORT SUBGRID:/)                          SB3583
  635 FORMAT (1H0,05X,05X,44HNO. OF FINITE-DIFFERENCE CELLS IN AQUIFER = SB3584
     1 ,I4//10X,28HAREA OF AQUIFER IN MODEL  = ,G12.5,7H   L**2/)        SB3585
  640 FORMAT (20I1)                                                       B3590
  660 FORMAT (20G4.0)                                                     B3610
  665 FORMAT (8E12.4)                                                     B3611b
  670 FORMAT (1H1,11HWATER TABLE)                                         B3620
  680 FORMAT (1H ,20F5.0)                                                 B3630
  690 FORMAT (1H0,10X,19HAREA OF ONE CELL = ,G12.4)                       B3640
  700 FORMAT (2I5)                                                        B3650
  710 FORMAT (2I5,(10G10.2))                                              B3660b
  720 FORMAT (10A8)                                                       B3670
  730 FORMAT (1H0,10A8)                                                   B3680
  740 FORMAT (20I5)                                                       B3691b
  750 FORMAT (1H1,77HU.S.G.S. METHOD-OF-CHARACTERISTICS MODEL FOR SOLUTE  B3700
     1 TRANSPORT IN GROUND WATER)                                         B3710
  755 FORMAT (1H )                                                       SB3715
  760 FORMAT (1H0,21X,21HI N P U T     D A T A)                           B3720
  770 FORMAT (1H0,23X,16HGRID DESCRIPTORS//13X,30HNX    (NUMBER OF COLUM  B3730
     1NS)  =  ,I4/13X,28HNY    (NUMBER OF ROWS)     =,I6/13X,31HXDEL  (X  B3740
     2-DISTANCE (L UNITS)) = ,F7.1/13X,31HYDEL  (Y-DISTANCE (L UNITS)) =  B3750
     3 ,F7.1)                                                             B3760
  775 FORMAT (1H0,18X,31HSECONDARY SUBGRID FOR TRANSPORT//16X,30HNMX   ( SB3763
     1NUMBER OF COLUMNS)  =  ,I4/16X,30HNMY   (NUMBER OF ROWS)     =  ,I SB3764
     24//16X,38HCROSS-REF. TO PRIMARY GRID      IX  IY/46X,8H --- ---/18 SB3765
     3X,28HFIRST NODE (UPPER LEFT) AT: ,2I4/18X,28HLAST NODE (LOWER RIGH SB3766
     4T) AT: ,2I4)                                                       SB3767
  780 FORMAT (1H0,23X,16HTIME  PARAMETERS//13X,40HNTIM   (MAX. NO. OF TI  B3770
     1ME STEPS)       = ,I6/13X,40HNPMP   (NO. OF PUMPING PERIODS)        B3780
     2 = ,I6/13X,39HPINT   (PUMPING PERIOD IN YEARS)      =,F11.3/13X,39  B3791
     3HTIMX   (TIME INCREMENT MULTIPLIER)    =,F10.2/13X,39HTINIT  (INIT  B3800
     4IAL TIME STEP IN SEC.)    =,F8.0)                                   B3810
  790 FORMAT (1H0,14X,34HHYDROLOGIC AND CHEMICAL PARAMETERS//13X,1HS,7X,  B3820
     129H(STORAGE COEFFICIENT)       =,5X,F9.6/13X,28HPOROS   (EFFECTIVE  B3830
     2 POROSITY),8X,3H=  ,F9.3/13X,39HBETA    (LONGITUDINAL DISPERSIVITY SB3841
     3) =  ,F7.1/13X,31HDLTRAT  (RATIO OF TRANSVERSE TO/21X,30HLONGITUDI SB3851
     4NAL DISPERSIVITY)  = ,F9.2/13X,39HANFCTR  (RATIO OF T-YY TO T-XX)   B3860
     5    =  ,F12.6//13x,'nsol    (No. of solutes)            =  ',i6/    B3861b
     &13x,'npop    (No. of microbial pop.)     =  ',i6/13x,'ibio',        B3862b
     &'    (0=no degradation, 1=mult.'/23x,'Monod, ',                     B3863b
     &'2=min. Monod)      =  ',                                           B3864b
     &i6//13x,'npset   (No. of particle ',                                B3865b
     &'sets)      =  ',i6/13x,                                            B3866b
     &'No. of concentrations per particle set:'/)                         B3867b
  791 format(18x,'nconc(',i2,')=',i2)                                     B3868b
  792 format(20x,'Particle set ',i3,' is not mobile')                     B3869b
  800 FORMAT (12G5.0)                                                     B3880
  810 FORMAT (1H ,15X,I3,4X,I3,3X,I3)                                     B3890
  820 FORMAT (1H ,7X,2I4,3X,9e10.3/(28x,9e10.3))                          B3891b
  830 FORMAT (1H1,38HDIFFUSE RECHARGE AND DISCHARGE (L/SEC))              B3910
  840 FORMAT (1H ,1P10E10.2)                                              B3920
  850 FORMAT (I2,3G10.2,I2,9g10.2,(9g10.2))                               B3930b
  860 FORMAT (1H0,7X,I2,7X,9E10.3/(26x,9e10.3))                           B3940b
  870 FORMAT (1H0,21X,20HEXECUTION PARAMETERS//13X,39HNITP   (NO. OF ITE  B3950
     1RATION PARAMETERS) = ,I4/13X,39HTOL    (CONVERGENCE CRITERIA - SIP  B3961
     2P) = ,E9.2/13X,39HITMAX  (MAX.NO.OF ITERATIONS - SIP)  = ,I7/13X,3  B3972b
     34HCELDIS (MAX.CELL DISTANCE PER MOVE/24X,28HOF PARTICLES - M.O.C.)  B3980
     4    = ,F8.3/13X,30HNPMAX  (MAX. NO. OF PARTICLES),7X,2H= ,I6/12X,3  B3990
     52H NPTPND (NO. PARTICLES PER NODE),6X,3H=  ,I4)                     B4000
  880 FORMAT (1H0,5X,47H*** WARNING *** NPTPND MUST =  1,4,5,8,9, OR 16)  B4011A
  882 FORMAT (1H0,5X,58H*** CAUTION *** USE OF NPTPND=1 MAY CAUSE LOSS O  B4012A
     1F ACCURACY)                                                         B4012B
  883 FORMAT (1H0,5X,56H*** ONE-DIMENSIONAL *** WILL USE ONLY 1 ROW OF P  B4013A
     1ARTICLES/13X,35HUSE 2 PARTICLES FOR NPTPND = 4 OR 5/13X,35HUSE 3 P  B4013B
     2ARTICLES FOR NPTPND = 8 OR 9/13X,31HUSE 4 PARTICLES FOR NPTPND = 1  B4013C
     36)                                                                  B4013D
  886 FORMAT (1H0,5X,38H*** WARNING ***  NITP SHOULD EQUAL 10 )           B4016
  888 FORMAT (1H1)                                                       SB4017
  890 FORMAT (1H0,23X,15HPROGRAM OPTIONS//13X,30HNPNT   (TIME STEP INTER  B4020
     1VAL FOR/21X,18HCOMPLETE PRINTOUT),7X,3H=  ,I4/13X,31HNPNTMV (MOVE   B4030
     2INTERVAL FOR CHEM./21X,28HCONCENTRATION PRINTOUT)  =  ,I4/13X,30HN  B4041
     3PNTVL (TIME STEP INTERVAL FOR/21X,'VELOCITY PRINTOUT; 0=NEVER;'/    B4045
     4 21X,'-1=FIRST TIME STEP;'/21X,'-2=LAST TIME STEP)',7X,3H=  ,I4/    B4051
     5 13X,'NPNTD  (PRINT OPTION-DISP.COEF.'/21X,                         B4055
     6 '0=NO; 1=FIRST TIME STEP;'/21X,'2=ALL TIME STEPS)',8X,3H=  ,I4/    B4061
     7 13X,'NUMOBS (NO. OF OBSERVATION WELLS'/                            B4065
     8 21X,'FOR HYDROGRAPH PRINTOUT) =  ',I4/                             B4071
     9 13X,'NREC   (NO. OF PUMPING WELLS)    = ',I5/                      B4075
     $ 13X,'NCODES (FOR NODE IDENT.)',9X,2H= ,I5/                         B4081
     1 13X,'NPNCHV (TIME STEP INTERVAL FOR'/21X,'VELOCITY PRINTOUT ON'/   B4091
     2 21X,'FILE UNIT 7; 0=NEVER;'/21X,'-1=FIRST TIME STEP;'/             B4101
     3 21X,'-2=LAST TIME STEP)',7X,2H= ,I5/                               B4111
     4 13X,'NPDELC (PRINT OPT.-CONC. CHANGE) =  ',I4/                     B4118R
     5 13X,'IREACT (REACTION SPECIFIERS):')                               B4126R
  891 FORMAT (//18X,'REACTION - ',A26/)                                   B4127R
  892 FORMAT (20X,'RHOB    (BULK DENSITY)                = ',1PE12.5)     B4128A
  893 FORMAT (20X,'DK      (DISTRIBUTION COEFFICIENT)    = ',1PE12.5/     B4128B
     1        20X,'RF      (RETARDATION FACTOR)          = ',1PE12.5)     B4128C
  894 FORMAT (20X,'EKF     (FREUNDLICH SORPTION CONSTANT)= ',1PE12.5/     B4128D
     1        20X,'XNF     (FREUNDLICH SORPTION SLOPE)   = ',1PE12.5)     B4128E
  895 FORMAT (20X,'EKL     (LANGMUIR SORPTION CONSTANT)  = ',1PE12.5/     B4128F
     1        20X,'CEC     (CATION EXCHANGE CAPACITY)    = ',1PE12.5)     B4128G
  896 FORMAT (20X,'EK      (ION EXCHANGE CONSTANT)       = ',1PE12.5/     B4128H
     1        20X,'CEC     (CATION EXCHANGE CAPACITY)    = ',1PE12.5/     B4128I
     2        20X,'CTOT    (TOTAL SOLUTE CONCENTRATION)  = ',1PE12.5)     B4128J
  897 FORMAT (/' *** WARNING ***  BETA.EQ.0.0 AND SORPTION-EXCHANGE IS',  B4129A
     1                                           ' NONLINEAR')            B4129B
  898 FORMAT (/13X,'THALF   (HALF LIFE OF DECAY,IN SEC)   = ',1PE12.5/    B4129C
     1         13X,'DECAY   (DECAY CONSTANT=LN 2/THALF)   = ',1PE12.5)    B4129D
  899 FORMAT (1H0,'Particle Set ',i2,' MINIMUM NONLINEAR RETARDATION',    B4129b
     &            ' FACTOR FOR THIS',                                     B4129E
     1            ' PUMPING PERIOD'//10X,' RF2MIN = ',1PE12.4)            B4129F
  901 format(//13x,'Particle Set ',i4,':')                                B4130b
  900 FORMAT (1H0,10X,29HLOCATION OF OBSERVATION WELLS//17X,3HNO.,5X,1HX  B4130
     1,5X,1HY/)                                                           B4140
  910 FORMAT (1H0,10X,28HLOCATION  OF  PUMPING  WELLS//11X,'X   Y   RA',  B4150b
     1'TE(IN CFS)   SOLUTE CONC. (1,2,....,NSOL)'/)                       B4160b
  920 FORMAT (1H0,5X,37HNO. OF NODE IDENT. CODES SPECIFIED = ,I2)         B4170
  930 FORMAT (1H0,10X,41HTHE FOLLOWING ASSIGNMENTS HAVE BEEN MADE:/5X,    B4180b
     1'CODE NO.     LEAKANCE     SOURCE SOLUTE CONC.(1,2,...,NSOL)        B4181b
     &     RECHARGE')                                                     B4190b
  935 FORMAT (1H ,5X,54H*** WARNING ***   THCK.NE.0.0 ON BOUNDARY AT NOD  B4195
     1E IX =,I4,6H, IY =,I4)                                              B4196
  940 FORMAT (1H ,5X,61H*** WARNING ***   THCK.EQ.0.0 AND TMRX(X).GT.0.0  B4200
     1 AT NODE IX =,I4,6H, IY =,I4)                                       B4210
  950 FORMAT (1H ,5X,61H*** WARNING ***   THCK.EQ.0.0 AND TMRX(Y).GT.0.0  B4220
     1 AT NODE IX =,I4,6H, IY =,I4)                                       B4230
  960 FORMAT (1H ,5X,61H*** WARNING ***    THCK.EQ.0.0 AND NODEID.GT.0.0  B4240
     1 AT NODE IX =,I4,6H, IY =,I4)                                       B4250
  970 FORMAT (1H ,5X,56H*** WARNING ***   THCK.EQ.0.0 AND WT.NE.0.0 AT N  B4260
     1ODE IX =,I4,6H, IY =,I4)                                            B4270
  980 FORMAT (1H ,5X,58H*** WARNING ***   THCK.EQ.0.0 AND RECH.NE.0.0 AT  B4280
     1 NODE IX =,I4,6H, IY =,I4)                                          B4290
  990 FORMAT (1H ,5X,58H*** WARNING ***    THCK.EQ.0.0 AND REC.NE.0.0 AT  B4300
     1 NODE IX =,I4,6H, IY =,I4)                                          B4310
 1000 FORMAT (1H ,5X,61H*** WARNING ***    TMRX.EQ.0.0 AND NODEID.GT.0.0  B4321
     1 AT NODE IX =,I4,6H, IY =,I4)                                       B4330
 1010 FORMAT (1H ,5X,56H*** WARNING ***   TMRX.EQ.0.0 AND WT.NE.0.0 AT N  B4341
     1ODE IX =,I4,6H, IY =,I4)                                            B4350
 1020 FORMAT (1H ,5X,58H*** WARNING ***   TMRX.EQ.0.0 AND RECH.NE.0.0 AT  B4361
     1 NODE IX =,I4,6H, IY =,I4)                                          B4370
 1030 FORMAT (1H ,5X,58H*** WARNING ***    TMRX.EQ.0.0 AND REC.NE.0.0 AT  B4381
     1 NODE IX =,I4,6H, IY =,I4)                                          B4390
 1040 FORMAT (1H ,5X,58H*** WARNING ***   TMRX.EQ.0.0 AND THCK.GT.0.0 AT  B4401
     1 NODE IX =,I4,6H, IY =,I4)                                          B4410
 1050 FORMAT (1H0,5X,45H*** WARNING ***   ANFCTR WAS SPECIFIED AS 0.0/23  B4420
     1X,34HDEFAULT ACTION: RESET ANFCTR = 1.0)                            B4430
 1060 FORMAT (I1)                                                         B4440
 1070 FORMAT (10I5,3G5.0)                                                 B4450
 1080 FORMAT (1H1,5X,25HSTART PUMPING PERIOD NO. ,I2//2X,75HTHE FOLLOWIN  B4460
     1G TIME STEP, PUMPAGE, AND PRINT PARAMETERS HAVE BEEN REDEFINED:/)   B4470
 1090 FORMAT (1H0,14X,9HNTIM   = ,I4/15X,9HNPNT   = ,I4/15X,9HNITP   = ,  B4480
     1I4/15X,9HITMAX  = ,I4/15X,9HNREC   = ,I4/15X,9HNPNTMV = ,I4/15X,9H  B4490
     2NPNTVL = ,I4/15X,9HNPNTD  = ,I4/15X,9HNPDELC = ,I4/15X,9HNPNCHV =   B4500
     3,I4/15X,9HPINT   = ,F10.3/15X,9HTIMX   = ,F10.3/15X,9HTINIT  = ,F1  B4510
     40.3/)                                                               B4520
 1100 FORMAT (1H ,46X,E10.3)                                              B4530
 1110 FORMAT (1H1,5X,25HSTART PUMPING PERIOD NO. ,I2//2X,23HNO PARAMETER  B4532
     1S REDEFINED/)                                                       B4533
      END                                                                 B4540-
      SUBROUTINE ITERAT                                                   C  10
C     ----------------------------------------------------------------    C  30
C     SOLUTION BY THE STRONGLY IMPLICIT PROCEDURE                         C  40
C     ----------------------------------------------------------------    C  50
      INCLUDE 'dims.inc'                                                  C  51b
      DOUBLE PRECISION DMIN1,DEXP,DLOG,DABS                               C  20
      DOUBLE PRECISION TMRX,VPRM,HI,HR,HC,HK,WT,REC,RECH,TIM,AOPT,TITLE   C  30
      DOUBLE PRECISION DEL,ETA,V,XI,RHOP,TEST3                            C  82
      DOUBLE PRECISION BIGI,DX,DY                                         C  85
      DOUBLE PRECISION XDEL,YDEL,S,AREA,SUMT,RHO,PARAM,TEST,TOL,PINT,     C  40
     1                 HMIN,PYR,ANFCTR                                    C  42
      DOUBLE PRECISION DXINV,DYINV,ARINV,PORINV                           C  45
      DOUBLE PRECISION B,G,W,A,C,E,F,DR,DC,TBAR,TMK,COEF,BLH,BRK,CHK,QL,  C  50
     1                 BRH,HMAX                                           C  52b
      DOUBLE PRECISION TOTLQ,TOTLQI,TPIN,TPOUT,PQIN,PQOUT,DELQ            C  52
      DOUBLE PRECISION RATIO                                              C 113
      double precision d,h,ch,gh,bh,dh,eh,fh,hh,gama                      C 113b
      COMMON /PRMJ/ NTIM,NPMP,NPNT,NITP,N,NX,NY,NP(NPS),NREC,INT,NNX,     C  53b
     &              NNY,                                                  C  61b
     1              NUMOBS,NMOV,IMOV,NPMAX,ITMAX,NZCRIT,IPRNT,NPTPND,     C  71
     2              NPNTMV,NPNTVL,NPNTD,NPNCHV,NPDELC,ICHK,nsol,npop,     C  82b
     3              npset,nconc(NPS),imob(NPS)                            C  83b
      COMMON /HEDA/ THCK(NXD,NYD),TMWL(NOB,500),TMOBS(500)                C  84b
      COMMON /HEDB/ TMRX(NXD,NYD,2),VPRM(NXD,NYD),HI(NXD,NYD),            C  85b
     1              HR(NXD,NYD),HC(NXD,NYD),HK(NXD,NYD),WT(NXD,NYD),      C  86b
     2REC(NXD,NYD),RECH(NXD,NYD),TIM(500),AOPT(20),TITLE(010),XDEL,YDEL,  C  87b
     3              S,AREA,SUMT,RHO,PARAM,TEST(NPS),TOL,PINT,HMIN,PYR,    C  88b
     4              ANFCTR                                                C  89b
      COMMON /XINV/ DXINV,DYINV,ARINV,PORINV                              C  90b
      COMMON /BALM/ TOTLQ,TOTLQI,TPIN,TPOUT,HMAX                          C  91b
      DIMENSION DEL(NXD,NYD),ETA(NXD,NYD),V(NXD,NYD),XI(NXD,NYD),        SC 231
     1          RHOP(NXD),TEST3(501)                                     SC 242
      EQUIVALENCE (DEL,HC)                                                C 245
C     ***************************************************************     C 180
C                                                                         C 260
C      COMPUTE AND PRINT ITERATION PARAMETERS                             C 270
C                                                                         C 280
      PQIN=0.D0                                                           C 290
      PQOUT=0.D0                                                          C 300
C      DO NOT REPEAT SOLUTION FOR STEADY-STATE                            C 302
      IREPET=0                                                            C 303
      IF (S.EQ.0.0.AND.(N.GT.1.OR.(INT.GT.1.AND.ICHK.EQ.0))) THEN         C 304
       IREPET=1                                                           C 305
       GO TO 222                                                          C 306
      END IF                                                              C 307
      KOUNT=-1                                                            C 310
      DO 1000 I=1,NX                                                      C 320
      DO 1000 J=1,NY                                                      C 330
 1000 HR(I,J)=HK(I,J)                                                     C 340
      IF(INT.NE.1) GO TO 40                                               C 350
C                                                                         C 360
C      ---INITIALIZE ORDER OF ITERATION PARAMETERS                        C 370
C                                                                         C 380
      INO1=NX-1                                                           C 390
      JNO1=NY-1                                                           C 400
      I2=INO1-1                                                           C 410
      J2=JNO1-1                                                           C 420
      L2=NITP/2                                                           C 430
      PL2=L2-1.                                                           C 440
C                                                                         C 450
C      COMPUTE MAXIMUM PARAMETER FOR PROBLEM                              C 460
C                                                                         C 470
      RATIO=ANFCTR*XDEL**2/YDEL**2                                        C 492
      W=4.9348022D0/DMAX1(NX**2*(1.D0+RATIO),                             C 503
     1                    NY**2*(1.D0+1.D0/RATIO))                        C 504
C                                                                         C 510
C      --- COMPUTE PARAMETERS IN GEOMETRIC SEQUENCE ---                   C 520
C                                                                         C 530
      PJ=-1.                                                              C 540
      DO 20 I=1,L2                                                        C 550
      PJ=PJ+1.                                                            C 560
      RHOP(I)=1.D0-(W*10.)**(PJ/PL2)                                      C 571b
  20  RHOP(I+L2)=RHOP(I)                                                  C 572
      RHOP(NITP)=RHOP(L2)                                                 C 573
C                                                                         C 580
C      --- PRINT ITERATION PARAMETERS ---                                 C 591
C                                                                         C 600
      WRITE(6,1002) HMAX,NITP,(RHOP(J),J=1,NITP)                          C 630
 1002 FORMAT(1X,6HBETA= ,F4.2,/,1X,I3,23H ITERATION  PARAMETERS:,6(/1X,   C 640
     16E15.6))                                                            C 650
C                                                                         C 660
C      INITIALIZE DATA FOR A NEW ITERATION                                C 670
C                                                                         C 680
  40  KOUNT=KOUNT+1                                                       C 690
      IF(KOUNT.LE.ITMAX) GO TO 50                                         C 700
      WRITE(6,160)                                                        C 710
      CALL OUTPT                                                          C 720
      WRITE(6,1003) (TEST3(I),I=1,KOUNT)                                  C 730
 1003 FORMAT(1X,39HMAXIMUM HEAD CHANGE FOR EACH ITERATION:,               C 740
     +20(/,1X,10(F12.5)))                                                 C 750
      STOP                                                                C 760
  50  NTH=MOD(KOUNT,NITP)+1                                               C 771
C                                                                         C 780
C      INITIALIZE DATA FOR A NEW ITERATION                                C 790
C                                                                         C 800
      W=RHOP(NTH)                                                         C 830
      TEST3(KOUNT+1)=0.D0                                                 C 840
      TEST(1)=0.D0                                                        C 850b
      DO 80 I=1,NX                                                        C 860
      DO 80 J=1,NY                                                        C 870
      DEL(I,J)=0.D0                                                       C 880
      ETA(I,J)=0.D0                                                       C 890
      V(I,J)=0.D0                                                         C 900
   80 XI(I,J)=0.D0                                                        C 910
      BIGI=0.D0                                                           C 920
      RHO=S/TIM(N)                                                        C 930
C                                                                         C 940
C      CHOOSE SIP NORMAL OR REVERSE ALGORITHM                             C 950
C                                                                         C 960
      IF(MOD(KOUNT,2)) 100,230,100                                        C 970
C                                                                         C 980
C      ...............................................................    C 990
C      ---ORDER EQUATIONS WITH ROW 1 FIRST- 3X3 EXAMPLE:                  C1000
C                       1 2 3                                             C1010
C                       4 5 6                                             C1020
C                       7 8 9                                             C1030
C      ................................................................   C1040
  100 DO 210 J=2,JNO1                                                     C1050
      DO 210 I=2,INO1                                                     C1060
C                                                                         C1070
C      --- SKIP COMPUTATIONS IF NODE IS OUTSIDE AQUIFER BOUNDARY---       C1080
      IF(THCK(I,J).EQ.0.) GO TO 210                                       C1090
C                                                                         C1100
C      --- COMPUTE COEFFICIENTS---                                        C1110
C                                                                         C1120
      D=TMRX(I-1,J,1)/XDEL                                                C1130
      F=TMRX(I,J,1)/XDEL                                                  C1140
      B=TMRX(I,J-1,2)/YDEL                                                C1150
      H=TMRX(I,J,2)/YDEL                                                  C1160
      CH=DEL(I,J-1)*B/(1.+W*DEL(I,J-1))                                   C1170
      GH=ETA(I-1,J)*D/(1.+W*ETA(I-1,J))                                   C1180
C                                                                         C1190
C      ---SIP 'NORMAL' ALGORITHM ---                                      C1200
C      ---FOWARD SUBSTITUTE, COMPUTING INTERMEDIATE VECTOR V---           C1210
C                                                                         C1220
      E=-B-D-F-H-RHO-VPRM(I,J)                                            C1230
      BH=B-W*CH                                                           C1240
      DH=D-W*GH                                                           C1250
      EH=E+W*(CH+GH)                                                      C1260
      FH=F-W*CH                                                           C1270
      HH=H-W*GH                                                           C1280
      ALFA=BH                                                             C1290
      BETA=DH                                                             C1300
      GAMA=EH-ALFA*ETA(I,J-1)-BETA*DEL(I-1,J)                             C1310
      DEL(I,J)=FH/GAMA                                                    C1320
      ETA(I,J)=HH/GAMA                                                    C1330
      QL=-VPRM(I,J)*WT(I,J)                                               C1340
      RES=-D*HK(I-1,J)-F*HK(I+1,J)-H*HK(I,J+1)-B*HK(I,J-1)-               C1350
     1E*HK(I,J)-RHO*HR(I,J)+QL+RECH(I,J)+REC(I,J)*ARINV                   C1360
      V(I,J)=(HMAX*RES-ALFA*V(I,J-1)-BETA*V(I-1,J))/GAMA                  C1370
  210 CONTINUE                                                            C1380
C                                                                         C1390
C      ---BACK SUBSTITUTE FOR VECTOR XI ---                               C1400
C                                                                         C1410
      DO 220 J=1,J2                                                       C1420
      J3=NY-J                                                             C1430
      DO 220 I=1,I2                                                       C1440
      I3=NX-I                                                             C1450
      IF(THCK(I3,J3).EQ.0.) GO TO 220                                     C1460
      XI(I3,J3)=V(I3,J3)-DEL(I3,J3)*XI(I3+1,J3)-                          C1470
     1ETA(I3,J3)*XI(I3,J3+1)                                              C1480
C                                                                         C1490
C      --- COMPARE MAGNITUDE OF CHANGE WITH CLOSURE CRITERION---          C1500
C                                                                         C1510
      TCHK=DABS(XI(I3,J3))                                                C1520
      IF(TCHK.GT.BIGI)BIGI=TCHK                                           C1530
      HK(I3,J3)=HK(I3,J3)+XI(I3,J3)                                       C1540
  220 CONTINUE                                                            C1550
  221 IF(BIGI.GT.TOL)TEST(1)=1.D0                                         C1560b
      TEST3(KOUNT+1)=BIGI                                                 C1570
      IF(TEST(1).EQ.1.) GO TO 40                                          C1580b
  222 DO 130 IY=1,NY                                                      C1591
      DO 130 IX=1,NX                                                      C1600
      IF (THCK(IX,IY).EQ.0.0) GO TO 130                                   C1602
C      UPDATE THICKNESS*POROSITY FOR TRANSIENT FLOW                       C1603
      IF (IREPET.EQ.0) THEN                                               C1604
       THCK(IX,IY)=THCK(IX,IY)+S*(HK(IX,IY)-HR(IX,IY))                    C1605
       IF (THCK(IX,IY).LE.0.0) THEN                                       C1606A
        WRITE (6,170) IX,IY                                               C1606B
        THCK(IX,IY)=0.0                                                   C1606C
       END IF                                                             C1606D
      END IF                                                              C1607
C     ---CUMULATE PUMPAGE AND RECHARGE FOR MASS BALANCE---                C1610
      IF (REC(IX,IY).GT.0.0) GO TO 32                                     C1620
      PQIN=PQIN+REC(IX,IY)                                                C1630
      GO TO 34                                                            C1640
   32 PQOUT=PQOUT+REC(IX,IY)                                              C1650
   34 IF (RECH(IX,IY).GT.0.0) GO TO 36                                    C1660
      PQIN=PQIN+RECH(IX,IY)*AREA                                          C1670
      GO TO 38                                                            C1680
   36 PQOUT=PQOUT+RECH(IX,IY)*AREA                                        C1690
C     ---COMPUTE LEAKAGE FOR MASS BALANCE---                              C1700
   38 IF (VPRM(IX,IY).EQ.0.0) GO TO 130                                   C1710
      DELQ=VPRM(IX,IY)*AREA*(WT(IX,IY)-HK(IX,IY))                         C1720
      IF (DELQ.GT.0.0) GO TO 125                                          C1730
      TOTLQ=TOTLQ+DELQ*TIM(N)                                             C1740
      GO TO 130                                                           C1750
  125 TOTLQI=TOTLQI+DELQ*TIM(N)                                           C1760
  130 CONTINUE                                                            C1770
      TPIN=PQIN*TIM(N)+TPIN                                               C1780
      TPOUT=PQOUT*TIM(N)+TPOUT                                            C1790
      WRITE(6,140) N                                                      C1800
      IF (IREPET.EQ.0) THEN                                               C1805
      KOUNT=KOUNT+1                                                       C1810
      WRITE(6,150) KOUNT,(TEST3(I),I=1,KOUNT)                             C1820
      ELSE                                                                C1824
       WRITE (6,151)                                                      C1825
      END IF                                                              C1826
      RETURN                                                              C1830
C                                                                         C1840
C      .................................................................  C1850
C      ---ORDER EQUATIONS WITH THE LAST ROW FIRST- 3X3 EXAMPLE:           C1860
C               7 8 9                                                     C1870
C               4 5 6                                                     C1880
C               1 2 3                                                     C1890
C      ................................................................   C1900
230   DO 340 JJ=1,J2                                                      C1910
      J=NY-JJ                                                             C1920
      DO 340 I=2,INO1                                                     C1930
C                                                                         C1940
C      --- SKIP COMPUTATIONS IF NODE IS OUTSIDE OF AQUIFER BOUNDARY---    C1950
      IF (THCK(I,J).EQ.0.) GO TO 340                                      C1960
C                                                                         C1970
C      ---COMPUTE COEFFICIENTS---                                         C1980
      D=TMRX(I-1,J,1)/XDEL                                                C1990
      F=TMRX(I,J,1)/XDEL                                                  C2000
      B=TMRX(I,J-1,2)/YDEL                                                C2010
      H=TMRX(I,J,2)/YDEL                                                  C2020
C                                                                         C2030
C      --- SIP 'REVERSE' ALGORITHM---                                     C2040
C      --- FOWARD SUBSTITUTE, COMPUTING INTERMEDIATE VECTOR V---          C2050
C                                                                         C2060
      E=-B-D-F-H-RHO-VPRM(I,J)                                            C2070
      CH=DEL(I,J+1)*H/(1.+W*DEL(I,J+1))                                   C2080
      GH=ETA(I-1,J)*D/(1.+W*ETA(I-1,J))                                   C2090
      BH=H-W*CH                                                           C2100
      DH=D-W*GH                                                           C2110
      EH=E+W*(CH+GH)                                                      C2120
      FH=F-W*CH                                                           C2130
      HH=B-W*GH                                                           C2140
      ALFA=BH                                                             C2150
      BETA=DH                                                             C2160
      GAMA=EH-ALFA*ETA(I,J+1)-BETA*DEL(I-1,J)                             C2170
      DEL(I,J)=FH/GAMA                                                    C2180
      ETA(I,J)=HH/GAMA                                                    C2190
      QL=-VPRM(I,J)*WT(I,J)                                               C2200
      RES=-D*HK(I-1,J)-F*HK(I+1,J)-H*HK(I,J+1)-B*HK(I,J-1)-               C2210
     1E*HK(I,J)-RHO*HR(I,J)+QL+RECH(I,J)+REC(I,J)*ARINV                   C2220
      V(I,J)=(HMAX*RES-ALFA*V(I,J+1)-BETA*V(I-1,J))/GAMA                  C2230
  340 CONTINUE                                                            C2240
 1030 FORMAT(1X,8F13.2)                                                   C2250
C                                                                         C2260
C      --- BACK SUBSTITUTE FOR VECTOR XI ---                              C2270
      DO 350 J=2,JNO1                                                     C2280
      DO 350 I3=1,I2                                                      C2290
      I=NX-I3                                                             C2300
      IF(THCK(I,J).EQ.0.) GO TO 350                                       C2310
      XI(I,J)=V(I,J)-DEL(I,J)*XI(I+1,J)-ETA(I,J)*XI(I,J-1)                C2320
C                                                                         C2330
C      --- COMPARE MAGNITUDE OF CHANGE WITH CLOSURE CRITERION ---         C2340
C                                                                         C2350
      TCHK=DABS(XI(I,J))                                                  C2360
      IF(TCHK.GT.BIGI) BIGI=TCHK                                          C2370
      HK(I,J)=HK(I,J)+XI(I,J)                                             C2380
  350 CONTINUE                                                            C2390
      GO TO 221                                                           C2400
  140 FORMAT(1H0//3X,4HN = ,1I4)                                          C2410
  150 FORMAT(1X,22HNUMBER OF ITERATIONS= ,I3,/,1X,                        C2420
     139HMAXIMUM HEAD CHANGE FOR EACH ITERATION:,20(/,1X,10F12.5))        C2430
  151 FORMAT (1X,44HNUMBER OF ITERATIONS=   0  (HEADS UNCHANGED))         C2432
  160 FORMAT(1H0,5X, 53H*** EXECUTION TERMINATED -- MAX # ITERATIONS EXC  C2440
     1EEDED/26X,21HFINAL OUTPUT FOLLOWS:)                                 C2450
  170 FORMAT (/' **** ERROR ****  EFFECTIVE AQUIFER VOLUME IS ZERO ',     C2454
     1         'IN CELL ',I4,' ,',I4//)                                   C2455
C     RETURN                                                              C2460
      END                                                                 C2470-
C *********************************************************************   D   5
      SUBROUTINE GENPT(kp)                                                D  10b
      INCLUDE 'dims.inc'                                                  D  11b
      DOUBLE PRECISION TMRX,VPRM,HI,HR,HC,HK,WT,REC,RECH,TIM,AOPT,TITLE   D  20
      DOUBLE PRECISION XDEL,YDEL,S,AREA,SUMT,RHO,PARAM,TEST,TOL,PINT,     D  30
     1                 HMIN,PYR,ANFCTR                                    D  32
      double precision bioloss,biogain,up,uptake                          D  33b
      real ncinhib                                                        D  34b
      INTEGER PTID                                                        D  36
      COMMON /PRMJ/ NTIM,NPMP,NPNT,NITP,N,NX,NY,NP(NPS),NREC,INT,NNX,     D  37b
     &              NNY,                                                  D  41b
     1              NUMOBS,NMOV,IMOV,NPMAX,ITMAX,NZCRIT,IPRNT,NPTPND,     D  51
     2              NPNTMV,NPNTVL,NPNTD,NPNCHV,NPDELC,ICHK,nsol,npop,     D  62b
     3              npset,nconc(NPS),imob(NPS)                            D  63b
      COMMON /PRMC/ NODEID(NXD,NYD),NPCELL(NXC,NYC,NPS),                  D  64b
     &              NPOLD(NXC,NYC,NPS),                                   D  65b
     1              LIMBO(1000,NPS),IXOBS(NOB),IYOBS(NOB)                 D  66b
      COMMON /HEDA/ THCK(NXD,NYD),TMWL(NOB,500),TMOBS(500)                D  67b
      COMMON /HEDB/ TMRX(NXD,NYD,2),VPRM(NXD,NYD),HI(NXD,NYD),            D  68b
     1              HR(NXD,NYD),HC(NXD,NYD),HK(NXD,NYD),WT(NXD,NYD),      D  69b
     2REC(NXD,NYD),RECH(NXD,NYD),TIM(500),AOPT(20),TITLE(010),XDEL,YDEL,  D  70b
     3              S,AREA,SUMT,RHO,PARAM,TEST(NPS),TOL,PINT,HMIN,PYR,    D  71b
     4              ANFCTR                                                D  72b
      COMMON /HEDC/ MX,MY,MMX,MMY,NMX,NMY,MCHK                            D  73b 
      COMMON /CHMA/ PART(NPC,NPTS,NPS),CONC(NXC,NYC,NSL),                 D  74b
     &              TMCN(NOB,500,NSL),                                    D  75b
     &              partxy(2,NPTS,NPS),                                   D  76b
     &              VX(NXD,NYD),tmz(NOB,500,NMC),                         D  77b
     1              VY(NXD,NYD),CONINT(NXC,NYC,NSL),CNRECH(NXC,NYC,NSL),  D  78b
     &              POROS,                                                D  79b
     2              SUMTCH,BETA,TIMV,STORM(NSL),STORMI(NSL),CMSIN(NSL),   D  80b
     &              CMSOUT(NSL),FLMIN(NSL),                               D  81b
     3              FLMOT(NSL),SUMIO(NSL),CELDIS,DLTRAT,CSTORM(NSL)       D  82b
      COMMON /CHMP/ PTID(NPTS,NPS)                                        D  83b
      common /inbio/ ibio,nproc,nsproc(NPR),iz(NPR),nzinhib,ncomp(NPR),   D  84b
     &               nnc(NPR),nhal(NPR),kscomp(NPR,NMC),ksnc(NPR,NMC),    D  85b
     &               kshal(NPR,NMC),ksproc(NPR,NSL),numnut,ksnut(NSL)     D  86b
      common /rbio/  z(NXC,NYC,NMC),vmax(NPR),                            D  87b
     &               yield(NPR),                                          D  88b
     &               upcoef(NPR,NSL),hfk(NPR,NSL),faccomp(NPR,NMC),       D  89b
     &               facnc(NPR,NMC),                                      D  90b
     &               fachal(NPR,NMC),death(NMC),yieldnut(NSL),            D  91b
     &               compinhib(NPR),ncinhib(NPR),                         D  92b
     &               zinhibfac(NMC),                                      D  93b
     &               halinhib(NPR),grow(NMC),zinit(NXC,NYC,NMC),          D  94b
     &               hfknut(NSL),relcoef(NSL),zinhib(NMC)                 D  95b
      common /dbio/  bioloss(NXC,NYC,NSL), biogain(NXC,NYC,NSL),          D
     &               up(NPR), uptake(NPR,NSL)                             D
      DIMENSION RPT(NPC,16),RNT(NPC,16),RP(NPC,16),RN(NPC,16),IPT(16),    D  96b
     &c1(NPC),test3(NPC),cnode(NPC),meth(NPC),partc(NPC)                  D 161b
C     ***************************************************************     D 170
      ks1=1                                                               D 162b
      do 1 nn=1,kp-1                                                      D 163b
        ks1=ks1+nconc(nn)                                                 D 164b
  1   continue                                                            D 165b
      kslast=ks1+nconc(kp)-1                                              D 166b
      IONED=0                                                             D 172
      IF(NX.EQ.3.OR.NY.EQ.3) IONED=1                                      D 173
      F1=0.30                                                             D 180
      F2=1.0/3.0                                                          D 190
      IF (NPTPND.EQ.4) F1=0.25                                            D 200
      IF (NPTPND.EQ.5.AND.IONED.EQ.1) F1=0.25                             D 202
      IF (NPTPND.EQ.9) F1=1.0/3.0                                         D 210
      IF (NPTPND.EQ.8.AND.IONED.NE.1) F2=0.25                             D 221
      IF (NPTPND.EQ.8.AND.IONED.EQ.1) F1=1.0/3.0                          D 222
      IF (NPTPND.EQ.16) F1=0.25                                           D 223
      IF (NPTPND.EQ.16) F2=0.125                                          D 224
      NCHK=NPTPND                                                         D 230
      IF (NPTPND.EQ.5.OR.NPTPND.EQ.9) NCHK=NPTPND-1                       D 240
      IF (TEST(kp).GT.98.) GO TO 10                                       D 250b
C     ***************************************************************     D 260
C     ---INITIALIZE VALUES---                                             D 270
      do 2 ks=ks1,kslast                                                  D 271b
      STORM(ks)=0.0                                                       D 280b
      CMSIN(ks)=0.0                                                       D 290b
      CMSOUT(ks)=0.0                                                      D 300b
      FLMIN(ks)=0.0                                                       D 310b
      FLMOT(ks)=0.0                                                       D 320b
      SUMIO(ks)=0.0                                                       D 330b
  2   continue                                                            D 331b
C     ***************************************************************     D 340
   10 DO 20 IN=1,NPMAX                                                    D 345
      PTID(IN,kp)=0                                                       D 355b
      partxy(1,in,kp)=0.0                                                 D 356b
      partxy(2,in,kp)=0.0                                                 D 357b
      DO 20 ID=1,nconc(kp)                                                D 365b
   20 PART(ID,IN,kp)=0.0                                                  D 370b
      DO 30 IA=1,16                                                       D 381
      DO 30 ID=1,nconc(kp)                                                D 365b
      RP(id,IA)=0.0                                                       D 390b
      RN(id,IA)=0.0                                                       D 400b
      RPT(id,IA)=0.0                                                      D 401b
      RNT(id,IA)=0.0                                                      D 402b
   30 IPT(IA)=0                                                           D 410
C     ---SET UP LIMBO ARRAY---                                            D 420
      DO 40 IN=1,1000                                                     D 430b
   40 LIMBO(IN,kp)=0                                                      D 441b
      IND=1                                                               D 450
C     ***************************************************************     D 490
C     ---INSERT PARTICLES---                                              D 500
C        ---TRACK PARTICLE LOCATIONS IN COORDINATES OF PRIMARY GRID---   SD 505
      DO 410 IX=1,NMX                                                    SD 512
      JX=IX+MX-1                                                         SD 515
      DO 410 IY=1,NMY                                                    SD 522
      JY=IY+MY-1                                                         SD 525
      IF (THCK(JX,JY).EQ.0.0) GO TO 410                                  SD 531
      KR=0                                                                D 540
      KR2=0                                                               D 541
      TEST2=0.0                                                           D 550
      do 21 kps=1,nconc(kp)                                               D 551
        test3(kps)=0.0                                                    D 552
        METH(kps)=1                                                       D 560b
 21   continue                                                            D 561b
      NPCELL(IX,IY,kp)=0                                                  D 570b
      NPOLD(IX,IY,kp)=NPTPND                                              D 575b
      kps=0                                                               D 576b
      do 3 ks=ks1,kslast                                                  D 577b
        kps=kps+1                                                         D 578b
        C1(kps)=CONC(IX,IY,ks)                                            D 580b
  3   continue                                                            D 581b
      IF (NPTPND.EQ.1) GO TO 150                                          D 585
      do 4 kps=1,nconc(kp)                                                D 586b
        IF (C1(kps).LE.1.0E-05) TEST3(kps)=1.0                            D 590b
  4   continue                                                            D 591b
      IF (IX.EQ.1.OR.IX.EQ.NMX.OR.IY.EQ.1.OR.IY.EQ.NMY) TEST2=1.0        SD 595
      IF (VPRM(JX,JY).GT.0.09) TEST2=1.0                                 SD 601
      IF (REC(JX,JY).NE.0.0) TEST2=1.0                                   SD 611
      IF (THCK(JX+1,JY+1).EQ.0.0.OR.THCK(JX+1,JY-1).EQ.0.0.OR.THCK(JX-1, SD 621
     1JY+1).EQ.0.0.OR.THCK(JX-1,JY-1).EQ.0.0) TEST2=1.0                  SD 631
      IF ((THCK(JX,JY+1).EQ.0.0.OR.THCK(JX,JY-1).EQ.0.0.OR.THCK(JX+1,JY) SD 641
     1.EQ.0.0.OR.THCK(JX-1,JY).EQ.0.0).AND.NPTPND.GT.5) TEST2=1.0        SD 651
      do 5 kps=1,nconc(kp)                                                D 652b
        CNODE(kps)=C1(kps)*(1.0-F1)                                       D 660b
  5   continue                                                            D 661b
      IF (TEST(kp).LT.98.0.OR.TEST2.GT.0.0) GO TO 70                      D 670b
      kps=0                                                               D 671b
      do 6 ks=ks1,kslast                                                  D 672b
        kps=kps+1                                                         D 673b
        if(test3(kps).gt.0.0)go to 6                                      D 674b
      SUMC=CONC(IX+1,IY,ks)+CONC(IX-1,IY,ks)+CONC(IX,IY+1,ks)+            D 675b
     &  CONC(IX,IY-1,ks)                                                  D 680b
      IF (NCHK.EQ.4) GO TO 60                                             D 690
      SUMC=SUMC+CONC(IX+1,IY+1,ks)+CONC(IX+1,IY-1,ks)+CONC(IX-1,IY+1,ks)  D 691b
     &  +CONC(IX-1,IY-1,ks)                                               D 710b
   60 AVC=SUMC/NCHK                                                       D 720
      IF (AVC.GT.C1(kps)) METH(kps)=2                                     D 730b
  6   continue                                                            D 731b
C                                                                         D 740
C        ---PUT 4 PARTICLES ON CELL DIAGONALS---                          D 750
   70 DO 140 IT=1,2                                                       D 760
      EVET=(-1.0)**IT                                                     D 770
      DO 140 IS=1,2                                                       D 780
      IF(IONED.EQ.1.AND.IT.EQ.1.AND.IS.EQ.2) GO TO 140                    D 782
      IF(IONED.EQ.1.AND.IT.EQ.2.AND.IS.EQ.1) GO TO 140                    D 783
      EVES=(-1.0)**IS                                                     D 790
      KR=KR+1                                                             D 793
      IF (NPTPND.EQ.16) GO TO 72                                          D 795
      PARTxy(1,IND,kp)=JX+F1*EVET                                        SD 801b
      PARTxy(2,IND,kp)=JY+F1*EVES                                        SD 811b
      PARTxy(2,IND,kp)=-PARTxy(2,IND,kp)                                  D 820b
      do 7 kps=1,nconc(kp)                                                D 821b
        PART(kps,IND,kp)=C1(kps)                                          D 830b
  7   continue                                                            D 831b
      IPT(KR)=IND                                                         D 833
      PTID(IND,kp)=KR                                                     D 834b
      IF(IONED.EQ.1.AND.IS.EQ.2) PTID(IND,kp)=4                           D 835b
      GO TO 76                                                            D 835
   72 IF (TEST(kp).LT.98.0.OR.TEST2.GT.0.0) GO TO 135                     D 841b
   76 IF (TEST(kp).LT.98.0.OR.TEST2.GT.0.0) GO TO 139                     D 845b
      IXD=IX+EVET                                                         D 850
      IYD=IY+EVES                                                         D 860
      kps=0                                                               D 861b
      do 8 ks=ks1,kslast                                                  D 862b
        kps=kps+1                                                         D 863b
        if(test3(kps).gt.0.0)go to 8                                      D 864b
      IF (METH(kps).EQ.2) GO TO 80                                        D 890b
      PARTC(kps)=CNODE(kps)+CONC(IXD,IYD,ks)*F1                           D 901b
      GO TO 90                                                            D 910
   80 PARTC(kps)=2.0*C1(kps)*CONC(IXD,IYD,ks)/(C1(kps)+CONC(IXD,IYD,ks))  D 921b
   90 IF (C1(kps)-CONC(IXD,IYD,ks)) 100,110,120                           D 930b
  100 RPT(kps,KR)=CONC(IXD,IYD,ks)-PARTC(kps)                             D 941b
      RNT(kps,KR)=C1(kps)-PARTC(kps)                                      D 951b
      GO TO 130                                                           D 960
  110 RPT(kps,KR)=0.0                                                     D 971b
      RNT(kps,KR)=0.0                                                     D 981b
      GO TO 130                                                           D 990
  120 RPT(kps,KR)=C1(kps)-PARTC(kps)                                      D1001b
      RNT(kps,KR)=CONC(IXD,IYD,ks)-PARTC(kps)                             D1011b
  130 IF (NPTPND.EQ.16) GO TO 008                                         D1012
      PART(kps,IND,kp)=PARTC(kps)                                         D1013b
      RP(kps,KR)=RPT(kps,KR)                                              D1014b
      RN(kps,KR)=RNT(kps,KR)                                              D1015b
  8   continue                                                            D1016b
      if(nptpnd.eq.16)go to 135                                           D1017b
      GO TO 139                                                           D1016
  135 DO 138 ITT = 1,2                                                    D1017
      EVET2=(-1.0)**ITT                                                   D1018
      DO 138 ISS = 1,2                                                    D1019
      IF(IONED.EQ.1.AND.ITT.EQ.1.AND.ISS.EQ.2) GO TO 138                  D1019A
      IF(IONED.EQ.1.AND.ITT.EQ.2.AND.ISS.EQ.1) GO TO 138                  D1019B
      EVES2=(-1.0)**ISS                                                   D1021
      PARTxy(1,IND,kp)=(JX+F1*EVET)+F2*EVET2                             SD1022b
      PARTxy(2,IND,kp)=(JY+F1*EVES)+F2*EVES2                             SD1023b
      PARTxy(2,IND,kp)=-PARTxy(2,IND,kp)                                  D1024b
      KR2=KR2+1                                                           D1025
c      IF (TEST(ks).LT.98.0.OR.TEST2.GT.0.0) GO TO 136                    D1026b
c      PART(3,IND,ks) = PARTC                                             D1027b
c      RP(KR2) = RPT(KR)                                                  D1028b
c      RN(KR2) = RNT(KR)                                                  D1029b
c      IPT(KR2) = IND                                                     D1031b
c      GO TO 137                                                          D1032b
c  136 PART(3,IND,ks) = C1                                                D1033b
      IF (TEST(kp).LT.98.0.OR.TEST2.GT.0.0) then                          D1034b
        do 9 kps=1,nconc(kp)                                              D1035b
          part(kps,ind,kp)=c1(kps)                                        D1036b
   9    continue                                                          D1037b
      else                                                                D1038b
        do 11 kps=1,nconc(kp)                                             D1039b
        if(test3(kps).gt.0.0)then                                         D1040b
          part(kps,ind,kp)=c1(kps)                                        D1041b
        else                                                              D1042b
          PART(kps,IND,kp) = PARTC(kps)                                   D1043b
          RP(kps,KR2) = RPT(kps,KR)                                       D1044b
          RN(kps,KR2) = RNT(kps,KR)                                       D1045b
          IPT(KR2) = IND                                                  D1046b
        end if                                                            D1047b
  11    continue                                                          D1048b
      end if                                                              D1049b
  137 PTID(IND,kp)=KR2                                                    D1050b
      IF(IONED.EQ.1) THEN                                                 D1034A
       IF(IT.EQ.1.AND.ISS.EQ.2) PTID(IND,kp)=4                            D1034b
       IF(IT.EQ.2) THEN                                                   D1034C
        IF(ISS.EQ.1) PTID(IND,kp)=13                                      D1034d
        IF(ISS.EQ.2) PTID(IND,kp)=16                                      D1034e
       END IF                                                             D1034F
      END IF                                                              D1034G
      IND=IND+1                                                           D1035
  138 CONTINUE                                                            D1036
      GO TO 140                                                           D1037
  139 IND=IND+1                                                           D1038
  140 CONTINUE                                                            D1039
      IF (NPTPND.EQ.16) GO TO 290                                         D1045
      IF ((NPTPND.EQ.5.AND.IONED.NE.1).OR.NPTPND.EQ.9) GO TO 150          D1051
      IF (NPTPND.EQ.8.AND.IONED.EQ.1) GO TO 150                           D1052
      GO TO 160                                                           D1060
C        ---PUT ONE PARTICLE AT CENTER OF CELL---                         D1070
  150 PARTxy(1,IND,kp)=JX                                                SD1076b
      PARTxy(2,IND,kp)=-JY                                               SD1091b
      do 12 kps=1,nconc(kp)                                               D1080b
        PART(kps,IND,kp)=C1(kps)                                          D1100b
  12  continue                                                            D1101b
      PTID(IND,kp)=5                                                      D1105
      IND=IND+1                                                           D1110
      IF (NPTPND.EQ.1) GO TO 410                                          D1115
C        ---PLACE NORTH, SOUTH, EAST, AND WEST PARTICLES---               D1120
  160 IF (NPTPND.LT.8) GO TO 290                                          D1130
      IF(IONED.EQ.1) GO TO 290                                            D1132
      do 13 kps=1,nconc(kp)                                               D1133b
        CNODE(kps)=C1(kps)*(1.0-F2)                                       D1140b
  13  continue                                                            D1141b
      DO 280 IT=1,2                                                       D1150
      EVET=(-1.0)**IT                                                     D1160
      PARTxy(1,IND,kp)=JX+F2*EVET                                        SD1171b
      PARTxy(2,IND,kp)=-JY                                               SD1181b
      do 14 kps=1,nconc(kp)                                               D1170b
        PART(kps,IND,kp)=C1(kps)                                          D1190b
  14  continue                                                            D1191b
      IF (EVET.LT.0) PTID(IND,kp)=6                                       D1192b
      IF (EVET.GT.0) PTID(IND,kp)=8                                       D1194b
      IF (TEST(kp).LT.98.0.OR.TEST2.GT.0.0) GO TO 220                     D1200b
      IXD=IX+EVET                                                         D1210
      KR=KR+1                                                             D1220
      IPT(KR)=IND                                                         D1230
      kps=0                                                               D1231b
      do 15 ks=ks1,kslast                                                 D1232b
        kps=kps+1                                                         D1233b
        if(test3(kps).gt.0.0)go to 15                                     D1234b
      IF (METH(kps).EQ.2) GO TO 170                                       D1240b
      PART(kps,IND,kp)=CNODE(kps)+CONC(IXD,IY,ks)*F2                      D1250b
      GO TO 180                                                           D1260
  170 PART(kps,IND,kp)=2.0*C1(kps)*CONC(IXD,IY,ks)/(C1(kps)               D1261b
     &+CONC(IXD,IY,ks))                                                   D1270b
  180 IF (C1(kps)-CONC(IXD,IY,ks)) 190,200,210                            D1280b
  190 RP(kps,KR)=CONC(IXD,IY,ks)-PART(kps,IND,kp)                         D1290b
      RN(kps,KR)=C1(kps)-PART(kps,IND,kp)                                 D1300b
      GO TO 015                                                           D1310
  200 RP(kps,KR)=0.0                                                      D1320b
      RN(kps,KR)=0.0                                                      D1330b
      GO TO 015                                                           D1340
  210 RP(kps,KR)=C1(kps)-PART(kps,IND,kp)                                 D1350b
      RN(kps,KR)=CONC(IXD,IY,ks)-PART(kps,IND,kp)                         D1360b
  15  continue                                                            D1361b
  220 IND=IND+1                                                           D1370
      PARTxy(1,IND,kp)=JX                                                SD1381b
      PARTxy(2,IND,kp)=JY+F2*EVET                                        SD1391b
      PARTxy(2,IND,kp)=-PARTxy(2,IND,kp)                                  D1400b
      do 17 kps=1,nconc(kp)                                               D1401b
        PART(kps,IND,kp)=C1(kps)                                          D1410b
  17  continue                                                            D1411b
      IF (EVET.LT.0) PTID(IND,kp)=7                                       D1412b
      IF (EVET.GT.0) PTID(IND,kp)=9                                       D1414b
      IF (TEST(kp).LT.98.0.OR.TEST2.GT.0.0) GO TO 280                     D1420b
      IYD=IY+EVET                                                         D1430
      KR=KR+1                                                             D1440
      IPT(KR)=IND                                                         D1450
      kps=0                                                               D1451b
      do 18 ks=ks1,kslast                                                 D1452b
        kps=kps+1                                                         D1453b
        if(test3(kps).gt.0.0)go to 18                                     D1454b
      IF (METH(kps).EQ.2) GO TO 230                                       D1460b
      PART(kps,IND,kp)=CNODE(kps)+CONC(IX,IYD,ks)*F2                      D1470b
      GO TO 240                                                           D1480
  230 PART(kps,IND,kp)=2.0*C1(kps)*CONC(IX,IYD,ks)/(C1(kps)               D1481b
     &+CONC(IX,IYD,ks))                                                   D1490b
  240 IF (C1(kps)-CONC(IX,IYD,ks)) 250,260,270                            D1500b
  250 RP(kps,KR)=CONC(IX,IYD,ks)-PART(kps,IND,kp)                         D1510b
      RN(kps,KR)=C1(kps)-PART(kps,IND,kp)                                 D1520b
      GO TO 018                                                           D1530
  260 RP(kps,KR)=0.0                                                      D1540b
      RN(kps,KR)=0.0                                                      D1550b
      GO TO 018                                                           D1560
  270 RP(kps,KR)=C1(kps)-PART(kps,IND,kp)                                 D1570b
      RN(kps,KR)=CONC(IX,IYD,ks)-PART(kps,IND,kp)                         D1580b
  18  continue                                                            D1581b
  280 IND=IND+1                                                           D1590
C                                                                         D1600
  290 IF (TEST(kp).LT.98.0.OR.TEST2.GT.0.0) GO TO 410                     D1610b
      do 19 kps=1,nconc(kp)                                               D1611b
        if(test3(kps).gt.0.0)go to 19                                     D1612b
      SUMPT=0.0                                                           D1620
C        ---COMPUTE CONC. GRADIENT WITHIN CELL---                         D1630
      DO 300 KPT=1,NCHK                                                   D1640
      IK=IPT(KPT)                                                         D1650
  300 SUMPT=PART(kps,IK,kp)+SUMPT                                         D1660b
      CBAR=SUMPT/NCHK                                                     D1670
C        ---CHECK MASS BALANCE WITHIN CELL AND ADJUST PT. CONCS.---       D1680
      SUMPT=0.0                                                           D1690
      IF (CBAR-C1(kps)) 310,019,330                                       D1700b
  310 CRCT=1.0-(CBAR/C1(kps))                                             D1710b
      IF (METH(kps).EQ.1) CRCT=CBAR/C1(kps)                               D1720b
      DO 320 KPT=1,NCHK                                                   D1730
      IK=IPT(KPT)                                                         D1740
      PART(kps,IK,kp)=PART(kps,IK,kp)+RP(kps,KPT)*CRCT                    D1750b
  320 SUMPT=SUMPT+PART(kps,IK,kp)                                         D1760b
      CBARN=SUMPT/NCHK                                                    D1770
      GO TO 350                                                           D1780
  330 CRCT=1.0-(C1(kps)/CBAR)                                             D1790b
      IF (METH(kps).EQ.1) CRCT=C1(kps)/CBAR                               D1800b
      DO 340 KPT=1,NCHK                                                   D1810
      IK=IPT(KPT)                                                         D1820
      PART(kps,IK,kp)=PART(kps,IK,kp)+RN(kps,KPT)*CRCT                    D1830b
  340 SUMPT=SUMPT+PART(kps,IK,kp)                                         D1840b
      CBARN=SUMPT/NCHK                                                    D1850
  350 IF (CBARN.EQ.C1(kps)) GO TO 019                                     D1860b
C        ---CORRECT FOR OVERCOMPENSATION---                               D1870
      CRCT=C1(kps)/CBARN                                                  D1880b
      DO 380 KPT=1,NCHK                                                   D1890
      IK=IPT(KPT)                                                         D1900
      PART(kps,IK,kp)=PART(kps,IK,kp)*CRCT                                D1910b
C        ---CHECK CONSTRAINTS---                                          D1920
      IF (PART(kps,IK,kp)-C1(kps)) 360,380,370                            D1930b
  360 CLIM=C1(kps)-RP(kps,KPT)+RN(kps,KPT)                                D1940b
      IF (PART(kps,IK,kp).LT.CLIM) GO TO 390                              D1950b
      GO TO 380                                                           D1960
  370 CLIM=C1(kps)+RP(kps,KPT)-RN(kps,KPT)                                D1970b
      IF (PART(kps,IK,kp).GT.CLIM) GO TO 390                              D1980b
  380 CONTINUE                                                            D1990
      GO TO 019                                                           D2000
  390 TEST2=1.0                                                           D2010
      DO 400 KPT=1,NCHK                                                   D2020
      IK=IPT(KPT)                                                         D2030
  400 PART(kps,IK,kp)=C1(kps)                                             D2040b
c                                                                         D2041b
 19   continue                                                            D2042b
  410 CONTINUE                                                            D2050
      NP(kp)=IND-1                                                        D2061b
      IF (INT.EQ.0.and.kp.eq.npset) CALL CHMOT                            D2070b
C     ****************************************************************    D2080
      RETURN                                                              D2090
C     ****************************************************************    D2100
      END                                                                 D2110-
      SUBROUTINE VELO(kp)                                                 E  10b
      INCLUDE 'dims.inc'                                                  E  11b
      DOUBLE PRECISION DMIN1,DEXP,DLOG,DABS                               E  20
      DOUBLE PRECISION TMRX,VPRM,HI,HR,HC,HK,WT,REC,RECH,TIM,AOPT,TITLE   E  30
      DOUBLE PRECISION XDEL,YDEL,S,AREA,SUMT,RHO,PARAM,TEST,TOL,PINT,     E  40
     1                 HMIN,PYR,ANFCTR                                    E  42
      DOUBLE PRECISION RATE,SLEAK,DIV                                     E  50
      COMMON /PRMJ/ NTIM,NPMP,NPNT,NITP,N,NX,NY,NP(NPS),NREC,INT,NNX,     E  60b
     &              NNY,                                                  E  61b
     1              NUMOBS,NMOV,IMOV,NPMAX,ITMAX,NZCRIT,IPRNT,NPTPND,     E  71
     2              NPNTMV,NPNTVL,NPNTD,NPNCHV,NPDELC,ICHK,nsol,npop,     E  82b
     3              npset,nconc(NPS),imob(NPS)                            E  84b
      COMMON /HEDA/ THCK(NXD,NYD),TMWL(NOB,500),TMOBS(500)                E  86b
      COMMON /HEDB/ TMRX(NXD,NYD,2),VPRM(NXD,NYD),HI(NXD,NYD),            E  88b
     1              HR(NXD,NYD),HC(NXD,NYD),HK(NXD,NYD),WT(NXD,NYD),      E  90b
     2REC(NXD,NYD),RECH(NXD,NYD),TIM(500),AOPT(20),TITLE(010),XDEL,YDEL,  E  92b
     3              S,AREA,SUMT,RHO,PARAM,TEST(NPS),TOL,PINT,HMIN,PYR,    E  94b
     4              ANFCTR                                                E  96b
      COMMON /HEDC/ MX,MY,MMX,MMY,NMX,NMY,MCHK                            E  98b
      COMMON /CHMA/ PART(NPC,NPTS,NPS),CONC(NXC,NYC,NSL),                 E 100b 
     &              TMCN(NOB,500,NSL),                                    E 102b
     &              partxy(2,NPTS,NPS),                                   E 104b
     &              VX(NXD,NYD),tmz(NOB,500,NMC),                         E 106b
     1              VY(NXD,NYD),CONINT(NXC,NYC,NSL),CNRECH(NXC,NYC,NSL),  E 108b
     &              POROS,                                                E 110b
     2              SUMTCH,BETA,TIMV,STORM(NSL),STORMI(NSL),CMSIN(NSL),   E 112b
     &              CMSOUT(NSL),FLMIN(NSL),                               E 114b
     3              FLMOT(NSL),SUMIO(NSL),CELDIS,DLTRAT,CSTORM(NSL)       E 116b
      COMMON /CHMC/ SUMC(NXC,NYC,NSL),VXBDY(NXD,NYD),VYBDY(NXD,NYD)       E 118b
      COMMON /CHMR/ RF(NPS),DK(NPS),RHOB,THALF(NPS),DECAY(NPS),           E 120b
     &              ADSORB(NSL),degloss(NSL),deggain(NSL),                E 122b
     &              SORBI(NSL),DMASS1(NSL),CSTM2(NSL),                    E 124b
     1              EKF(NPS),XNF(NPS),XNFM1(NPS),FCTRF(NPS),EKL(NPS),     E 126b
     &              CEC(NPS),                                             E 128b
     &              EKLCEC(NPS),FCTRL(NPS),CINMAX(NPS),                   E 130b
     2              RF2MIN(NPS),RF2MAX(NPS),CZERO(NPS),IREACT(NPS),       E 132b
     &              EK(NPS),                                              E 134b
     &              EKCEC(NPS),FCTRE(NPS),CTOT(NPS),C3,C4(NPS),C5(NPS),   E 136b
     &              C6(NPS)                                               E 138b 
      COMMON /DIFUS/ DISP(NXC,NYC,4)                                      E 140b
C     ***************************************************************     E 210
C      DO NOT RECOMPUTE VELOCITY OR DISP.COEFS FOR STEADY-STATE FLOW      E 212
      ISOLV=1                                                             E 213
      IF (S.EQ.0.0.AND.ICHK.EQ.0.AND.(N.GT.1.OR.INT.GT.1)) THEN           E 214
       ISOLV=0                                                            E 215
       GO TO 28                                                           E 216
      END IF                                                              E 217
C     ---COMPUTE VELOCITIES AND STORE---                                  E 220
      VMAX=1.0E-10                                                        E 230
      VMAY=1.0E-10                                                        E 240
      VMXBD=1.0E-10                                                       E 250
      VMYBD=1.0E-10                                                       E 260
      TMV=TIM(N)*1.0E5                                                    E 275
      LIM=0                                                               E 280
      MAXX=0                                                              E 284
      MAXY=0                                                              E 285
      MAXVXI=0                                                            E 286
      MAXVXJ=0                                                            E 287
      MAXVYI=0                                                            E 288
      MAXVYJ=0                                                            E 289
C                                                                         E 290
      DO 20 IX=1,NX                                                       E 300
      DO 20 IY=1,NY                                                       E 310
      IF (IX.GT.NMX.OR.IY.GT.NMY) GO TO 12                               SE 315
      DO 10 IZ=1,4                                                        E 320
   10 DISP(IX,IY,IZ)=0.0                                                  E 330
C                                                                         E 340
   12 JCK=0                                                              SE 343
      IF (IX.LT.(MX-1).OR.IY.LT.(MY-1).OR.IX.GT.(MMX+1).OR.IY.GT.(MMY+1) SE 344
     1) JCK=1                                                            SE 345
      IF (THCK(IX,IY).EQ.0.0) GO TO 20                                    E 350
      RATE=REC(IX,IY)/AREA                                                E 360
      SLEAK=(HK(IX,IY)-WT(IX,IY))*VPRM(IX,IY)                             E 370
      DIV=0.D0                                                            E 381
      IF (RATE.LT.0.0) DIV=RATE                                           E 382
      IF (SLEAK.LT.0.0) DIV=DIV+SLEAK                                     E 383
      IF (RECH(IX,IY).LT.0.0) DIV=DIV+RECH(IX,IY)                         E 384
C                                                                         E 390
C        ---VELOCITIES AT CELL BOUNDARIES---                              E 580
C           TERM SAVED IS VELOCITY*THICKNESS*POROSITY                     E 582
      VXBDY(IX,IY)=TMRX(IX,IY,1)*(HK(IX,IY)-HK(IX+1,IY))                  E 585
      VYBDY(IX,IY)=TMRX(IX,IY,2)*(HK(IX,IY)-HK(IX,IY+1))                  E 595
C        ---VELOCITIES AT NODES---                                        E 605
C           TEMPORARILY SAVE SEEPAGE VELOCITY FOR PRINTING                E 607
      VX(IX,IY)=(0.5*(VXBDY(IX,IY)+VXBDY(IX-1,IY)))/THCK(IX,IY)           E 615
      VY(IX,IY)=(0.5*(VYBDY(IX,IY)+VYBDY(IX,IY-1)))/THCK(IX,IY)           E 625
      IF (JCK.EQ.0) THEN                                                 SE 645
       IF (THCK(IX+1,IY).NE.0.0.AND.THCK(IX+1,IY).LT.THCK(IX,IY)) THEN    E 646
        ABVX=ABS(VXBDY(IX,IY))/THCK(IX+1,IY)                              E 647
       ELSE                                                               E 648
        ABVX=ABS(VXBDY(IX,IY))/THCK(IX,IY)                                E 649
       END IF                                                             E 651
       IF (THCK(IX,IY+1).NE.0.0.AND.THCK(IX,IY+1).LT.THCK(IX,IY)) THEN    E 652
        ABVY=ABS(VYBDY(IX,IY))/THCK(IX,IY+1)                              E 653
       ELSE                                                               E 654
        ABVY=ABS(VYBDY(IX,IY))/THCK(IX,IY)                                E 655
       END IF                                                             E 656
       IF (ABVX.GT.VMXBD) THEN                                            E 672
         VMXBD=ABVX                                                       E 673
         MAXVXI=IX                                                        E 674
         MAXVXJ=IY                                                        E 675
       END IF                                                             E 676
       IF (ABVY.GT.VMYBD) THEN                                            E 682
         VMYBD=ABVY                                                       E 683
         MAXVYI=IX                                                        E 684
         MAXVYJ=IY                                                        E 685
       END IF                                                             E 686
      END IF                                                             SE 687
C                                                                         E 690
      IF (DIV.GE.0.0) GO TO 20                                            E 700
      IF (JCK.GT.0) GO TO 20                                             SE 705
      TDIV=THCK(IX,IY)/DABS(DIV)                                          E 712
      IF (TDIV.GE.TMV) GO TO 20                                           E 722
      TMV=TDIV                                                            E 724
      MAXX=IX                                                             E 725
      MAXY=IY                                                             E 726
   20 CONTINUE                                                            E 728
      TMV=TMV*RF(kp)*RF2MIN(kp)                                           E 729b
C      IF OUTPUT OF VELOCITIES ON CELL BOUNDARIES IS DESIRED,             E 731A
C       SEE LINES E 732, E 795A, E 839, E 909, E 986A, E1027A, AND E2399  E 731B
C      ACTIVATE NEXT 6 LINES TO COMPUTE BOUNDARY VELOCITIES FOR PRINTING  E 732
C     DO 25 IY=2,NNY                                                      E 733
C     DO 25 IX=2,NNX                                                      E 734
C     IF (THCK(IX,IY).EQ.0.0) GO TO 25                                    E 735
C     VXBDY(IX,IY)=VXBDY(IX,IY)/(THCK(IX,IY)+THCK(IX+1,IY))*2.            E 736
C     VYBDY(IX,IY)=VYBDY(IX,IY)/(THCK(IX,IY)+THCK(IX,IY+1))*2.            E 737
C  25 CONTINUE                                                            E 738
C     ***************************************************************     E 740
C     ---PRINT VELOCITIES---                                              E 750
   28 IF (NPNTVL.EQ.0) GO TO 80                                           E 761
      IF (NPNTVL.EQ.-2.AND.(N.EQ.NTIM.OR.IPRNT.EQ.1)) GO TO 30            E 771
      IF (NPNTVL.EQ.-1.AND.N.EQ.1) GO TO 30                               E 781
      IF (MOD(N,NPNTVL).EQ.0) GO TO 30                                    E 785
      GO TO 80                                                            E 790
   30 IF (ISOLV.EQ.0) THEN                                                E 792
       DO 32 IY=2,NNY                                                     E 793A
       DO 32 IX=2,NNX                                                     E 793B
       IF (THCK(IX,IY).EQ.0.0) GO TO 32                                   E 793C
       VX(IX,IY)=VX(IX,IY)/THCK(IX,IY)                                    E 794A
       VY(IX,IY)=VY(IX,IY)/THCK(IX,IY)                                    E 794B
C       ACTIVATE NEXT 2 LINES IF BOUNDARY VELOCITIES PRINTED              E 795A
C      VXBDY(IX,IY)=2.0*VXBDY(IX,IY)/(THCK(IX,IY)+THCK(IX+1,IY))          E 795B
C      VYBDY(IX,IY)=2.0*VYBDY(IX,IY)/(THCK(IX,IY)+THCK(IX,IY+1))          E 795C
   32  CONTINUE                                                           E 796
       ISOLV=-1                                                           E 797
      END IF                                                              E 798
      WRITE (6,320)                                                       E 801
      WRITE (6,330)                                                       E 810
      DO 40 IY=1,NY                                                       E 820
   40 WRITE (6,350) (VX(IX,IY),IX=1,NX)                                   E 830
C      ACTIVATE NEXT 3 LINES TO PRINT BOUNDARY VELOCITIES                 E 839
C     WRITE (6,340)                                                       E 840
C     DO 50 IY=1,NY                                                       E 850
C  50 WRITE (6,350) (VXBDY(IX,IY),IX=1,NX)                                E 860
      WRITE (6,360)                                                       E 870
      WRITE (6,330)                                                       E 880
      DO 60 IY=1,NY                                                       E 890
   60 WRITE (6,350) (VY(IX,IY),IX=1,NX)                                   E 900
C      ACTIVATE NEXT 3 LINES TO PRINT BOUNDARY VELOCITIES                 E 909
C     WRITE (6,340)                                                       E 910
C     DO 70 IY=1,NY                                                       E 920
C  70 WRITE (6,350) (VYBDY(IX,IY),IX=1,NX)                                E 930
C     ---WRITE VELOCITIES TO FILE UNIT 7---                               E 941
   80 IF (NPNCHV.EQ.0) GO TO 110                                          E 950
      IF (NPNCHV.EQ.-2.AND.(N.EQ.NTIM.OR.IPRNT.EQ.1)) GO TO 90            E 961
      IF (NPNCHV.EQ.-1.AND.N.EQ.1) GO TO 90                               E 971
      IF (MOD(N,NPNCHV).EQ.0) GO TO 90                                    E 975
      GO TO 110                                                           E 980
   90 IF (ISOLV.EQ.0) THEN                                                E 982
       DO 92 IY=2,NNY                                                     E 983A
       DO 92 IX=2,NNX                                                     E 983B
       IF (THCK(IX,IY).EQ.0.0) GO TO 92                                   E 984
       VX(IX,IY)=VX(IX,IY)/THCK(IX,IY)                                    E 985A
       VY(IX,IY)=VY(IX,IY)/THCK(IX,IY)                                    E 985B
C       ACTIVATE NEXT 2 LINES IF BOUNDARY VELOCITIES PRINTED              E 986A
C      VXBDY(IX,IY)=2.0*VXBDY(IX,IY)/(THCK(IX,IY)+THCK(IX+1,IY))          E 986B
C      VYBDY(IX,IY)=2.0*VYBDY(IX,IY)/(THCK(IX,IY)+THCK(IX,IY+1))          E 986C
   92  CONTINUE                                                           E 987
       ISOLV=-1                                                           E 988
      END IF                                                              E 989
      open(7,file='biovel.out',status='unknown')                          E
      WRITE (7,510) NX,NY,XDEL,YDEL,VMAX,VMAY                             E 991
      DO 100 IY=1,NY                                                      E1000
      WRITE (7,520) (VX(IX,IY),IX=1,NX)                                   E1010
  100 WRITE (7,520) (VY(IX,IY),IX=1,NX)                                   E1020
C      SAVE VELOCITY*THICKNESS*POROSITY                                   E1021
  110 IF (ISOLV.EQ.0) GO TO 240                                           E1022A
      DO 112 IY=2,NNY                                                     E1022B
      DO 112 IX=2,NNX                                                     E1023
      IF (THCK(IX,IY).EQ.0.0) GO TO 112                                   E1024
      VX(IX,IY)=VX(IX,IY)*THCK(IX,IY)                                     E1025
      VY(IX,IY)=VY(IX,IY)*THCK(IX,IY)                                     E1026
C      ACTIVATE NEXT 2 LINES IF BOUNDARY VELOCITIES PRINTED               E1027A
C     VXBDY(IX,IY)=VXBDY(IX,IY)*0.5*(THCK(IX,IY)+THCK(IX+1,IY))           E1027B
C     VYBDY(IX,IY)=VYBDY(IX,IY)*0.5*(THCK(IX,IY)+THCK(IX,IY+1))           E1027C
  112 CONTINUE                                                            E1028
      IF (ISOLV.NE.1) GO TO 240                                           E1029
C     ****************************************************************    E1030
C     ---COMPUTE NEXT TIME STEP---                                        E1040
      WRITE (6,390)                                                       E1051
      WRITE (6,410) VMXBD,VMYBD                                           E1070
      IF (IREACT(kp).LE.0) GO TO 115                                      E1072b
      VMXBD=VMXBD/(RF(kp)*RF2MIN(kp))                                     E1077b
      VMYBD=VMYBD/(RF(kp)*RF2MIN(kp))                                     E1078b
      WRITE (6,394) VMXBD,VMYBD                                           E1079R
  115 TDELXB=CELDIS*XDEL/VMXBD                                            E1082R
      TDELYB=CELDIS*YDEL/VMYBD                                            E1110
      ITCD=0                                                              E1111
      IF (TDELYB.LT.TDELXB) ITCD=1                                        E1112
      TIMV=AMIN1(TDELXB,TDELYB)                                           E1121
      IF (AMAX1(VMXBD,VMYBD).LE.1.0E-10) WRITE(6,570)                     E1126
      WRITE (6,310) TMV,TIMV                                              E1130
      IF (TMV.LT.TIMV) GO TO 120                                          E1140
      LIM=-1                                                              E1150
      GO TO 130                                                           E1160
  120 TIMV=TMV                                                            E1170
      LIM=1                                                               E1180
  130 NTIMV=TIM(N)/TIMV                                                   E1190
      NMOV=NTIMV+1                                                        E1200
      WRITE (6,420) TIMV,NTIMV,NMOV                                       E1210
      TIMV=TIM(N)/NMOV                                                    E1220
      WRITE (6,370) TIM(N)                                                E1230
      WRITE (6,380) TIMV                                                  E1240
C                                                                         E1250
      IF (BETA.EQ.0.0) GO TO 200                                          E1260
C     ****************************************************************    E1270
C     ---COMPUTE DISPERSION COEFFICIENTS---                               E1280
      ALPHA=BETA                                                          E1290
      ALNG=ALPHA                                                          E1300
      TRAN=DLTRAT*ALPHA                                                   E1310
      XX2=XDEL*XDEL                                                       E1320
      YY2=YDEL*YDEL                                                       E1330
      XY2=4.0*XDEL*YDEL                                                   E1340
      DO 150 IX=2,MMX                                                    SE1351
      DO 150 IY=2,MMY                                                    SE1361
      IF (THCK(IX,IY).EQ.0.0) GO TO 150                                   E1370
      JX=IX-MX+1                                                         SE1375
      JY=IY-MY+1                                                         SE1376
      IF (JX.LT.1.OR.JY.LT.1) GO TO 150                                  SE1377
      VXE=VXBDY(IX,IY)                                                    E1380
      VYS=VYBDY(IX,IY)                                                    E1390
      IF (THCK(IX+1,IY).EQ.0.0) GO TO 140                                 E1400
      IF ((IX+1).GT.MMX) GO TO 140                                       SE1405
C        ---FORWARD COEFFICIENTS: X-DIRECTION---                          E1410
      VYE=(VYBDY(IX,IY-1)+VYBDY(IX+1,IY-1)+VYS+VYBDY(IX+1,IY))/4.0        E1420
      VXE2=VXE*VXE                                                        E1430
      VYE2=VYE*VYE                                                        E1440
      VMGE=SQRT(VXE2+VYE2)                                                E1450
      IF (VMGE.LT.1.0E-20) GO TO 140                                      E1460
      DALN=ALNG*VMGE                                                      E1470
      DTRN=TRAN*VMGE                                                      E1480
      VMGE2=VMGE*VMGE                                                     E1490
C           ---XX COEFFICIENT---                                          E1500
      DISP(JX,JY,1)=(DALN*VXE2+DTRN*VYE2)/(VMGE2*XX2)                    SE1511
C           ---XY COEFFICIENT---                                          E1520
      IF ((IY-1).LT.MY.OR.(IY+1).GT.MMY) GO TO 140                       SE1525
      DISP(JX,JY,3)=(DALN-DTRN)*VXE*VYE/(VMGE2*XY2)                      SE1531
C        ---FORWARD COEFFICIENTS: Y-DIRECTION---                          E1540
  140 IF (THCK(IX,IY+1).EQ.0.0) GO TO 150                                 E1550
      IF ((IY+1).GT.MMY) GO TO 150                                       SE1555
      VXS=(VXBDY(IX-1,IY)+VXE+VXBDY(IX-1,IY+1)+VXBDY(IX,IY+1))/4.0        E1560
      VYS2=VYS*VYS                                                        E1570
      VXS2=VXS*VXS                                                        E1580
      VMGS=SQRT(VXS2+VYS2)                                                E1590
      IF (VMGS.LT.1.0E-20) GO TO 150                                      E1600
      DALN=ALNG*VMGS                                                      E1610
      DTRN=TRAN*VMGS                                                      E1620
      VMGS2=VMGS*VMGS                                                     E1630
C           ---YY COEFFICIENT---                                          E1640
      DISP(JX,JY,2)=(DALN*VYS2+DTRN*VXS2)/(VMGS2*YY2)                    SE1651
C           ---YX COEFFICIENT---                                          E1660
      IF ((IX-1).LT.MX.OR.(IX+1).GT.MMX) GO TO 150                       SE1665
      DISP(JX,JY,4)=(DALN-DTRN)*VXS*VYS/(VMGS2*XY2)                      SE1671
  150 CONTINUE                                                            E1680
C     ****************************************************************    E1690
C     ---ADJUST CROSS-PRODUCT TERMS FOR ZERO THICKNESS---                 E1700
      DO 160 IX=2,MMX                                                    SE1711
      DO 160 IY=2,MMY                                                    SE1721
      JX=IX-MX+1                                                         SE1725
      JY=IY-MY+1                                                         SE1726
      IF (JX.LT.1.OR.JY.LT.1) GO TO 160                                  SE1727
      IF (THCK(IX,IY+1).EQ.0.0.OR.THCK(IX+1,IY+1).EQ.0.0.OR.THCK(IX,IY-1  E1730
     1).EQ.0.0.OR.THCK(IX+1,IY-1).EQ.0.0) DISP(JX,JY,3)=0.0              SE1741
      IF (THCK(IX+1,IY).EQ.0.0.OR.THCK(IX+1,IY+1).EQ.0.0.OR.THCK(IX-1,IY  E1750
     1).EQ.0.0.OR.THCK(IX-1,IY+1).EQ.0.0) DISP(JX,JY,4)=0.0              SE1761
  160 CONTINUE                                                            E1770
C     ****************************************************************    E1780
C     ---CHECK FOR STABILITY OF EXPLICIT METHOD---                        E1790
      TIMDIS=0.0                                                          E1800
      DO 170 IX=1,NMX                                                    SE1811
      DO 170 IY=1,NMY                                                    SE1821
      JX=IX+MX-1                                                         SE1822
      JY=IY+MY-1                                                         SE1823
      IF (THCK(JX,JY).LE.0.0) GO TO 170                                  SE1824
      IF (IX.EQ.1) THEN                                                   E1825
       DISPX=DISP(IX,IY,1)                                                E1826
      ELSE                                                                E1827
       DISPX=AMAX1(DISP(IX,IY,1),DISP(IX-1,IY,1))                         E1828
      END IF                                                              E1832
      IF (IY.EQ.1) THEN                                                   E1833
       DISPY=DISP(IX,IY,2)                                                E1834
      ELSE                                                                E1835
       DISPY=AMAX1(DISP(IX,IY,2),DISP(IX,IY-1,2))                         E1836
      END IF                                                              E1837
      TDCO=(DISPX+DISPY)/THCK(JX,JY)                                     SE1838
      IF (TDCO.GT.TIMDIS) TIMDIS=TDCO                                     E1839
  170 CONTINUE                                                            E1841
      TIMDC=0.5*RF(kp)*RF2MIN(kp)/TIMDIS                                  E1852b
      WRITE (6,440) TIMDC                                                 E1860
      NTIMD=TIM(N)/TIMDC                                                  E1870
      NDISP=NTIMD+1                                                       E1880
      IF (NDISP.LE.NMOV) GO TO 180                                        E1890
      NMOV=NDISP                                                          E1900
      TIMV=TIM(N)/NMOV                                                    E1910
      LIM=0                                                               E1920
  180 WRITE (6,430) TIMV,NTIMD,NMOV                                       E1930
C     ****************************************************************    E2040
  200 IF (NMOV.EQ.1) GO TO 235                                            E2052
      IF (LIM) 210,220,230                                                E2054
  210 WRITE (6,530)                                                       E2060
      IF (ITCD.GT.0) THEN                                                 E2062
         MJ=MAXVYJ+1                                                      E2063
         WRITE (6,534) MAXVYI,MAXVYJ,MAXVYI,MJ                            E2064
       ELSE                                                               E2065
         MI=MAXVXI+1                                                      E2066
         WRITE (6,535) MAXVXI,MAXVXJ,MI,MAXVXJ                            E2067
      END IF                                                              E2068
      GO TO 240                                                           E2070
  220 WRITE (6,540)                                                       E2080
      GO TO 240                                                           E2090
  230 WRITE (6,550)                                                       E2100
      WRITE (6,560) MAXX,MAXY                                             E2102
      GO TO 240                                                           E2104
  235 WRITE (6,580)                                                       E2106
C     ****************************************************************    E2110
C     ---PRINT DISPERSION EQUATION COEFFICIENTS---                        E2120
  240 IF (NPNTD.EQ.0) GO TO 300                                           E2130
      IF (NPNTD.EQ.2) GO TO 250                                           E2140
      IF (NPNTD.EQ.1.AND.N.EQ.1) GO TO 250                                E2150
      GO TO 300                                                           E2160
  250 WRITE (6,450)                                                       E2170
      WRITE (6,460)                                                       E2180
      DO 260 IY=1,NMY                                                    SE2191
  260 WRITE (6,500) (DISP(IX,IY,1),IX=1,NMX)                             SE2201
      WRITE (6,470)                                                       E2210
      DO 270 IY=1,NMY                                                    SE2221
  270 WRITE (6,500) (DISP(IX,IY,2),IX=1,NMX)                             SE2231
      WRITE (6,480)                                                       E2240
      DO 280 IY=1,NMY                                                    SE2251
  280 WRITE (6,500) (DISP(IX,IY,3),IX=1,NMX)                             SE2261
      WRITE (6,490)                                                       E2270
      DO 290 IY=1,NMY                                                    SE2281
  290 WRITE (6,500) (DISP(IX,IY,4),IX=1,NMX)                             SE2291
C     ****************************************************************    E2300
  300 RETURN                                                              E2310
C     ****************************************************************    E2320
C                                                                         E2330
C                                                                         E2340
C                                                                         E2350
  310 FORMAT (1H0,19H TMV (MAX. INJ.) = ,G12.5/20H  TIMV (CELDIS)   = ,G  E2361R
     112.5)                                                               E2370
  320 FORMAT (1H1,12HX VELOCITIES)                                        E2380
  330 FORMAT (1H ,25X,8HAT NODES/)                                        E2390
C      ACTIVATE NEXT LINE IF BOUNDARY VELOCITIES PRINTED                  E2399
C 340 FORMAT (1H0,25X,41HON BOUNDARIES (USING INTERFACE THICKNESS)/)      E2401
  350 FORMAT (1H ,1P10E12.3)                                              E2411
  360 FORMAT (1H1,12HY VELOCITIES)                                        E2420
  370 FORMAT (3H   ,11HTIM (N)  = ,1G12.5)                                E2430
  380 FORMAT (3H   ,11HTIMEVELO = ,1G12.5)                                E2440
  390 FORMAT (1H1,10X,29HSTABILITY CRITERIA --- M.O.C.//)                 E2450
  394 FORMAT (1H0,5X,46HMAXIMUM EFFECTIVE SOLUTE VELOCITIES:  X-VEL = ,   E2453R
     1  1PE9.2,5X,8HY-VEL = ,1PE9.2)                                      E2454R
  410 FORMAT (1H0,5X,35HMAXIMUM FLUID VELOCITIES:  X-VEL = ,1PE9.2,5X,    E2471
     1  8HY-VEL = ,1PE9.2)                                                E2472
  420 FORMAT (1H0,8H TIMV = ,1PE9.2,5X,8HNTIMV = ,I5,5X,7HNMOV = ,I5/)    E2480
  430 FORMAT (1H0,8H TIMV = ,1PE9.2,5X,8HNTIMD = ,I5,5X,7HNMOV = ,I5)     E2490
  440 FORMAT (3H   ,11HTIMEDISP = ,1E12.5)                                E2500
  450 FORMAT (1H1,32HDISPERSION EQUATION COEFFICIENTS,10X,33H=(D-IJ)*(B)  E2511
     1*(POROS)/(GRID FACTOR))                                             E2521
  460 FORMAT (1H0,35X,14HXX COEFFICIENT/)                                 E2531
  470 FORMAT (1H0,35X,14HYY COEFFICIENT/)                                 E2541
  480 FORMAT (1H0,35X,14HXY COEFFICIENT/)                                 E2551
  490 FORMAT (1H0,35X,14HYX COEFFICIENT/)                                 E2561
  500 FORMAT (1H ,1P10E11.2)                                              E2571
  510 FORMAT (2I4,2F10.1,2F10.7)                                          E2580
  520 FORMAT (8F10.7)                                                     E2590
  530 FORMAT (1H0,10X,42HTHE LIMITING STABILITY CRITERION IS CELDIS)      E2600
  534 FORMAT (1H ,4X,52HMAX. Y-VEL. IS CONSTRAINT AND OCCURS BETWEEN NOD  E2602
     1ES (,I4,1H,,I4,7H) AND (,I4,1H,,I4,1H))                             E2603b
  535 FORMAT (1H ,4X,52HMAX. X-VEL. IS CONSTRAINT AND OCCURS BETWEEN NOD  E2604
     1ES (,I4,1H,,I4,7H) AND (,I4,1H,,I4,1H))                             E2605b
  540 FORMAT (1H0,10X,40HTHE LIMITING STABILITY CRITERION IS BETA)        E2610
  550 FORMAT (1H0,10X,58HTHE LIMITING STABILITY CRITERION IS MAXIMUM INJ  E2620
     1ECTION RATE)                                                        E2630
  560 FORMAT (1H ,15X,35HMAX. INJECTION OCCURS AT CELL IX = ,I4,7H  IY =  E2635b
     1 ,I4)                                                               E2636b
  570 FORMAT (1H0,5X,47H*** WARNING ***  DECREASE CRITERIA IN E 230-260)  E2637
  580 FORMAT (1H0,10X,63H*TIME INCREMENT FOR SOLUTE TRANSPORT EQUALS TIM  E2638
     1E STEP FOR FLOW*)                                                   E2639
      END                                                                 E2640-
      SUBROUTINE MOVE                                                     F  10
      INCLUDE 'dims.inc'                                                  F  11b
      DOUBLE PRECISION TMRX,VPRM,HI,HR,HC,HK,WT,REC,RECH,TIM,AOPT,TITLE   F  20
      DOUBLE PRECISION XDEL,YDEL,S,AREA,SUMT,RHO,PARAM,TEST,TOL,PINT,     F  30
     1                 HMIN,PYR,ANFCTR                                    F  31A
      DOUBLE PRECISION DXINV,DYINV,ARINV,PORINV                           F  32
      DOUBLE PRECISION DCYFCT(NPS),DCYT(NPS),DCYT2(NPS)                   F  33b
      double precision bioloss,biogain,up,uptake                          F  34b
      real ncinhib                                                        F  35b
      INTEGER PTID                                                        F  36
      COMMON /PRMJ/ NTIM,NPMP,NPNT,NITP,N,NX,NY,NP(NPS),NREC,INT,NNX,     F  37b
     &              NNY,                                                  F  41b
     1              NUMOBS,NMOV,IMOV,NPMAX,ITMAX,NZCRIT,IPRNT,NPTPND,     F  51
     2              NPNTMV,NPNTVL,NPNTD,NPNCHV,NPDELC,ICHK,nsol,npop,     F  62b
     3              npset,nconc(NPS),imob(NPS)                            F  63b
      COMMON /PRMC/ NODEID(NXD,NYD),NPCELL(NXC,NYC,NPS),                  F  64b
     &              NPOLD(NXC,NYC,NPS),                                   F  66b
     1              LIMBO(1000,NPS),IXOBS(NOB),IYOBS(NOB)                 F  68b
      COMMON /HEDA/ THCK(NXD,NYD),TMWL(NOB,500),TMOBS(500)                F  70b
      COMMON /HEDB/ TMRX(NXD,NYD,2),VPRM(NXD,NYD),HI(NXD,NYD),            F  72b
     1              HR(NXD,NYD),HC(NXD,NYD),HK(NXD,NYD),WT(NXD,NYD),      F  74b
     2REC(NXD,NYD),RECH(NXD,NYD),TIM(500),AOPT(20),TITLE(010),XDEL,YDEL,  F  76b
     3              S,AREA,SUMT,RHO,PARAM,TEST(NPS),TOL,PINT,HMIN,PYR,    F  78b
     4              ANFCTR                                                F  80b
      COMMON /HEDC/ MX,MY,MMX,MMY,NMX,NMY,MCHK                            F  82b
      COMMON /XINV/ DXINV,DYINV,ARINV,PORINV                              F  84b
      COMMON /CHMA/ PART(NPC,NPTS,NPS),CONC(NXC,NYC,NSL),                 F  86b
     &              TMCN(NOB,500,NSL),                                    F  88b
     &              partxy(2,NPTS,NPS),                                   F  90b
     &              VX(NXD,NYD),tmz(NOB,500,NMC),                         F  92b
     1              VY(NXD,NYD),CONINT(NXC,NYC,NSL),CNRECH(NXC,NYC,NSL),  F  94b
     &              POROS,                                                F  96b
     2              SUMTCH,BETA,TIMV,STORM(NSL),STORMI(NSL),CMSIN(NSL),   F  98b
     &              CMSOUT(NSL),FLMIN(NSL),                               F 100b
     3              FLMOT(NSL),SUMIO(NSL),CELDIS,DLTRAT,CSTORM(NSL)       F 102b
      COMMON /CHMC/ SUMC(NXC,NYC,NSL),VXBDY(NXD,NYD),VYBDY(NXD,NYD)       F 104b
      COMMON /CHMP/ PTID(NPTS,NPS)                                        F 106b
      COMMON /CHMR/ RF(NPS),DK(NPS),RHOB,THALF(NPS),DECAY(NPS),           F 108b
     &              ADSORB(NSL),degloss(NSL),deggain(NSL),                F 110b
     &              SORBI(NSL),DMASS1(NSL),CSTM2(NSL),                    F 112b
     1              EKF(NPS),XNF(NPS),XNFM1(NPS),FCTRF(NPS),EKL(NPS),     F 114b
     &              CEC(NPS),                                             F 116b
     &              EKLCEC(NPS),FCTRL(NPS),CINMAX(NPS),                   F 118b
     2              RF2MIN(NPS),RF2MAX(NPS),CZERO(NPS),IREACT(NPS),       F 120b
     &              EK(NPS),                                              F 122b
     &              EKCEC(NPS),FCTRE(NPS),CTOT(NPS),C3,C4(NPS),C5(NPS),   F 124b
     &              C6(NPS)                                               F 126b
      COMMON /CHMR2/ CRETRD(NXC,NYC,NSL),CRDCOF(NXC,NYC,NSL),             F 128b
     &              CELDCY(NXC,NYC,NSL)                                   F 130b
      common /inbio/ ibio,nproc,nsproc(NPR),iz(NPR),nzinhib,ncomp(NPR),   F 132b
     &               nnc(NPR),nhal(NPR),kscomp(NPR,NMC),ksnc(NPR,NMC),    F 134b
     &               kshal(NPR,NMC),ksproc(NPR,NSL),numnut,ksnut(NSL)     F 136b
      common /rbio/  z(NXC,NYC,NMC),vmax(NPR),                            F 138b
     &               yield(NPR),                                          F 140b
     &               upcoef(NPR,NSL),hfk(NPR,NSL),faccomp(NPR,NMC),       F 142b
     &               facnc(NPR,NMC),                                      F 144b
     &               fachal(NPR,NMC),death(NMC),yieldnut(NSL),            F 146b
     &               compinhib(NPR),ncinhib(NPR),                         F 148b
     &               zinhibfac(NMC),                                      F 150b
     &               halinhib(NPR),grow(NMC),zinit(NXC,NYC,NMC),          F 152b
     &               hfknut(NSL),relcoef(NSL),zinhib(NMC)                 F 154b
      common /dbio/  bioloss(NXC,NYC,NSL), biogain(NXC,NYC,NSL),          F
     &               up(NPR), uptake(NPR,NSL)                             F
      COMMON /CHMB1/CNCNC(NXC,NYC,NSL),CNOLD(NXC,NYC,NSL),                F 156b
     &               CAVG(NXC,NYC,NSL)                                    F 158b
      dimension const1(NPS),const2(NPS)                                   F 160b
C     ***************************************************************     F 190
      WRITE (6,680) NMOV                                                  F 200
      SUMTCH=SUMT-TIM(N)                                                  F 210
      IONED=0                                                             F 211A
      IF(NX.EQ.3.OR.NY.EQ.3) IONED=1                                      F 211B
      F1=0.30                                                             F 212
      F2=1.0/3.0                                                          F 214
      IF (NPTPND.EQ.4) F1=0.25                                            F 216
      IF (NPTPND.EQ.5.AND.IONED.EQ.1) F1=0.25                             F 217
      IF (NPTPND.EQ.9) F1=F2                                              F 218
      IF (NPTPND.EQ.8.AND.IONED.NE.1) F2=0.25                             F 222A
      IF (NPTPND.EQ.8.AND.IONED.EQ.1) F1=F2                               F 222B
      IF (NPTPND.EQ.16) F1=0.25                                           F 223
      IF (NPTPND.EQ.16) F2=0.125                                          F 224
c                                                                         F 225b
      ks=0                                                                F 226b
      do 8 kp=1,npset                                                     F 227b
      do 8 kps=1,nconc(kp)                                                F 228b
        ks=ks+1                                                           F 229b
      IF (THALF(kp).GT.0.0.AND.THALF(kp).LT.TIMV) WRITE (6,685)           F 205b
      CONST1(kp)=TIMV*DXINV/RF(kp)                                        F 251b
      CONST2(kp)=TIMV*DYINV/RF(kp)                                        F 261b
      if(imob(kp).gt.0)then                                               F 262b
        const1(kp)=0.0                                                    F 263b
        const2(kp)=0.0                                                    F 264b
      end if                                                              F 265b
      DCYFCT(kp)=TIMV*DECAY(kp)                                           F 266b
      DCYT(kp)=1.D0                                                       F 268a
      DCYT2(kp)=1.D0                                                      F 268b
      IF(DECAY(kp).NE.0.0) THEN                                           F 268c
       DCYT(kp)=DEXP(-DCYFCT(kp))                                         F 268d
       DCYT2(kp)=DEXP(-DCYFCT(kp)*0.5D0)                                  F 268e
      END IF                                                              F 268F
      DO 8 IY=1,NMY                                                       F 269A
      JY=IY+MY-1                                                         SF 269B
      DO 8 IX=1,NMX                                                       F 269C
      JX=IX+MX-1                                                         SF 269D
      CRETRD(IX,IY,ks)=1.0                                                F 269e
      CRDCOF(IX,IY,ks)=1.0                                                F 269f
      CELDCY(IX,IY,ks)=1.0                                                F 269g
      IF (IREACT(kp).LE.1.OR.THCK(JX,JY).EQ.0.0) GO TO 8                 SF 269h
      CALL RETRD2(CONC(IX,IY,ks),CRETRD(IX,IY,ks),CRDCOF(IX,IY,ks),kp)    F 269i
      IF (DECAY(kp).NE.0.0)                                               F 269j
     1    CELDCY(IX,IY,ks)=EXP(-DCYFCT(kp)*CRDCOF(IX,IY,ks)/              F 270b
     &    CRETRD(IX,IY,ks))                                               F 269k
    8 CONTINUE                                                            F 269l
C     ---MOVE PARTICLES 'NMOV' TIMES---                                   F 270
      DO 650 IMOV=1,NMOV                                                  F 280
      kstart=0                                                            F 281
      do 625 kp=1,npset                                                   F 282
   10 NPTM=NP(kp)                                                         F 290b
C        ---MOVE EACH PARTICLE---                                         F 300
      DO 590 IN=1,NP(kp)                                                  F 310b
      IF (PARTxy(1,IN,kp).EQ.0.0) GO TO 590                               F 320b
      KFLAG=0                                                             F 330
      NLOC=0                                                             SF 335
C     ***************************************************************     F 340
C           ---COMPUTE OLD LOCATION---                                    F 350
   20 XOLD=PARTxy(1,IN,kp)                                                F 400b
      IX=XOLD+0.5                                                         F 410
      JX=IX-MX+1                                                         SF 415
      IFLAG=1                                                             F 420
      IF (PARTxy(2,IN,kp).GE.0.0) GO TO 30                                F 430b
      IFLAG=-1                                                            F 440
      PARTxy(2,IN,kp)=-PARTxy(2,IN,kp)                                    F 450b
   30 YOLD=PARTxy(2,IN,kp)                                                F 460b
      IY=YOLD+0.5                                                         F 470
      JY=IY-MY+1                                                         SF 475
      IF (THCK(IX,IY).EQ.0.0) GO TO 590                                   F 482
C     ***************************************************************     F 490
C           ---COMPUTE NEW LOCATION AND LOCATE CLOSEST NODE---            F 500
C           ---LOCATE NORTHWEST CORNER---                                 F 510
      IVX=XOLD                                                            F 520
      IVY=YOLD                                                            F 530
      IXE=IVX+1                                                           F 540
      IYS=IVY+1                                                           F 550
C     ***************************************************************     F 560
C        ---LOCATE QUADRANT, VEL. AT 4 CORNERS, CHECK FOR BOUNDARIES---   F 570
      CELDX=XOLD-IX                                                       F 580
      CELDY=YOLD-IY                                                       F 590
      ICD=9                                                               F 595
      IF (CELDX.EQ.0.0.AND.CELDY.EQ.0.0) GO TO 280                        F 600
      IF (CELDX.GE.0.0.OR.CELDY.GE.0.0) GO TO 70                          F 610
C              ---PT. IN NW QUADRANT---                                   F 620
      VXNW=VXBDY(IVX,IVY)                                                 F 630
      VXNE=VX(IXE,IVY)                                                    F 640
      VXSW=VXBDY(IVX,IYS)                                                 F 650
      VXSE=VX(IXE,IYS)                                                    F 660
      VYNW=VYBDY(IVX,IVY)                                                 F 670
      VYNE=VYBDY(IXE,IVY)                                                 F 680
      VYSW=VY(IVX,IYS)                                                    F 690
      VYSE=VY(IXE,IYS)                                                    F 700
      ICD=1                                                               F 705
      IF (THCK(IVX,IVY).EQ.0.0) GO TO 50                                  F 710
      IF (REC(IXE,IVY).EQ.0.0.AND.VPRM(IXE,IVY).LT.0.09) GO TO 40         F 720
      IF (THCK(IXE+1,IVY).NE.0.0) VXNE=VXNW                               F 731
   40 IF (REC(IVX,IYS).EQ.0.0.AND.VPRM(IVX,IYS).LT.0.09) GO TO 50         F 740
      IF (THCK(IVX,IYS+1).NE.0.0) VYSW=VYNW                               F 751
   50 IF (REC(IXE,IYS).EQ.0.0.AND.VPRM(IXE,IYS).LT.0.09) GO TO 270        F 760
      IF (THCK(IVX,IYS).EQ.0.0) GO TO 60                                  F 770
      IF (THCK(IXE+1,IYS).GT.0.0) VXSE=VXSW                               F 782
   60 IF (THCK(IXE,IVY).EQ.0.0) GO TO 270                                 F 790
      IF (THCK(IXE,IYS+1).GT.0.0) VYSE=VYNE                               F 802
      GO TO 270                                                           F 810
C                                                                         F 820
   70 IF (CELDX.LE.0.0.OR.CELDY.GE.0.0) GO TO 130                         F 830
C              ---PT. IN NE QUADRANT---                                   F 840
   80 VXNW=VX(IVX,IVY)                                                    F 850
      VXNE=VXBDY(IVX,IVY)                                                 F 860
      VXSW=VX(IVX,IYS)                                                    F 870
      VXSE=VXBDY(IVX,IYS)                                                 F 880
      VYNW=VYBDY(IVX,IVY)                                                 F 890
      VYNE=VYBDY(IXE,IVY)                                                 F 900
      VYSW=VY(IVX,IYS)                                                    F 910
      VYSE=VY(IXE,IYS)                                                    F 920
      ICD=2                                                               F 925
      IF (CELDX.EQ.0.0) GO TO 120                                         F 930
      IF (THCK(IXE,IVY).EQ.0.0) GO TO 100                                 F 940
      IF (REC(IVX,IVY).EQ.0.0.AND.VPRM(IVX,IVY).LT.0.09) GO TO 90         F 950
      IF (THCK(IVX-1,IVY).NE.0.0) VXNW=VXNE                               F 961
   90 IF (REC(IXE,IYS).EQ.0.0.AND.VPRM(IXE,IYS).LT.0.09) GO TO 100        F 970
      IF (THCK(IXE,IYS+1).NE.0.0) VYSE=VYNE                               F 981
  100 IF (REC(IVX,IYS).EQ.0.0.AND.VPRM(IVX,IYS).LT.0.09) GO TO 270        F 990
      IF (THCK(IXE,IYS).EQ.0.0) GO TO 110                                 F1000
      IF (THCK(IVX-1,IYS).GT.0.0) VXSW=VXSE                               F1012
  110 IF (THCK(IVX,IVY).EQ.0.0) GO TO 270                                 F1020
      IF (THCK(IVX,IYS+1).GT.0.0) VYSW=VYNW                               F1032
      GO TO 270                                                           F1040
  120 IF (REC(IVX,IYS).EQ.0.0.AND.VPRM(IVX,IYS).LE.0.09) GO TO 270        F1050
      IF (THCK(IVX,IVY).EQ.0.0) GO TO 270                                 F1060
      IF (THCK(IVX,IYS+1).GT.0.0) VYSW=VYNW                               F1072
      GO TO 270                                                           F1080
C                                                                         F1090
  130 IF (CELDY.LE.0.0.OR.CELDX.GE.0.0) GO TO 190                         F1100
C              ---PT. IN SW QUADRANT---                                   F1110
  140 VXNW=VXBDY(IVX,IVY)                                                 F1120
      VXNE=VX(IXE,IVY)                                                    F1130
      VXSW=VXBDY(IVX,IYS)                                                 F1140
      VXSE=VX(IXE,IYS)                                                    F1150
      VYNW=VY(IVX,IVY)                                                    F1160
      VYNE=VY(IXE,IVY)                                                    F1170
      VYSW=VYBDY(IVX,IVY)                                                 F1180
      VYSE=VYBDY(IXE,IVY)                                                 F1190
      ICD=3                                                               F1195
      IF (CELDY.EQ.0.0) GO TO 180                                         F1200
      IF (THCK(IVX,IYS).EQ.0.0) GO TO 160                                 F1210
      IF (REC(IVX,IVY).EQ.0.0.AND.VPRM(IVX,IVY).LT.0.09) GO TO 150        F1220
      IF (THCK(IVX,IVY-1).NE.0.0) VYNW=VYSW                               F1231
  150 IF (REC(IXE,IYS).EQ.0.0.AND.VPRM(IXE,IYS).LT.0.09) GO TO 160        F1240
      IF (THCK(IXE+1,IYS).NE.0.0) VXSE=VXSW                               F1251
  160 IF (REC(IXE,IVY).EQ.0.0.AND.VPRM(IXE,IVY).LT.0.09) GO TO 270        F1260
      IF (THCK(IVX,IVY).EQ.0.0) GO TO 170                                 F1270
      IF (THCK(IXE+1,IVY).GT.0.0) VXNE=VXNW                               F1282
  170 IF (THCK(IXE,IYS).EQ.0.0) GO TO 270                                 F1290
      IF (THCK(IXE,IVY-1).GT.0.0) VYNE=VYSE                               F1302
      GO TO 270                                                           F1310
  180 IF (REC(IXE,IVY).EQ.0.0.AND.VPRM(IXE,IVY).LE.0.09) GO TO 270        F1320
      IF (THCK(IVX,IVY).EQ.0.0) GO TO 270                                 F1330
      IF (THCK(IXE+1,IVY).GT.0.0) VXNE=VXNW                               F1342
      GO TO 270                                                           F1350
C                                                                         F1360
  190 IF (CELDY.LE.0.0.OR.CELDX.LE.0.0) GO TO 260                         F1370
C              ---PT. IN SE QUADRANT---                                   F1380
  200 VXNW=VX(IVX,IVY)                                                    F1390
      VXNE=VXBDY(IVX,IVY)                                                 F1400
      VXSW=VX(IVX,IYS)                                                    F1410
      VXSE=VXBDY(IVX,IYS)                                                 F1420
      VYNW=VY(IVX,IVY)                                                    F1430
      VYNE=VY(IXE,IVY)                                                    F1440
      VYSW=VYBDY(IVX,IVY)                                                 F1450
      VYSE=VYBDY(IXE,IVY)                                                 F1460
      ICD=4                                                               F1465
      IF (CELDY.EQ.0.0) GO TO 240                                         F1470
      IF (CELDX.EQ.0.0) GO TO 250                                         F1480
      IF (THCK(IXE,IYS).EQ.0.0) GO TO 220                                 F1490
      IF (REC(IXE,IVY).EQ.0.0.AND.VPRM(IXE,IVY).LT.0.09) GO TO 210        F1500
      IF (THCK(IXE,IVY-1).NE.0.0) VYNE=VYSE                               F1511
  210 IF (REC(IVX,IYS).EQ.0.0.AND.VPRM(IVX,IYS).LT.0.09) GO TO 220        F1520
      IF (THCK(IVX-1,IYS).NE.0.0) VXSW=VXSE                               F1531
  220 IF (REC(IVX,IVY).EQ.0.0.AND.VPRM(IVX,IVY).LT.0.09) GO TO 270        F1540
      IF (THCK(IXE,IVY).EQ.0.0) GO TO 230                                 F1550
      IF (THCK(IVX-1,IVY).GT.0.0) VXNW=VXNE                               F1562
  230 IF (THCK(IVX,IYS).EQ.0.0) GO TO 270                                 F1570
      IF (THCK(IVX,IVY-1).GT.0.0) VYNW=VYSW                               F1582
      GO TO 270                                                           F1590
  240 IF (REC(IVX,IVY).EQ.0.0.AND.VPRM(IVX,IVY).LE.0.09) GO TO 270        F1600
      IF (THCK(IXE,IVY).EQ.0.0) GO TO 270                                 F1610
      IF (THCK(IVX-1,IVY).GT.0.0) VXNW=VXNE                               F1622
      GO TO 270                                                           F1630
  250 IF (REC(IVX,IVY).EQ.0.0.AND.VPRM(IVX,IVY).LE.0.09) GO TO 270        F1640
      IF (THCK(IVX,IYS).EQ.0.0) GO TO 270                                 F1650
      IF (THCK(IVX,IVY-1).GT.0.0) VYNW=VYSW                               F1662
      GO TO 270                                                           F1670
C                                                                         F1680
  260 IF (CELDX.EQ.0.0.AND.CELDY.LT.0.0) GO TO 80                         F1690
      IF (CELDX.LT.0.0.AND.CELDY.EQ.0.0) GO TO 140                        F1700
      IF (CELDX.GT.0.0.AND.CELDY.EQ.0.0) GO TO 200                        F1710
      IF (CELDX.EQ.0.0.AND.CELDY.GT.0.0) GO TO 200                        F1720
      WRITE (6,690) IN,IX,IY                                              F1730
  270 CONTINUE                                                            F1740
C              --- CHECK FOR ADJACENT NO-FLOW BOUNDARIES---               F1741A
      GO TO (1270,1275,1280,1285,1290) ICD                                F1741B
      GO TO 1290                                                          F1741C
 1270 IF (THCK(IXE,IVY).EQ.0.0) GO TO 1272                                F1742A
      IF (THCK(IVX,IYS).EQ.0.0) GO TO 1273                                F1742B
      IF (THCK(IVX,IVY).EQ.0.0) GO TO 1274                                F1742C
      GO TO 1290                                                          F1742D
 1272 VXNE=VXSE                                                           F1742E
      IF (THCK(IVX,IYS).GT.0.0) GO TO 1274                                F1742F
 1273 VYSW=VYSE                                                           F1742G
 1274 VXNW=VXSW                                                           F1742H
      VYNW=VYNE                                                           F1742I
      GO TO 1290                                                          F1742J
 1275 IF (THCK(IVX,IVY).EQ.0.0) GO TO 1277                                F1744A
      IF (THCK(IXE,IYS).EQ.0.0) GO TO 1278                                F1744B
      IF (THCK(IXE,IVY).EQ.0.0) GO TO 1279                                F1744C
      GO TO 1290                                                          F1744D
 1277 VXNW=VXSW                                                           F1744E
      IF (THCK(IXE,IYS).GT.0.0) GO TO 1279                                F1744F
 1278 VYSE=VYSW                                                           F1744G
 1279 VXNE=VXSE                                                           F1744H
      VYNE=VYNW                                                           F1744I
      GO TO 1290                                                          F1744J
 1280 IF (THCK(IXE,IYS).EQ.0.0) GO TO 1282                                F1746A
      IF (THCK(IVX,IVY).EQ.0.0) GO TO 1283                                F1746B
      IF (THCK(IVX,IYS).EQ.0.0) GO TO 1284                                F1746C
      GO TO 1290                                                          F1746D
 1282 VXSE=VXNE                                                           F1746E
      IF (THCK(IVX,IVY).GT.0.0) GO TO 1284                                F1746F
 1283 VYNW=VYNE                                                           F1746G
 1284 VXSW=VXNW                                                           F1746H
      VYSW=VYSE                                                           F1746I
      GO TO 1290                                                          F1746J
 1285 IF (THCK(IVX,IYS).EQ.0.0) GO TO 1287                                F1748A
      IF (THCK(IXE,IVY).EQ.0.0) GO TO 1288                                F1748B
      IF (THCK(IXE,IYS).EQ.0.0) GO TO 1289                                F1748C
      GO TO 1290                                                          F1748D
 1287 VXSW=VXNW                                                           F1748E
      IF (THCK(IXE,IVY).GT.0.0) GO TO 1289                                F1748F
 1288 VYNE=VYNW                                                           F1748G
 1289 VYSE=VYSW                                                           F1748H
      VXSE=VXNE                                                           F1748I
 1290 CONTINUE                                                            F1749A
C     ****************************************************************    F1750
C        ---BILINEAR INTERPOLATION---                                     F1760
      CELXD=XOLD-IVX                                                      F1770
      CELDXH=AMOD(CELXD,0.5)                                              F1780
      CELDX=CELDXH*2.0                                                    F1790
      CELDY=YOLD-IVY                                                      F1800
C     ****************************************************************    F1810
C           ---X VELOCITY---                                              F1820
      VXN=VXNW*(1.0-CELDX)+VXNE*CELDX                                     F1830
      VXS=VXSW*(1.0-CELDX)+VXSE*CELDX                                     F1850
      XVEL=(VXN*(1.0-CELDY)+VXS*CELDY)/THCK(IX,IY)                        F1871
C           ---Y VELOCITY---                                              F1900
      CELDYH=AMOD(CELDY,0.5)                                              F1910
      CELYD=CELDYH*2.0                                                    F1921
      VYW=VYNW*(1.0-CELYD)+VYSW*CELYD                                     F1931
      VYE=VYNE*(1.0-CELYD)+VYSE*CELYD                                     F1951
      YVEL=(VYW*(1.0-CELXD)+VYE*CELXD)/THCK(IX,IY)                        F1971
C                                                                         F2000
      GO TO 290                                                           F2010
  280 XVEL=VX(IX,IY)/THCK(IX,IY)                                          F2021
      YVEL=VY(IX,IY)/THCK(IX,IY)                                          F2031
  290 DISTX=XVEL*CONST1(kp)                                               F2040b
      DISTY=YVEL*CONST2(kp)                                               F2050b
      IF (IREACT(kp).GE.2) THEN                                           F2051b
       ks=1                                                               F2052b
       do 291 lp=1,kp-1                                                   F2053b
         ks=ks+nconc(lp)                                                  F2054b
  291  continue                                                           F2055b
       RF2INV=1.0/CRETRD(JX,JY,ks)                                        SF2056b
       DISTX=DISTX*RF2INV                                                 F2054R
       DISTY=DISTY*RF2INV                                                 F2055R
      ENDIF                                                               F2056R
C     ****************************************************************    F2060
C        ---BOUNDARY CONDITIONS---                                        F2070
      TEMPX=XOLD+DISTX                                                    F2080
      TEMPY=YOLD+DISTY                                                    F2090
      INX=TEMPX+0.5                                                       F2100
      INY=TEMPY+0.5                                                       F2110
      IF (THCK(INX,INY).GT.0.0) GO TO 330                                 F2120
C     ****************************************************************    F2130
C           ---X BOUNDARY---                                              F2140
      IF (THCK(INX,IY).EQ.0.0) GO TO 300                                  F2150
      PARTxy(1,IN,kp)=TEMPX                                               F2160b
      GO TO 310                                                           F2170
  300 BEYON=TEMPX-IX                                                      F2180
      IF (BEYON.LT.0.0) BEYON=BEYON+0.5                                   F2190
      IF (BEYON.GT.0.0) BEYON=BEYON-0.5                                   F2200
      PARTxy(1,IN,kp)=TEMPX-2.0*BEYON                                     F2210b
      INX=PARTxy(1,IN,kp)+0.5                                             F2220b
      TEMPX=PARTxy(1,IN,kp)                                               F2230b
C     ****************************************************************    F2240
C           ---Y BOUNDARY---                                              F2250
  310 IF (THCK(INX,INY).EQ.0.0) GO TO 320                                 F2260
      PARTxy(2,IN,kp)=TEMPY                                               F2270b
      GO TO 340                                                           F2280
C     ****************************************************************    F2290
  320 BEYON=TEMPY-IY                                                      F2300
      IF (BEYON.LT.0.0) BEYON=BEYON+0.5                                   F2310
      IF (BEYON.GT.0.0) BEYON=BEYON-0.5                                   F2320
      PARTxy(2,IN,kp)=TEMPY-2.0*BEYON                                     F2330b
      INY=PARTxy(2,IN,kp)+0.5                                             F2340b
      TEMPY=PARTxy(2,IN,kp)                                               F2350b
      GO TO 340                                                           F2360
  330 PARTxy(1,IN,kp)=TEMPX                                               F2370b
      PARTxy(2,IN,kp)=TEMPY                                               F2380b
  340 CONTINUE                                                            F2390
      JNX=INX-MX+1                                                       SF2395
      JNY=INY-MY+1                                                       SF2396
      IF (MCHK.EQ.0) GO TO 342                                           SF2397
      IF (JNX.LT.1.OR.JNX.GT.NMX.OR.JNY.LT.1.OR.JNY.GT.NMY) NLOC=1       SF2398
C     ***************************************************************     F2400
      IF (NLOC.GT.0) GO TO 345                                           SF2405
  342 CONTINUE                                                           SF2407
C        ---SUM CONCENTRATIONS AND COUNT PARTICLES---                     F2410
C           ---DECAY PARTICLES---                                         F2414R
      ks=kstart                                                           F2415b
      do 343 kps=1,nconc(kp)                                              F2416b
        ks=ks+1                                                           F2417b
      IF (DECAY(kp).NE.0.0) THEN                                          F2418b
       IF (IREACT(kp).LE.1) THEN                                          F2419b
      PART(kps,IN,kp)=PART(kps,IN,kp)*DCYT(kp)                            F2420b
       ELSE                                                               F2417R
        PART(kps,IN,kp)=PART(kps,IN,kp)*CELDCY(JX,JY,ks)                 SF2421b
       END IF                                                             F2418B
      END IF                                                              F2419R
      SUMC(JNX,JNY,ks)=SUMC(JNX,JNY,ks)+PART(kps,IN,kp)                  SF2422b
  343 continue                                                            F2423b
      NPCELL(JNX,JNY,kp)=NPCELL(JNX,JNY,kp)+1                            SF2431b
C     ****************************************************************    F2440
  345 CONTINUE                                                           SF2445
C        ---CHECK FOR CHANGE IN CELL LOCATION---                          F2450
      IF (IX.EQ.INX.AND.IY.EQ.INY) GO TO 580                              F2460
C           ---CHECK FOR CONST.-HEAD BDY. OR SOURCE AT OLD LOCATION---    F2470
      IBD=0                                                              SF2478
C     IF (REC(IX,IY).LT.-0.1) GO TO 350                                    FXXX
C     IF (REC(IX,IY).GT.0.1) GO TO 360                                    FXXX
      IF (REC(IX,IY).LT.0.0) GO TO 350                                    F2480
      IF (REC(IX,IY).GT.0.0) GO TO 360                                    F2490
      IF (VPRM(IX,IY).LT.0.09) GO TO 348                                 SF2501
      IF (WT(IX,IY).GT.HK(IX,IY)) GO TO 350                               F2510
      IF (WT(IX,IY).LT.HK(IX,IY)) GO TO 360                               F2520
  348 IF (MCHK.EQ.0) GO TO 540                                           SF2522
      IF (JX.EQ.1.AND.VXBDY(IX-1,IY).GT.0.0.AND.JNX.GT.JX) IBD=1         SF2523
      IF (JX.EQ.NMX.AND.VXBDY(IX,IY).LT.0.0.AND.JNX.LT.JX) IBD=1         SF2524
      IF (JY.EQ.1.AND.VYBDY(IX,IY-1).GT.0.0.AND.JNY.GT.JY) IBD=1         SF2525
      IF (JY.EQ.NMY.AND.VYBDY(IX,IY).LT.0.0.AND.JNY.LT.JY) IBD=1         SF2526
      IF (IBD.EQ.1) GO TO 350                                            SF2527
      GO TO 540                                                           F2530
C     ****************************************************************    F2540
C           ---CREATE NEW PARTICLES AT BOUNDARIES---                      F2550
  350 IF (IFLAG.GT.0) GO TO 550                                           F2560
      KFLAG=1                                                             F2570
  360 CONTINUE                                                            F2581
C     ****************************************************************    F2630
C           ---GENERATE NEW TEMPORARY PARTICLE---                         F2641
      IF (NPTM.EQ.NPMAX) GO TO 600                                        F2650
      NPTM=NPTM+1                                                         F2660
      IP=NPTM                                                             F2670
C                                                                         F2700
  390 IF (KFLAG.EQ.0) GO TO 398                                           F2705
      IF (IBD.EQ.1) GO TO 525                                            SF2708
      ITEM=PTID(IN,kp)                                                    F2845b
      GO TO 399                                                           F2855
  398 continue                                                            F2856b
      ks=kstart                                                           F2857b
      do 395 kps=1,nconc(kp)                                              F2858b
        ks=ks+1                                                           F2859b
      IF (IREACT(kp).LE.1) THEN                                           F2864b
       SUMC(JX,JY,ks)=SUMC(JX,JY,ks)+CONC(JX,JY,ks)*DCYT2(kp)            SF2865b
      ELSE                                                                F2866R
       SUMC(JX,JY,ks)=SUMC(JX,JY,ks)+CONC(JX,JY,ks)*                      F2867b
     &   SQRT(CELDCY(JX,JY,ks))                                          SF2868b
      END IF                                                              F2869R
  395 continue                                                            F2870b
      NPCELL(JX,JY,kp)=NPCELL(JX,JY,kp)+1                                SF2876b
      IF (NPOLD(JX,JY,kp).GT.0) NPOLD(JX,JY,kp)=NPOLD(JX,JY,kp)-1        SF2886b
      IF (IFLAG.GT.0) GO TO 441                                           F2895
      IF (KFLAG.EQ.0) GO TO 441                                           F2899
  399 IF (NPTPND.EQ.16) GO TO 400                                         F2901
      GO TO (401,411,421,431,441,451,461,471,481),ITEM                    F2906
      GO TO 441                                                           F2915
  400 GO TO (482,483,484,485,486,487,488,489,490,491,492,493,494,495,     F2921
     1       496,497),ITEM                                                F2922
      GO TO 441                                                           F2924
  401 PARTxy(1,IP,kp)=IX-F1                                               F2925b
      PARTxy(2,IP,kp)=IY-F1                                               F2935b
      PTID(IP,kp)=1                                                       F2945b
      GO TO 530                                                           F2955
  411 PARTxy(1,IP,kp)=IX-F1                                               F2965b
      PARTxy(2,IP,kp)=IY+F1                                               F2975b
      PTID(IP,kp)=2                                                       F2985b
      GO TO 530                                                           F2995
  421 PARTxy(1,IP,kp)=IX+F1                                               F3005b
      PARTxy(2,IP,kp)=IY-F1                                               F3015b
      PTID(IP,kp)=3                                                       F3025b
      GO TO 530                                                           F3035
  431 PARTxy(1,IP,kp)=IX+F1                                               F3045b
      PARTxy(2,IP,kp)=IY+F1                                               F3055b
      PTID(IP,kp)=4                                                       F3065b
      GO TO 530                                                           F3075
  441 PARTxy(1,IP,kp)=IX                                                  F3085b
      PARTxy(2,IP,kp)=IY                                                  F3095b
      PTID(IP,kp)=5                                                       F3105b
      GO TO 530                                                           F3115
  451 PARTxy(1,IP,kp)=IX-F2                                               F3125b
      PARTxy(2,IP,kp)=IY                                                  F3135b
      PTID(IP,kp)=6                                                       F3145b
      GO TO 530                                                           F3155
  461 PARTxy(1,IP,kp)=IX                                                  F3165b
      PARTxy(2,IP,kp)=IY-F2                                               F3175b
      PTID(IP,kp)=7                                                       F3185b
      GO TO 530                                                           F3195
  471 PARTxy(1,IP,kp)=IX+F2                                               F3205b
      PARTxy(2,IP,kp)=IY                                                  F3215b
      PTID(IP,kp)=8                                                       F3225b
      GO TO 530                                                           F3235
  481 PARTxy(1,IP,kp)=IX                                                  F3245b
      PARTxy(2,IP,kp)=IY+F2                                               F3255b
      PTID(IP,kp)=9                                                       F3265b
      GO TO 530                                                           F3266
  482 PARTxy(1,IP,kp)=IX-F1-F2                                            F3267b
      PARTxy(2,IP,kp)=IY-F1-F2                                            F3268b
      PTID(IP,kp)=1                                                       F3269b
      GO TO 530                                                           F3271
  483 PARTxy(1,IP,kp)=IX-F1-F2                                            F3272b
      PARTxy(2,IP,kp)=IY-F1+F2                                            F3273b
      PTID(IP,kp)=2                                                       F3274b
      GO TO 530                                                           F3275
  484 PARTxy(1,IP,kp)=IX-F1+F2                                            F3276b
      PARTxy(2,IP,kp)=IY-F1-F2                                            F3277b
      PTID(IP,kp)=3                                                       F3278b
      GO TO 530                                                           F3279
  485 PARTxy(1,IP,kp)=IX-F1+F2                                            F3281b
      PARTxy(2,IP,kp)=IY-F1+F2                                            F3282b
      PTID(IP,kp)=4                                                       F3283b
      GO TO 530                                                           F3284
  486 PARTxy(1,IP,kp)=IX-F1-F2                                            F3285b
      PARTxy(2,IP,kp)=IY+F1-F2                                            F3286b
      PTID(IP,kp)=5                                                       F3287b
      GO TO 530                                                           F3288
  487 PARTxy(1,IP,kp)=IX-F1-F2                                            F3289b
      PARTxy(2,IP,kp)=IY+F1+F2                                            F3291b
      PTID(IP,kp)=6                                                       F3292b
      GO TO 530                                                           F3293
  488 PARTxy(1,IP,kp)=IX-F1+F2                                            F3294b
      PARTxy(2,IP,kp)=IY+F1-F2                                            F3295b
      PTID(IP,kp)=7                                                       F3296b
      GO TO 530                                                           F3297
  489 PARTxy(1,IP,kp)=IX-F1+F2                                            F3298b
      PARTxy(2,IP,kp)=IY+F1+F2                                            F3299b
      PTID(IP,kp)=8                                                       F3301b
      GO TO 530                                                           F3302
  490 PARTxy(1,IP,kp)=IX+F1-F2                                            F3303b
      PARTxy(2,IP,kp)=IY-F1-F2                                            F3304b
      PTID(IP,kp)=9                                                       F3305b
      GO TO 530                                                           F3306
  491 PARTxy(1,IP,kp)=IX+F1-F2                                            F3307b
      PARTxy(2,IP,kp)=IY-F1+F2                                            F3308b
      PTID(IP,kp)=10                                                      F3309b
      GO TO 530                                                           F3311
  492 PARTxy(1,IP,kp)=IX+F1+F2                                            F3312b
      PARTxy(2,IP,kp)=IY-F1-F2                                            F3313b
      PTID(IP,kp)=11                                                      F3314b
      GO TO 530                                                           F3315
  493 PARTxy(1,IP,kp)=IX+F1+F2                                            F3316b
      PARTxy(2,IP,kp)=IY-F1+F2                                            F3317b
      PTID(IP,kp)=12                                                      F3318b
      GO TO 530                                                           F3319
  494 PARTxy(1,IP,kp)=IX+F1-F2                                            F3321b
      PARTxy(2,IP,kp)=IY+F1-F2                                            F3322b
      PTID(IP,kp)=13                                                      F3323b
      GO TO 530                                                           F3324
  495 PARTxy(1,IP,kp)=IX+F1-F2                                            F3325b
      PARTxy(2,IP,kp)=IY+F1+F2                                            F3326b
      PTID(IP,kp)=14                                                      F3327b
      GO TO 530                                                           F3328
  496 PARTxy(1,IP,kp)=IX+F1+F2                                            F3329b
      PARTxy(2,IP,kp)=IY+F1-F2                                            F3331b
      PTID(IP,kp)=15                                                      F3332b
      GO TO 530                                                           F3333
  497 PARTxy(1,IP,kp)=IX+F1+F2                                            F3334b
      PARTxy(2,IP,kp)=IY+F1+F2                                            F3335b
      PTID(IP,kp)=16                                                      F3336b
      GO TO 530                                                           F3337
  525 DLX=INX-IX                                                         SF3425
      PARTxy(1,IP,kp)=TEMPX-DLX                                          SF3435b
      DLY=INY-IY                                                         SF3455
      PARTxy(2,IP,kp)=TEMPY-DLY                                          SF3465b
      PARTxy(2,IP,kp)=-PARTxy(2,IP,kp)                                   SF3475b
      ks=kstart                                                           F3476b
      do 526 kps=1,nconc(kp)                                              F3477b
        ks=ks+1                                                           F3478b
      IF (IREACT(kp).LE.1) THEN                                           F3479b
       PART(kps,IP,kp)=CONC(JX,JY,ks)*DCYT(kp)                           SF3480b
      ELSE                                                                F3478C
       PART(kps,IP,kp)=CONC(JX,JY,ks)*CELDCY(JX,JY,ks)                   SF3481b
      END IF                                                              F3478E
      SUMC(JX,JY,ks)=SUMC(JX,JY,ks)+PART(kps,IP,kp)                      SF3482b
  526 continue                                                            F3483b
      NPCELL(JX,JY,kp)=NPCELL(JX,JY,kp)+1                                SF3481b
      GO TO 540                                                          SF3483
C                                                                         F3510
  530 PARTxy(2,IP,kp)=-PARTxy(2,IP,kp)                                    F3520b
      ks=kstart                                                           F3521b
      do 531 kps=1,nconc(kp)                                              F3522b
        ks=ks+1                                                           F3523b
      PART(kps,IP,kp)=CONC(JX,JY,ks)                                     SF3531b
  531 continue                                                            F3532b
C     ****************************************************************    F3550
C           ---CHECK FOR DISCHARGE BOUNDARY AT NEW LOCATION---            F3560
  540 IFLAG=1                                                             F3571
  550 IF (NLOC.GT.0) GO TO 565                                           SF3575
      IF (VPRM(INX,INY).GT.0.09.AND.WT(INX,INY).LT.HK(INX,INY)) GO TO 56 SF3581
     10                                                                   F3590
C     IF (REC(INX,INY).GT.0.1) GO TO 560                                  FXXX
      IF (REC(INX,INY).GT.0.0) GO TO 560                                  F3600
      GO TO 590                                                           F3610
C     ****************************************************************    F3620
C           ---PUT PT. IN LIMBO IF PT. DENSITY NOT INCREASED---           F3625
  560 IF (NPOLD(JNX,JNY,kp).LE.0) GO TO 590                              SF3636b
  565 CONTINUE                                                           SF3638
      PARTxy(1,IN,kp)=0.0                                                 F3645b
      PARTxy(2,IN,kp)=0.0                                                 F3650b
      do 566 kps=1,nconc(kp)                                              F3651b
      PART(kps,IN,kp)=0.0                                                 F3660b
  566 continue                                                            F3661b
      IF (NLOC.GT.0) GO TO 567                                           SF3661
      ks=kstart                                                           F3662b
      do 568 kps=1,nconc(kp)                                              F3663b
        ks=ks+1                                                           F3664b
      SUMC(JNX,JNY,ks)=SUMC(JNX,JNY,ks)-CONC(JNX,JNY,ks)                 SF3665b
  568 continue                                                            F3666b
      NPCELL(JNX,JNY,kp)=NPCELL(JNX,JNY,kp)-1                            SF3666b
      NPOLD(JNX,JNY,kp)=NPOLD(JNX,JNY,kp)-1                              SF3667b
  567 CONTINUE                                                           SF3668
      DO 570 ID=1,1000                                                    F3670b
      IF (LIMBO(ID,kp).GT.0) GO TO 570                                    F3680b
      LIMBO(ID,kp)=IN                                                     F3690b
      GO TO 590                                                           F3700
  570 CONTINUE                                                            F3710
C                                                                         F3720
  580 IF (IFLAG.LT.0) PARTxy(2,IN,kp)=-TEMPY                              F3730b
  590 CONTINUE                                                            F3750
C     ---END OF LOOP---                                                   F3760
C     ****************************************************************    F3762
C                                                                         F3763
C        ---INSERT TEMPORARY PARTICLES INTO LIMBO LOCATIONS---            F3764
      IF(NPTM.EQ.NP(kp)) GO TO 620                                        F3765b
      IN=NPTM                                                             F3766
      DO 595 IL=1,1000                                                    F3767b
      IP=LIMBO(IL,kp)                                                     F3768b
      IF(IP.EQ.0) GO TO 595                                               F3769
      PARTxy(1,IP,kp)=PARTxy(1,IN,kp)                                     F3770b
      PARTxy(1,IN,kp)=0.0                                                 F3771b
      PARTxy(2,IP,kp)=PARTxy(2,IN,kp)                                     F3772b
      PARTxy(2,IN,kp)=0.0                                                 F3773b
      do 594 kps=1,nconc(kp)                                              F3774b
      PART(kps,IP,kp)=PART(kps,IN,kp)                                     F3775b
      PART(kps,IN,kp)=0.0                                                 F3776b
  594 continue                                                            F3777b
      PTID(IP,kp)=PTID(IN,kp)                                             F3778b
      PTID(IN,kp)=0                                                       F3779b
      LIMBO(IL,kp)=0                                                      F3780b
      IN=IN-1                                                             F3781
      IF(IN.LE.NP(kp)) GO TO 596                                          F3782b
  595 CONTINUE                                                            F3783
  596 NPTM=IN                                                             F3784
      GO TO 620                                                           F3785
C        ---RESTART MOVE IF PT. LIMIT EXCEEDED---                         F3790
  600 WRITE (6,700) IMOV,IN,kp                                            F3800b
      TEST(kp)=100.D0                                                     F3810b
      CALL GENPT(kp)                                                      F3820b
      DO 610 IX=1,NMX                                                    SF3831
      DO 610 IY=1,NMY                                                    SF3841
        ks=kstart                                                         F3842
        do 601 kps=1,nconc(kp)                                            F3843
        ks=ks+1                                                           F3844
      SUMC(IX,IY,ks)=0.0                                                  F3850b
  601   continue                                                          F3855b
  610 NPCELL(IX,IY,kp)=0                                                  F3860b
      TEST(kp)=0.D0                                                       F3870b
      GO TO 10                                                            F3880
C     ****************************************************************    F3890
  620 if(kp.eq.1)SUMTCH=SUMTCH+TIMV                                       F3900b
C        ---ADJUST NUMBER OF PARTICLES---                                 F3910
      NP(kp)=NPTM                                                         F3920b
      WRITE (6,670) NP(kp),IMOV,kp                                        F3930b
      kstart=kstart+nconc(kp)                                             F3931b
  625 continue                                                            F3932b
C     ****************************************************************    F3940
      do 626, ks=1,nsol                                                   F3945b
      CALL CNCON(ks)                                                      F3950b
  626 continue                                                            F3955b
C     ****************************************************************    F3960
      do 650 ks=1,nsol                                                    F3965b
C        ---STORE OBS. WELL DATA---                                       F3971
      IF (NUMOBS.LE.0) GO TO 650                                          F3983
      IF (S.GT.0.0) THEN                                                  F3985
       IF (IMOV.NE.NMOV) GO TO 650                                        F3987
       J=MOD(N,50)                                                        F3993
      ELSE                                                                F3997
      J=MOD(IMOV,50)                                                      F4000
      END IF                                                              F4005
      IF (J.EQ.0) J=50                                                    F4010
      TMOBS(J)=SUMTCH                                                     F4020
      DO 630 I=1,NUMOBS                                                   F4030
      TMWL(I,J)=HK(IXOBS(I),IYOBS(I))                                     F4040
      IX=IXOBS(I)-MX+1                                                   SF4042
      IF (IXOBS(I).LT.MX.OR.IXOBS(I).GT.MMX) GO TO 630                   SF4043
      IY=IYOBS(I)-MY+1                                                   SF4044
      IF (IYOBS(I).LT.MY.OR.IYOBS(I).GT.MMY) GO TO 630                   SF4045
      TMCN(I,J,ks)=CONC(IX,IY,ks)                                        SF4046b
      do 629, kb=1,npop                                                   F4047b
      tmz(i,j,kb)=z(ix,iy,kb)                                             F4048b
  629 continue                                                            F4049b
  630 CONTINUE                                                           SF4053
C        ---PRINT CHEMICAL OUTPUT---                                      F4060
  650 if(ks.eq.nsol)CALL CHMOT                                            F4084b
C     ****************************************************************    F4090
  660 RETURN                                                              F4100
C     ****************************************************************    F4110
C                                                                         F4120
C                                                                         F4130
C                                                                         F4140
  670 FORMAT (1H0,2X,2HNP,5X,2H= ,6X,I8,8X,11HIMOV     = ,6X,I4,          F4145b
     &'  Particle Set ',i3)                                               F4150b
  680 FORMAT (1H0,10X,61HNO. OF PARTICLE MOVES REQUIRED TO COMPLETE THIS  F4160
     1 TIME STEP  = ,I4//)                                                F4170
  685 FORMAT (1H0,5X,51H*** CAUTION ***  DECAY HALF-LIFE IS LESS THAN TI  F4174R
     1MV;/23X,24HACCURACY MAY BE AFFECTED/23X,34H(REDUCE TIMV BY DECREAS  F4175R
     2ING CELDIS))                                                        F4176R
  690 FORMAT (1H0,5X,53H*** WARNING ***     QUADRANT NOT LOCATED FOR PT.  F4180
     1 NO. ,I5,11H , IN CELL ,2I4)                                        F4190
c  700 FORMAT (1H0,5X,17H ***   NOTE   ***,10X,23HNPTM.EQ.NPMAX --- IMOV= F4200b
c     1,I4,5X,8HPT. NO.=,I6,' kp=',kp,5X,10HCALL GENPT/)                  F4210b
  700 FORMAT (1H0,5X,'***   NOTE   ***',10X,'NPTM.EQ.NPMAX --- IMOV='     F4200b
     1,I4,5X,'PT. NO.=',I6,' kp=',i4,5X,'CALL GENPT'/)                    F4210b
      END                                                                 F4220-
      SUBROUTINE CNCON(ks)                                                G  10b
      INCLUDE 'dims.inc'                                                  G  11b
      DOUBLE PRECISION TMRX,VPRM,HI,HR,HC,HK,WT,REC,RECH,TIM,AOPT,TITLE   G  20
      DOUBLE PRECISION XDEL,YDEL,S,AREA,SUMT,RHO,PARAM,TEST,TOL,PINT,     G  30
     1                 HMIN,PYR,ANFCTR                                    G  32
      DOUBLE PRECISION DXINV,DYINV,ARINV,PORINV                           G  35
      DOUBLE PRECISION FLW                                                G  40
      DOUBLE PRECISION DCYFCT,DCYT,DCYT2                                  G  42
      double precision bioloss,biogain,up,uptake                          G  43b
      real ncinhib                                                        G  44b
      COMMON /PRMJ/ NTIM,NPMP,NPNT,NITP,N,NX,NY,NP(NPS),NREC,INT,NNX,     G  45b
     &              NNY,                                                  G  51b
     1              NUMOBS,NMOV,IMOV,NPMAX,ITMAX,NZCRIT,IPRNT,NPTPND,     G  61
     2              NPNTMV,NPNTVL,NPNTD,NPNCHV,NPDELC,ICHK,nsol,npop,     G  72b
     3              npset,nconc(NPS),imob(NPS)                            G  73b
      COMMON /PRMC/ NODEID(NXD,NYD),NPCELL(NXC,NYC,NPS),                  G  74b
     &              NPOLD(NXC,NYC,NPS),                                   G  76b
     1              LIMBO(1000,NPS),IXOBS(NOB),IYOBS(NOB)                 G  78b
      COMMON /HEDA/ THCK(NXD,NYD),TMWL(NOB,500),TMOBS(500)                G  80b
      COMMON /HEDB/ TMRX(NXD,NYD,2),VPRM(NXD,NYD),HI(NXD,NYD),            G  82b
     1              HR(NXD,NYD),HC(NXD,NYD),HK(NXD,NYD),WT(NXD,NYD),      G  84b
     2REC(NXD,NYD),RECH(NXD,NYD),TIM(500),AOPT(20),TITLE(010),XDEL,YDEL,  G  86b
     3              S,AREA,SUMT,RHO,PARAM,TEST(NPS),TOL,PINT,HMIN,PYR,    G  88b
     4              ANFCTR                                                G  90b
      COMMON /HEDC/ MX,MY,MMX,MMY,NMX,NMY,MCHK                            G  92b
      COMMON /XINV/ DXINV,DYINV,ARINV,PORINV                              G  94b
      COMMON /CHMA/ PART(NPC,NPTS,NPS),CONC(NXC,NYC,NSL),                 G  96b
     &              TMCN(NOB,500,NSL),                                    G  98b
     &              partxy(2,NPTS,NPS),                                   G 100b
     &              VX(NXD,NYD),tmz(NOB,500,NMC),                         G 102b
     1              VY(NXD,NYD),CONINT(NXC,NYC,NSL),CNRECH(NXC,NYC,NSL),  G 104b
     &              POROS,                                                G 106b
     2              SUMTCH,BETA,TIMV,STORM(NSL),STORMI(NSL),CMSIN(NSL),   G 108b
     &              CMSOUT(NSL),FLMIN(NSL),                               G 110b
     3              FLMOT(NSL),SUMIO(NSL),CELDIS,DLTRAT,CSTORM(NSL)       G 112b
      COMMON /CHMC/ SUMC(NXC,NYC,NSL),VXBDY(NXD,NYD),VYBDY(NXD,NYD)       G 114b
      COMMON /CHMR/ RF(NPS),DK(NPS),RHOB,THALF(NPS),DECAY(NPS),           G 116b
     &              ADSORB(NSL),degloss(NSL),deggain(NSL),                G 118b
     &              SORBI(NSL),DMASS1(NSL),CSTM2(NSL),                    G 120b
     1              EKF(NPS),XNF(NPS),XNFM1(NPS),FCTRF(NPS),EKL(NPS),     G 122b
     &              CEC(NPS),                                             G 124b
     &              EKLCEC(NPS),FCTRL(NPS),CINMAX(NPS),                   G 126b
     2              RF2MIN(NPS),RF2MAX(NPS),CZERO(NPS),IREACT(NPS),       G 128b
     &              EK(NPS),                                              G 130b
     &              EKCEC(NPS),FCTRE(NPS),CTOT(NPS),C3,C4(NPS),C5(NPS),   G 132b
     &              C6(NPS)                                               G 134b
      COMMON /CHMR2/ CRETRD(NXC,NYC,NSL),CRDCOF(NXC,NYC,NSL),             G 136b
     &              CELDCY(NXC,NYC,NSL)                                   G 138b
      COMMON /DIFUS/ DISP(NXC,NYC,4)                                      G 140b
      common /inbio/ ibio,nproc,nsproc(NPR),iz(NPR),nzinhib,ncomp(NPR),   G 142b
     &               nnc(NPR),nhal(NPR),kscomp(NPR,NMC),ksnc(NPR,NMC),    G 144b
     &               kshal(NPR,NMC),ksproc(NPR,NSL),numnut,ksnut(NSL)     G 146b
      common /rbio/  z(NXC,NYC,NMC),vmax(NPR),                            G 148b
     &               yield(NPR),                                          G 150b
     &               upcoef(NPR,NSL),hfk(NPR,NSL),faccomp(NPR,NMC),       G 152b
     &               facnc(NPR,NMC),                                      G 154b
     &               fachal(NPR,NMC),death(NMC),yieldnut(NSL),            G 156b
     &               compinhib(NPR),ncinhib(NPR),                         G 158b
     &               zinhibfac(NMC),                                      G 160b
     &               halinhib(NPR),grow(NMC),zinit(NXC,NYC,NMC),          G 162b
     &               hfknut(NSL),relcoef(NSL),zinhib(NMC)                 G 164b
      common /dbio/  bioloss(NXC,NYC,NSL), biogain(NXC,NYC,NSL),          G
     &               up(NPR), uptake(NPR,NSL)                             G
      COMMON /CHMB1/CNCNC(NXC,NYC,NSL),CNOLD(NXC,NYC,NSL),                G 166b
     &              CAVG(NXC,NYC,NSL)                                     G 202b
C     ***************************************************************     G 210
      if(ks.eq.1)then                                                     G 212b
      do 10 ns=1,nsol                                                     G 214b
      DO 10 IX=1,NMX                                                     SG 232
      DO 10 IY=1,NMY                                                     SG 242
      CNOLD(IX,IY,ns)=CONC(IX,IY,ns)                                      G 250b
      CAVG(IX,IY,ns)=CONC(IX,IY,ns)                                       G 251b
   10 CNCNC(IX,IY,ns)=0.0                                                 G 252b
      end if                                                              G 253b
      ncon=0                                                              G 254b
      do 11 kp=1,npset                                                    G 255b
        nconold=ncon                                                      G 256b
        kpflag=0                                                          G 257b
        ncon=ncon+nconc(kp)                                               G 258b
        if(ks.le.ncon)then                                                G 259b
          if(ks.eq.ncon)kpflag=1                                          G 260b
          kps=ks-nconold                                                  G 261b
          go to 12                                                        G 262b
        end if                                                            G 263b
   11 continue                                                            G 264b
   12 continue                                                            G 265b
      APC=0.0                                                             G 270
c      NZERO=0                                                            G 280b
      TVA=AREA*TIMV                                                       G 290
      TVA2=TVA*0.5                                                        G 295R
      TMCHK=TIMV*10.0                                                     G 296R
      SRCDCY=0.0                                                          G 297R
      RFAREA=RF(kp)*AREA                                                  G 307b
C     ***************************************************************     G 310
C     ---CONC. CHANGE DUE TO:                                             G 321R
C           MIXING AT SOURCE CELLS...                                     G 322R
C           ...WITH DECAY OF RECHARGE DURING TIME INCREMENT               G 323R
      CONST=TIMV                                                          G 341R
      DCYFCT=TIMV*DECAY(kp)                                               G 342Rb
      RFFCT=CONST/RF(kp)                                                  G 344Rb
      DCYT=1.D0                                                           G 346A
      DCYT2=1.D0                                                          G 346B
      IF(DECAY(kp).NE.0.0) THEN                                           G 346Cb
       DCYT=DEXP(-DCYFCT)                                                 G 346D
       DCYT2=DEXP(-DCYFCT*0.5D0)                                          G 346E
      END IF                                                              G 346F
      if(ks.eq.1)GO TO 70                                                 G 347b
   20 continue                                                            G 348b
      if(imob(kp).gt.0)then                                               G 349b
        do 59 ix=1,nmx                                                    G 350b
        do 59 iy=1,nmy                                                    G 351b
          jx=ix+mx-1                                                      G 352b
          jy=iy+my-1                                                      G 353b
          if(thck(jx,jy).eq.0.0) go to 59                                 G 354b
          CALL RETRD2(CAVG(IX,IY,ks),RF2,RDCOEF,kp)                       G 355b
          EQFCT=RFFCT/(THCK(JX,JY)*RF2)                                   G 356b
          delc=eqfct*(bioloss(ix,iy,ks)+biogain(ix,iy,ks))*thck(jx,jy)    G 357b
          cncnc(ix,iy,ks)=cncnc(ix,iy,ks)-delc                            G 358b
   59   continue                                                          G 359b
        go to 110                                                         G 360b
      end if                                                              G 361b
      DO 60 IX=1,NMX                                                     SG 352
      DO 60 IY=1,NMY                                                     SG 362
      JX=IX+MX-1                                                         SG 366
      JY=IY+MY-1                                                         SG 367
      IF (THCK(JX,JY).EQ.0.0) GO TO 60                                   SG 371
      CALL RETRD2(CAVG(IX,IY,ks),RF2,RDCOEF,kp)                           G 384b
      EQFCT=RFFCT/(THCK(JX,JY)*RF2)                                      SG 385R
      C1=CAVG(IX,IY,ks)                                                   G 401b
      IF (ABS(C1).LT.1.0E-20) C1=0.0                                     MULTICS
      C2=C1                                                               G 403R
      CLKCN=C1                                                            G 411R
      SLEAK=(HK(JX,JY)-WT(JX,JY))*VPRM(JX,JY)                            SG 421
      IF (SLEAK.GE.0.0) GO TO 25                                          G 425R
      CLKCN=CNRECH(IX,IY,ks)*DCYT2                                        G 431b
      SRCDCY=SRCDCY+(CNRECH(IX,IY,ks)-CLKCN)*SLEAK*TVA                    G 432b
   25 CONTINUE                                                            G 435R
      CNREC=C1                                                            G 450
      CNREC2=C1                                                           G 455
      RATE=REC(JX,JY)*ARINV                                              SG 461
      IF (RATE.GE.0.0) GO TO 27                                           G 471R
      CNREC=CNRECH(IX,IY,ks)*DCYT2                                        G 472b
      SRCDCY=SRCDCY+(CNRECH(IX,IY,ks)-CNREC)*RATE*TVA                     G 473b
   27 IF (RECH(JX,JY).GE.0.0) GO TO 29                                   SG 474R
      CNREC2=CNRECH(IX,IY,ks)*DCYT2                                       G 476b
      SRCDCY=SRCDCY+(CNRECH(IX,IY,ks)-CNREC2)*RECH(JX,JY)*TVA            SG 477b
   29 CONTINUE                                                            G 478R
      DIV=RATE+SLEAK+RECH(JX,JY)                                         SG 481
      IF (THALF(kp).GT.TMCHK.OR.THALF(kp).EQ.0.0) GO TO 37                G 482b
      IF (DIV.GE.0.0) GO TO 37                                            G 484R
      IF (CNOLD(IX,IY,ks).LE.0.0.OR.CONC(IX,IY,ks).LE.0.0) GO TO 37       G 486b
C     NEXT CALC IS EQUIVALENT TO C1=EXP((ALOG(CNOLD)+ALOG(CONC))*0.5)     G 488A
      C1=SQRT(CNOLD(IX,IY,ks)*CONC(IX,IY,ks))                             G 488b
C     IF (NPCELL(IX,IY,kp).LE.0) C1=CNOLD(IX,IY,ks)*DCYT2                 G 489b
   37 CONTINUE                                                            G 592R
      DELC=EQFCT*(C1*DIV-RATE*CNREC-SLEAK*CLKCN-RECH(JX,JY)*CNREC2        G 593b
c    &     -((bioloss(ix,iy,ks)+biogain(ix,iy,ks))*rf(kp))*thck(jx,jy))  SG 595b
     &     -(bioloss(ix,iy,ks)+biogain(ix,iy,ks))*thck(jx,jy))           SG 597
   40 CNCNC(IX,IY,ks)=CNCNC(IX,IY,ks)+DELC                                G 610b
C     ---CONC. CHANGE DUE TO DISPERSION FOR TIMV---                       G 621R
C        ---DISPERSION WITH TENSOR COEFFICIENTS---                        G 630
      IF (BETA.EQ.0.0) GO TO 60                                           G 635
      IF (MCHK.EQ.1) GO TO 39                                            SG 638
      X1=DISP(IX,IY,1)*(CAVG(IX+1,IY,ks)-C2)                              G 651b
      X2=DISP(IX-1,IY,1)*(CAVG(IX-1,IY,ks)-C2)                            G 661b
      Y1=DISP(IX,IY,2)*(CAVG(IX,IY+1,ks)-C2)                              G 671b
      Y2=DISP(IX,IY-1,2)*(CAVG(IX,IY-1,ks)-C2)                            G 681b
      XX1=DISP(IX,IY,3)*(CAVG(IX,IY+1,ks)+CAVG(IX+1,IY+1,ks)-             G 682b
     1CAVG(IX,IY-1,ks)-CAVG(IX+1,IY-1,ks))                                G 701b
      XX2=DISP(IX-1,IY,3)*(CAVG(IX,IY+1,ks)+CAVG(IX-1,IY+1,ks)-           G 702b
     1CAVG(IX,IY-1,ks)-CAVG(IX-1,IY-1,ks))                                G 721b
      YY1=DISP(IX,IY,4)*(CAVG(IX+1,IY,ks)+CAVG(IX+1,IY+1,ks)-             G 722b
     1CAVG(IX-1,IY,ks)-CAVG(IX-1,IY+1,ks))                                G 741b
      YY2=DISP(IX,IY-1,4)*(CAVG(IX+1,IY,ks)+CAVG(IX+1,IY-1,ks)-           G 742b
     1CAVG(IX-1,IY,ks)-CAVG(IX-1,IY-1,ks))                                G 761b
      GO TO 48                                                           SG 762
   39 X1=0.0                                                             SG 763A
      X2=0.0                                                             SG 763B
      Y1=0.0                                                             SG 763C
      Y2=0.0                                                             SG 763D
      XX1=0.0                                                            SG 763E
      XX2=0.0                                                            SG 763F
      YY1=0.0                                                            SG 763G
      YY2=0.0                                                            SG 763H
      IF (IX.GE.NMX) GO TO 41                                            SG 763I
      X1=DISP(IX,IY,1)*(CAVG(IX+1,IY,ks)-C2)                             SG 763j
   41 IF (IX.LE.1) GO TO 42                                              SG 763K
      X2=DISP(IX-1,IY,1)*(CAVG(IX-1,IY,ks)-C2)                           SG 763l
   42 IF (IY.GE.NMY) GO TO 43                                            SG 763M
      Y1=DISP(IX,IY,2)*(CAVG(IX,IY+1,ks)-C2)                             SG 763n
   43 IF (IY.LE.1) GO TO 46                                              SG 763O
      Y2=DISP(IX,IY-1,2)*(CAVG(IX,IY-1,ks)-C2)                           SG 763p
   44 IF (IY.GE.NMY) GO TO 47                                            SG 764
      IF (IX.GE.NMX) GO TO 45                                            SG 765
      XX1=DISP(IX,IY,3)*(CAVG(IX,IY+1,ks)+CAVG(IX+1,IY+1,ks)-            SG 766a
     1CAVG(IX,IY-1,ks)-CAVG(IX+1,IY-1,ks))                               SG 766b
   45 IF (IX.LE.1) GO TO 48                                              SG 766C
      XX2=DISP(IX-1,IY,3)*(CAVG(IX,IY+1,ks)+CAVG(IX-1,IY+1,ks)-          SG 766d
     1CAVG(IX,IY-1,ks)-CAVG(IX-1,IY-1,ks))                               SG 766e
   46 IF (IX.LE.1) GO TO 48                                              SG 766F
      IF (IY.GE.NMY) GO TO 47                                            SG 766G
      IF (IX.GE.NMX) GO TO 48                                            SG 766H
      YY1=DISP(IX,IY,4)*(CAVG(IX+1,IY,ks)+CAVG(IX+1,IY+1,ks)-            SG 766i
     1CAVG(IX-1,IY,ks)-CAVG(IX-1,IY+1,ks))                               SG 766j
   47 IF (IY.LE.1) GO TO 48                                              SG 766K
      IF (IX.LE.1.OR.IX.GE.NMX) GO TO 48                                 SG 766L
      YY2=DISP(IX,IY-1,4)*(CAVG(IX+1,IY,ks)+CAVG(IX+1,IY-1,ks)-          SG 766m
     1CAVG(IX-1,IY,ks)-CAVG(IX-1,IY-1,ks))                               SG 766o
   48 CONTINUE                                                           SG 768
      CNCNC(IX,IY,ks)=CNCNC(IX,IY,ks)+EQFCT*(X1+X2+Y1+Y2+XX1-XX2+YY1      G 769b
     &  -YY2)                                                             G 772b
   60 CONTINUE                                                            G 780
C     ****************************************************************    G 790
      GO TO 110                                                           G 820
C     ****************************************************************    G 830
C     ---CONC. CHANGE AT NODES DUE TO CONVECTION---                       G 840
C                                  ... AND DECAY---                       G 841R
   70 do 72 ns=1,nsol                                                     G 842b
      nzero=0                                                             G 843b
      ncon=0                                                              G 844b
      lpflat=0                                                            G 845b
      do 73 lp=1,npset                                                    G 846b
        ncon=ncon+nconc(lp)                                               G 847b
        if(ns.lt.ncon)then                                                G 848b
          go to 74                                                        G 849b
        else if (ns.eq.ncon)then                                          G 850b
          lpflag=1                                                        G 851b
          go to 74                                                        G 852b
        end if                                                            G 853b
   73 continue                                                            G 854b
   74 continue                                                            G 855b
      DO 90 IX=1,NMX                                                     SG 852
      DO 90 IY=1,NMY                                                     SG 862
      JX=IX+MX-1                                                         SG 866
      JY=IY+MY-1                                                         SG 867
      IF (THCK(JX,JY).EQ.0.0) GO TO 90                                   SG 871
      APC=NPCELL(IX,IY,lp)                                                G 880b
      IF (APC.GT.0.0) GO TO 80                                            G 890
      IF (REC(JX,JY).NE.0.0.OR.VPRM(JX,JY).GT.0.09) GO TO 90             SG 901
      NZERO=NZERO+1                                                       G 910
      GO TO 90                                                            G 920
   80 CONC(IX,IY,ns)=SUMC(IX,IY,ns)/APC                                   G 930b
      CAVG(IX,IY,ns)=(CONC(IX,IY,ns)+CNOLD(IX,IY,ns))*0.5                 G 935b
      if(cavg(ix,iy,ns).lt.0.0)cavg(ix,iy,ns)=0.0                         G 936b
   90 CONTINUE                                                            G 940
C        ---CHECK NUMBER OF CELLS VOID OF PTS.---                         G 950
      if(lpflag.eq.1)then                                                 G 955b
      IF (NZERO.GT.0) WRITE (6,290) NZERO,IMOV,lp                         G 960b
      IF (NZERO.LE.NZCRIT) GO TO 72                                       G 970
      TEST(lp)=99.0                                                       G 980b
      WRITE (6,300)                                                       G 990
      write(6,*)lp,ns                                                     G 995b
      WRITE (6,320)                                                       G1000
      DO 100 IY=1,NMY                                                    SG1011
  100 WRITE (6,330) (NPCELL(IX,IY,lp),IX=1,NMX)                          SG1021b
      end if                                                              G1022b
  72  continue                                                            G1023b
c     ************************************************************        G1024b
c     Calculate biodegradation terms - bio1 for multiple Monod            G1025b
c       formulation, bio2 for minimum Monod formulation                   G1026b
c     ************************************************************        G1027b
      if(ibio.eq.1)then                                                   G1028b
        call bio1(timv,cavg)                                              G1029b
      else if(ibio.eq.2)then                                              G1030b
        call bio2(timv,cavg)                                              G1031b
      end if                                                              G1032b
      GO TO 20                                                            G1030
C     ****************************************************************    G1040
C     ---CHANGE CONCENTRATIONS AT NODES---                                G1050
  110 DO 130 IX=1,NMX                                                    SG1062
      DO 130 IY=1,NMY                                                    SG1072
      JX=IX+MX-1                                                         SG1076
      JY=IY+MY-1                                                         SG1077
      IF (THCK(JX,JY).EQ.0.0) GO TO 120                                  SG1081
      CNCPCT=0.0                                                          G1084G
      IF (CONC(IX,IY,ks).GT.0.0) CNCPCT=CNCNC(IX,IY,ks)/CONC(IX,IY,ks)    G1085b
      CONC(IX,IY,ks)=CONC(IX,IY,ks)+CNCNC(IX,IY,ks)                       G1090b
      if(conc(ix,iy,ks).lt.0.0)conc(ix,iy,ks)=0.0                         G1100b
      SUMC(IX,IY,ks)=0.0                                                  G1110b
      IF (CNCPCT.LT.0.0) SUMC(IX,IY,ks)=CNCPCT                            G1125b
      GO TO 130                                                           G1150
  120 IF (CONC(IX,IY,ks).GT.0.0) WRITE (6,310) JX,JY,CONC(IX,IY,ks),ks   SG1161b
      CONC(IX,IY,ks)=0.0                                                  G1170b
  130 CONTINUE                                                            G1180
C     ****************************************************************    G1190
C     ---CHANGE CONCENTRATION OF PARTICLES---                             G1200
      DO 180 IN=1,NP(kp)                                                  G1210b
      IF (PARTxy(1,IN,kp).EQ.0.0) GO TO 180                               G1220b
      INX=ABS(PARTxy(1,IN,kp))+0.5                                        G1230b
      INY=ABS(PARTxy(2,IN,kp))+0.5                                        G1240b
      JNX=INX-MX+1                                                       SG1244
      JNY=INY-MY+1                                                       SG1245
C     ---UPDATE CONC. OF PTS. IN SINK/SOURCE CELLS---                     G1250
      IF (REC(INX,INY).NE.0.0) GO TO 140                                  G1260
      IF (VPRM(INX,INY).LE.0.09) GO TO 150                                G1270
  140 PART(kps,IN,kp)=CONC(JNX,JNY,ks)                                   SG1281b
      GO TO 180                                                           G1290
  150 IF (CNCNC(JNX,JNY,ks).LT.0.0) GO TO 170                            SG1301b
  160 PART(kps,IN,kp)=PART(kps,IN,kp)+CNCNC(JNX,JNY,ks)                  SG1311b
      GO TO 180                                                           G1320
  170 IF (CONC(JNX,JNY,ks).LE.0.0) GO TO 160                             SG1331b
      IF (SUMC(JNX,JNY,ks).LT.-1.0) GO TO 160                            SG1341b
      PART(kps,IN,kp)=PART(kps,IN,kp)+PART(kps,IN,kp)*SUMC(JNX,JNY,ks)   SG1351b
  180 CONTINUE                                                            G1360
C     ****************************************************************    G1380
C     ---COMPUTE MASS BALANCE FOR SOLUTE---                               G1390
      CSTORM(ks)=0.0                                                      G1400b
      STORM(ks)=0.0                                                       G1410b
      ADSORB(ks)=0.0                                                      G1411b
      ADSRB2=0.0                                                          G1412R
      DO 270 IX=1,NMX                                                    SG1422
      DO 270 IY=1,NMY                                                    SG1432
      JX=IX+MX-1                                                         SG1435
      JY=IY+MY-1                                                         SG1436
      IF (THCK(JX,JY).EQ.0.0) GO TO 270                                  SG1441
      C1=CONC(IX,IY,ks)                                                   G1442b
      C1B=C1*THCK(JX,JY)                                                 SG1443R
      IF (DECAY(kp).NE.0.0) THEN                                          G1445a
       DELDCY=CNOLD(IX,IY,ks)*(1.0-DCYT)                                  G1445b
       IF (IREACT(kp).GE.2) DELDCY=DELDCY+SORB2(CNOLD(IX,IY,ks),kp)*      G1446b
     &     (1.0-DCYT)*C3                                                  G1447b
      DMASS1(ks)=DMASS1(ks)-DELDCY*THCK(JX,JY)*RFAREA                    SG1448b
      END IF                                                              G1447R
c                                                                         G1448b
c        ---compute mass degraded---                                      G1449b
c                                                                         G1450b
      degloss(ks)=degloss(ks)-bioloss(ix,iy,ks)*timv*thck(jx,jy)*area     G1451b
      deggain(ks)=deggain(ks)-biogain(ix,iy,ks)*timv*thck(jx,jy)*area     G1452b
c                                                                         G1453b
      SUMC(IX,IY,ks)=0.0                                                  G1450b
      WTFCT=0.0                                                           G1455
C        ---COMPUTE MASS OF SOLUTE IN STORAGE---                          G1460
      STORM(ks)=STORM(ks)+C1B                                             G1471b
C        ---COMPUTE MASS ADSORBED---                                      G1472R
      ADSORB(ks)=C1B+ADSORB(ks)                                           G1474b
      IF (IREACT(kp).GE.2) ADSRB2=ADSRB2+THCK(JX,JY)*SORB2(C1,kp)        SG1475b
C        ---ACCOUNT FOR MASS PUMPED IN, OUT, RECHARGED, & DISCHARGED---   G1480
      IF (REC(JX,JY)) 200,210,190                                        SG1491
  190 FCT1=NPOLD(IX,IY,kp)                                                G1492b
      FCT2=NPCELL(IX,IY,kp)                                               G1494b
      IF (FCT2.GT.0.0) WTFCT=FCT1/FCT2                                    G1496
      CMSOUT(ks)=CMSOUT(ks)+REC(JX,JY)*TIMV*((1.0-WTFCT)*CNOLD(IX,IY,ks)  G1497b
     &  +WTFCT*C1)                                                       SG1498b
      GO TO 210                                                           G1510
  200 CMSIN(ks)=CMSIN(ks)+REC(JX,JY)*CNRECH(IX,IY,ks)*TIMV               SG1521b
  210 IF (RECH(JX,JY)) 230,240,220                                       SG1531
  220 CMSOUT(ks)=CMSOUT(ks)+RECH(JX,JY)*TVA2*(CNOLD(IX,IY,ks)+C1)        SG1538b
      GO TO 240                                                           G1550
  230 CMSIN(ks)=CMSIN(ks)+RECH(JX,JY)*CNRECH(IX,IY,ks)*TVA               SG1561b
C     ****************************************************************    G1570
C        ---ACCOUNT FOR BOUNDARY FLOW---                                  G1580
  240 IF (VPRM(JX,JY).EQ.0.0) GO TO 265                                  SG1586
      FLW=VPRM(JX,JY)*(WT(JX,JY)-HK(JX,JY))                              SG1601
      IF (FLW.GT.0.0) GO TO 250                                           G1610
      IF (FLW.LT.0.0) GO TO 260                                           G1620
      GO TO 265                                                           G1625
C           ---MASS IN BOUNDARY DURING TIME STEP---                       G1640
  250 FLMIN(ks)=FLMIN(ks)+FLW*CNRECH(IX,IY,ks)*TVA                        G1650b
      GO TO 265                                                           G1655
C           ---MASS OUT DURING TIME STEP---                               G1670
  260 FCT1=NPOLD(IX,IY,kp)                                                G1672b
      FCT2=NPCELL(IX,IY,kp)                                               G1674b
      IF (FCT2.GT.0.0) WTFCT=FCT1/FCT2                                    G1676
      FLMOT(ks)=FLMOT(ks)+FLW*TVA*((1.0-WTFCT)*CNOLD(IX,IY,ks)+WTFCT*C1)  G1679b
  265 continue                                                            G1680b
      if(kpflag.eq.1)then                                                 G1681b
      NPOLD(IX,IY,kp)=NPCELL(IX,IY,kp)                                    G1682b
      NPCELL(IX,IY,kp)=0                                                  G1684b
      end if                                                              G1685b
      IF (IREACT(kp).GE.2) THEN                                           G1686b
       CALL RETRD2(C1,CRETRD(IX,IY,ks),CRDCOF(IX,IY,ks),kp)               G1687a
       IF (DECAY(kp).NE.0.0)                                              G1687b
     1     CELDCY(IX,IY,ks)=EXP(-DCYFCT*CRDCOF(IX,IY,ks)/                 G1686c
     &     CRETRD(IX,IY,ks))                                              G1687d
      END IF                                                              G1688R
  270 CONTINUE                                                            G1690
C           ---SUBGRID BOUNDARIES---                                     SG1692A
      IF (MCHK.EQ.0) GO TO 275                                           SG1692B
      YT=YDEL*TIMV                                                       SG1692C
      XT=XDEL*TIMV                                                       SG1692D
      DO 272 IY=MY,MMY                                                   SG1694A
      IX=MX                                                              SG1694B
      JY=IY-MY+1                                                         SG1694C
      FLW=TMRX(IX-1,IY,1)*(HK(IX-1,IY)-HK(IX,IY))                        SG1694D
      IF (FLW.GT.0.0) FLMIN(ks)=FLMIN(ks)+FLW*YT*CNOLD(1,JY,ks)*DCYT     SG1694g
      IF (FLW.LT.0.0) FLMOT(ks)=FLMOT(ks)+FLW*YT*CNOLD(1,JY,ks)*DCYT     SG1694h
      IX=MMX                                                             SG1695A
      FLW=TMRX(IX,IY,1)*(HK(IX+1,IY)-HK(IX,IY))                          SG1695B
      IF (FLW.GT.0.0) FLMIN(ks)=FLMIN(ks)+FLW*YT*CNOLD(NMX,JY,ks)*DCYT   SG1695e
  272 IF (FLW.LT.0.0) FLMOT(ks)=FLMOT(ks)+FLW*YT*CNOLD(NMX,JY,ks)*DCYT   SG1695f
      DO 274 IX=MX,MMX                                                   SG1696A
      IY=MY                                                              SG1696B
      JX=IX-MX+1                                                         SG1696C
      FLW=TMRX(IX,IY-1,2)*(HK(IX,IY-1)-HK(IX,IY))                        SG1696D
      IF (FLW.GT.0.0) FLMIN(ks)=FLMIN(ks)+FLW*XT*CNOLD(JX,1,ks)*DCYT     SG1696g
      IF (FLW.LT.0.0) FLMOT(ks)=FLMOT(ks)+FLW*XT*CNOLD(JX,1,ks)*DCYT     SG1696h
      IY=MMY                                                             SG1697A
      FLW=TMRX(IX,IY,2)*(HK(IX,IY+1)-HK(IX,IY))                          SG1697B
      IF (FLW.GT.0.0) FLMIN(ks)=FLMIN(ks)+FLW*XT*CNOLD(JX,NMY,ks)*DCYT   SG1697e
  274 IF (FLW.LT.0.0) FLMOT(ks)=FLMOT(ks)+FLW*XT*CNOLD(JX,NMY,ks)*DCYT   SG1697f
  275 CONTINUE                                                           SG1698A
C     ****************************************************************    G1700
C        ---COMPUTE CHANGE IN MASS OF SOLUTE STORED---                    G1710
C        ---COMPUTE MASS LOST BY DECAY---                                 G1715R
      STORM(ks)=STORM(ks)*AREA                                            G1717b
      ADSORB(ks)=(ADSORB(ks)*DK(kp)+ADSRB2)*RHOB/POROS*AREA               G1719b
      CSTORM(ks)=STORM(ks)-STORMI(ks)                                     G1720b
      CSTM2(ks)=CSTORM(ks)+ADSORB(ks)-SORBI(ks)                           G1725b
      DMASS1(ks)=DMASS1(ks)+SRCDCY                                        G1726b
      SUMIO(ks)=FLMIN(ks)+FLMOT(ks)-CMSIN(ks)-CMSOUT(ks)                  G1730b
C     ****************************************************************    G1740
C     ---REGENERATE PARTICLES IF 'NZCRIT' EXCEEDED---                     G1750
      if(kpflag.eq.1)then                                                 G1755b
      IF (TEST(kp).GT.98.0) CALL GENPT(kp)                                G1760b
      TEST(kp)=0.0                                                        G1770b
      end if                                                              G1775b
C     ****************************************************************    G1780
      RETURN                                                              G1790
C     ****************************************************************    G1800
C                                                                         G1810
C                                                                         G1820
C                                                                         G1830
  280 FORMAT (3H   ,11HTIM(N)   = ,1G12.5,10X,11HTIMV     = ,1G12.5,10X,  G1840
     19HSUMTCH = ,G12.5)                                                  G1850
  290 FORMAT (1H0,5X,40HNUMBER OF CELLS WITH ZERO PARTICLES  =  ,I4,5X,9  G1860
     1HIMOV  =  ,I4,'  Particle Set ', i3/)                               G1870b
  300 FORMAT (1H0,5X,44H***   NZCRIT EXCEEDED  ---  CALL GENPT   ***/)    G1880
  310 FORMAT (1H ,5X,37H***CONC.GT.0.AND.THCK.EQ.0 AT NODE = ,2I4,4X,7HC  G1890
     1ONC = ,G10.4,'ks=',i4,4H ***)                                       G1900b
  320 FORMAT (1H0,2X,6HNPCELL/)                                           G1910
  330 FORMAT (1H ,4X,40I3)                                                G1920
      END                                                                 G1930-
      SUBROUTINE OUTPT                                                    H  10
      INCLUDE 'dims.inc'                                                  H  11b
      DOUBLE PRECISION TMRX,VPRM,HI,HR,HC,HK,WT,REC,RECH,TIM,AOPT,TITLE   H  20
      DOUBLE PRECISION XDEL,YDEL,S,AREA,SUMT,RHO,PARAM,TEST,TOL,PINT,     H  30
     1                 HMIN,PYR,ANFCTR                                    H  31A
      DOUBLE PRECISION TOTLQ,TOTLQI,TPIN,TPOUT,PQIN,PQOUT,DELQ,QOUT,QIN,  H  32
     1                 QNET,DDRW                                          H  32A
      DOUBLE PRECISION QSTR,TPUM,PUMP,TOTLQN,SRCS,SINKS,ERRMB,DENOM,      H  33
     1                 PCTERR                                             H  34
      DOUBLE PRECISION HMAX                                               H  35b
      COMMON /PRMJ/ NTIM,NPMP,NPNT,NITP,N,NX,NY,NP(NPS),NREC,INT,NNX,     H  36b
     &              NNY,                                                  H  40b
     1NUMOBS,NMOV,IMOV,NPMAX,ITMAX,NZCRIT,IPRNT,NPTPND,NPNTMV,NPNTVL,     H  50b
     2NPNTD,NPNCHV,NPDELC,ICHK,nsol,npop,                                 H  61b
     3              npset,nconc(NPS),imob(NPS)                            H  62b
      COMMON /HEDA/ THCK(NXD,NYD),TMWL(NOB,500),TMOBS(500)                H  70b
      COMMON /HEDB/ TMRX(NXD,NYD,2),VPRM(NXD,NYD),HI(NXD,NYD),            H  80b
     1              HR(NXD,NYD),HC(NXD,NYD),HK(NXD,NYD),WT(NXD,NYD),      H  90b
     2REC(NXD,NYD),RECH(NXD,NYD),TIM(500),AOPT(20),TITLE(010),XDEL,YDEL,  H 100b
     3              S,AREA,SUMT,RHO,PARAM,TEST(NPS),TOL,PINT,HMIN,PYR,    H 110b
     4              ANFCTR                                                H 120b
      COMMON /BALM/ TOTLQ,TOTLQI,TPIN,TPOUT,HMAX                          H 130b
      DIMENSION IH(NXD)                                                  SH 142
C     ***************************************************************     H 150
      TIMD=SUMT/86400.                                                    H 160
      TIMY=SUMT/(86400.0*365.25)                                          H 170
C     ---PRINT HEAD VALUES---                                             H 180
      WRITE (6,120)                                                       H 190
      WRITE (6,130) N                                                     H 200
      WRITE (6,140) SUMT                                                  H 210
      WRITE (6,150) TIMD                                                  H 220
      WRITE (6,160) TIMY                                                  H 230
      WRITE (6,170)                                                       H 240
      DO 10 IY=1,NY                                                       H 250
   10 WRITE (6,180) (HK(IX,IY),IX=1,NX)                                   H 260
      IF (N.EQ.0) GO TO 110                                               H 270
C     ***************************************************************     H 280
C     ---PRINT HEAD MAP---                                                H 290
      WRITE (6,120)                                                       H 300
      WRITE (6,130) N                                                     H 310
      WRITE (6,140) SUMT                                                  H 320
      WRITE (6,150) TIMD                                                  H 330
      WRITE (6,160) TIMY                                                  H 340
      WRITE (6,170)                                                       H 350
      DO 30 IY=1,NY                                                       H 360
      DO 20 IX=1,NX                                                       H 370
   20 IH(IX)=NINT(HK(IX,IY))                                              H 381
   30 WRITE (6,190) (IH(ID),ID=1,NX)                                      H 390
C     ***************************************************************     H 400
C     ---COMPUTE WATER BALANCE AND DRAWDOWN---                            H 410
      QSTR=0.D0                                                           H 420
      PUMP=0.D0                                                           H 430
      PQIN=0.D0                                                           H 432
      PQOUT=0.D0                                                          H 434
      TPUM=0.D0                                                           H 440
      QIN=0.D0                                                            H 450
      QOUT=0.D0                                                           H 460
      QNET=0.D0                                                           H 470
      DELQ=0.D0                                                           H 480
      PCTERR=0.D0                                                         H 500
      WRITE (6,290)                                                       H 510
C                                                                         H 520
      DO 80 IY=1,NY                                                       H 530
      DO 70 IX=1,NX                                                       H 540
      IH(IX)=0                                                            H 551
      IF (THCK(IX,IY).EQ.0.0) GO TO 70                                    H 560
      IF (REC(IX,IY).GT.0.0) GO TO 32                                     H 562
      PQIN=PQIN+REC(IX,IY)                                                H 564
      GO TO 34                                                            H 566
   32 PQOUT=PQOUT+REC(IX,IY)                                              H 568
   34 IF (RECH(IX,IY).GT.0.0) GO TO 36                                    H 572
      PQIN=PQIN+RECH(IX,IY)*AREA                                          H 574
      GO TO 38                                                            H 576
   36 PQOUT=PQOUT+RECH(IX,IY)*AREA                                        H 578
   38 IF (VPRM(IX,IY).EQ.0.0) GO TO 60                                    H 582
      DELQ=VPRM(IX,IY)*AREA*(WT(IX,IY)-HK(IX,IY))                         H 590
      IF (DELQ.GT.0.0) GO TO 40                                           H 600
      QOUT=QOUT+DELQ                                                      H 610
      GO TO 50                                                            H 620
   40 QIN=QIN+DELQ                                                        H 630
   50 QNET=QNET+DELQ                                                      H 640
   60 DDRW=HI(IX,IY)-HK(IX,IY)                                            H 650
      IH(IX)=NINT(DDRW)                                                   H 661
      QSTR=QSTR+DDRW*AREA*S                                               H 670
   70 CONTINUE                                                            H 680
C        ---PRINT DRAWDOWN MAP---                                         H 690
      WRITE (6,300) (IH(IX),IX=1,NX)                                      H 700
   80 CONTINUE                                                            H 710
      TPUM=PQIN+PQOUT                                                     H 716
      PUMP=TPIN+TPOUT                                                     H 721
      TOTLQN=TOTLQ+TOTLQI                                                 H 745
      SRCS=QSTR-TPIN+TOTLQI                                               H 755
      SINKS=TPOUT-TOTLQ                                                   H 765
      ERRMB=SRCS-SINKS                                                    H 775
      DENOM=(SRCS+SINKS)*0.5D0                                            H 785
      IF (DENOM.EQ.0.0) GO TO 100                                         H 795
      PCTERR=ERRMB*100.D0/DENOM                                           H 805
C        ---PRINT MASS BALANCE DATA FOR FLOW MODEL---                     H 830
  100 WRITE (6,240)                                                       H 840
      WRITE (6,211) TPIN                                                  H 842
      WRITE (6,212) TPOUT                                                 H 844
      WRITE (6,250) PUMP                                                  H 850
      WRITE (6,230) QSTR                                                  H 860
      WRITE (6,202) TOTLQI                                                H 862
      WRITE (6,203) TOTLQ                                                 H 864
      WRITE (6,260) TOTLQN                                                H 866
      WRITE (6,270) ERRMB                                                 H 880
      WRITE (6,280) PCTERR                                                H 883
      WRITE (6,201)                                                       H 886
      WRITE (6,202) QIN                                                   H 889
      WRITE (6,203) QOUT                                                  H 892
      WRITE (6,204) QNET                                                  H 895
      WRITE (6,211) PQIN                                                  H 898
      WRITE (6,212) PQOUT                                                 H 901
      WRITE (6,210) TPUM                                                  H 910
C     ***************************************************************     H 940
  110 RETURN                                                              H 950
C     ***************************************************************     H 960
C                                                                         H 970
C                                                                         H 980
C                                                                         H 990
  120 FORMAT (1H1,23HHEAD DISTRIBUTION - ROW)                             H1000
  130 FORMAT (1X,23HNUMBER OF TIME STEPS = ,1I5)                          H1010
  140 FORMAT (8X,16HTIME(SECONDS) = ,1E12.5)                              H1020
  150 FORMAT (8X,16HTIME(DAYS)    = ,1E12.5)                              H1030
  160 FORMAT (8X,16HTIME(YEARS)   = ,1E12.5)                              H1040
  170 FORMAT (1H )                                                        H1050
  180 FORMAT (1H ,10F12.7)                                                H1055b
  190 FORMAT (1H ,30I4)                                                  SH1071b
  201 FORMAT (1H0,2X,33HRATE MASS BALANCE -- (IN C.F.S.) //)              H1073
  202 FORMAT (4X,29HLEAKAGE INTO AQUIFER       = ,E12.5)                  H1076
  203 FORMAT (4X,29HLEAKAGE OUT OF AQUIFER     = ,E12.5)                  H1083
  204 FORMAT (4X,29HNET LEAKAGE    (QNET)      = ,E12.5)                  H1086
  210 FORMAT (4X,29HNET WITHDRAWAL   (TPUM)    = ,E12.5)                  H1093
  211 FORMAT (4X,29HRECHARGE AND INJECTION     = ,E12.5)                  H1096
  212 FORMAT (4X,29HPUMPAGE AND E-T WITHDRAWAL = ,E12.5)                  H1103
  230 FORMAT (4X,29HWATER RELEASE FROM STORAGE = ,1E12.5)                 H1120
  240 FORMAT (1H0,2X,37HCUMULATIVE MASS BALANCE -- (IN L**3) //)          H1125
  250 FORMAT (4X,29HCUMULATIVE  NET  PUMPAGE   = ,1E12.5)                 H1140
  260 FORMAT (4X,29HCUMULATIVE  NET  LEAKAGE   = ,1E12.5)                 H1150
  270 FORMAT (1H0,7X,25HMASS BALANCE RESIDUAL  = ,G12.5)                  H1160
  280 FORMAT (1H ,7X,25HERROR  (AS PERCENT)    = ,G12.5/)                 H1170
  290 FORMAT (1H1,8HDRAWDOWN)                                             H1180
  300 FORMAT (3H   ,25I5)                                                SH1191
      END                                                                 H1200-
      SUBROUTINE CHMOT                                                    I  10
      INCLUDE 'dims.inc'                                                  I  11b
      DOUBLE PRECISION TMRX,VPRM,HI,HR,HC,HK,WT,REC,RECH,TIM,AOPT,TITLE   I  20
      DOUBLE PRECISION XDEL,YDEL,S,AREA,SUMT,RHO,PARAM,TEST,TOL,PINT,     I  30
     1                 HMIN,PYR,ANFCTR                                    I  32
      double precision bioloss,biogain,up,uptake                          I  34b
      real ncinhib                                                        I  36b
      COMMON /PRMJ/ NTIM,NPMP,NPNT,NITP,N,NX,NY,NP(NPS),NREC,INT,NNX,     I  38b
     &              NNY,                                                  I  41b
     1              NUMOBS,NMOV,IMOV,NPMAX,ITMAX,NZCRIT,IPRNT,NPTPND,     I  51
     2              NPNTMV,NPNTVL,NPNTD,NPNCHV,NPDELC,ICHK,nsol,npop,     I  62b
     3              npset,nconc(NPS),imob(NPS)                            I  64b
      COMMON /PRMC/ NODEID(NXD,NYD),NPCELL(NXC,NYC,NPS),                  I  66b
     &              NPOLD(NXC,NYC,NPS),                                   I  68b
     1              LIMBO(1000,NPS),IXOBS(NOB),IYOBS(NOB)                 I  70b
      COMMON /HEDA/ THCK(NXD,NYD),TMWL(NOB,500),TMOBS(500)                I  72b
      COMMON /HEDB/ TMRX(NXD,NYD,2),VPRM(NXD,NYD),HI(NXD,NYD),            I  74b
     1              HR(NXD,NYD),HC(NXD,NYD),HK(NXD,NYD),WT(NXD,NYD),      I  76b
     2REC(NXD,NYD),RECH(NXD,NYD),TIM(500),AOPT(20),TITLE(010),XDEL,YDEL,  I  78b
     3              S,AREA,SUMT,RHO,PARAM,TEST(NPS),TOL,PINT,HMIN,PYR,    I  80b
     4              ANFCTR                                                I  82b
      COMMON /HEDC/ MX,MY,MMX,MMY,NMX,NMY,MCHK                            I  84b
      COMMON /CHMA/ PART(NPC,NPTS,NPS),CONC(NXC,NYC,NSL),                 I  86b
     &              TMCN(NOB,500,NSL),                                    I  88b
     &              partxy(2,NPTS,NPS),                                   I  90b
     &              VX(NXD,NYD),tmz(NOB,500,NMC),                         I  92b
     1              VY(NXD,NYD),CONINT(NXC,NYC,NSL),CNRECH(NXC,NYC,NSL),  I  94b
     &              POROS,                                                I  96b
     2              SUMTCH,BETA,TIMV,STORM(NSL),STORMI(NSL),CMSIN(NSL),   I  98b
     &              CMSOUT(NSL),FLMIN(NSL),                               I 100b
     3              FLMOT(NSL),SUMIO(NSL),CELDIS,DLTRAT,CSTORM(NSL)       I 102b
      COMMON /CHMR/ RF(NPS),DK(NPS),RHOB,THALF(NPS),DECAY(NPS),           I 104b
     &              ADSORB(NSL),degloss(NSL),deggain(NSL),                I 106b
     &              SORBI(NSL),DMASS1(NSL),CSTM2(NSL),                    I 108b
     1              EKF(NPS),XNF(NPS),XNFM1(NPS),FCTRF(NPS),EKL(NPS),     I 110b
     &              CEC(NPS),                                             I 112b
     &              EKLCEC(NPS),FCTRL(NPS),CINMAX(NPS),                   I 114b
     2              RF2MIN(NPS),RF2MAX(NPS),CZERO(NPS),IREACT(NPS),       I 116b
     &              EK(NPS),                                              I 118b
     &              EKCEC(NPS),FCTRE(NPS),CTOT(NPS),C3,C4(NPS),C5(NPS),   I 120b
     &              C6(NPS)                                               I 122b
      common /inbio/ ibio,nproc,nsproc(NPR),iz(NPR),nzinhib,ncomp(NPR),   I 124b
     &               nnc(NPR),nhal(NPR),kscomp(NPR,NMC),ksnc(NPR,NMC),    I 126b
     &               kshal(NPR,NMC),ksproc(NPR,NSL),numnut,ksnut(NSL)     I 128b
      common /rbio/  z(NXC,NYC,NMC),vmax(NPR),                            I 130b
     &               yield(NPR),                                          I 132b
     &               upcoef(NPR,NSL),hfk(NPR,NSL),faccomp(NPR,NMC),       I 134b
     &               facnc(NPR,NMC),                                      I 136b
     &               fachal(NPR,NMC),death(NMC),yieldnut(NSL),            I 138b
     &               compinhib(NPR),ncinhib(NPR),                         I 140b
     &               zinhibfac(NMC),                                      I 142b
     &               halinhib(NPR),grow(NMC),zinit(NXC,NYC,NMC),          I 144b
     &               hfknut(NSL),relcoef(NSL),zinhib(NMC)                 I 146b
      common /dbio/  bioloss(NXC,NYC,NSL), biogain(NXC,NYC,NSL),          I
     &               up(NPR), uptake(NPR,NSL)                             I
      DIMENSION IC(NXC)                                                   I 161
C     ***************************************************************     I 170
      TMFY=86400.0*365.25                                                 I 180
      TMYR=SUMT/TMFY                                                      I 190
      TCHD=SUMTCH/86400.0                                                 I 200
      TCHYR=SUMTCH/TMFY                                                   I 210
      ERR1=0.0                                                            I 212
      ERR3=0.0                                                            I 214
      IF (MOD(IMOV,NPNTMV).NE.0.AND.(IMOV.NE.NMOV.OR.                     I 221
     1   (MOD(N,NPNT).NE.0.AND.N.NE.NTIM.AND.IPRNT.EQ.0)))                I 222
     2                 GO TO 100                                          I 223
C     ***************************************************************     I 230
C     ---PRINT CONCENTRATIONS---                                          I 240
      WRITE (6,160)                                                       I 250
      WRITE (6,170) N                                                     I 260
      IF (N.GT.0) WRITE (6,180) TIM(N)                                    I 270
      WRITE (6,190) SUMT                                                  I 280
      WRITE (6,450) SUMTCH                                                I 290
      WRITE (6,200) TCHD                                                  I 300
      WRITE (6,210) TMYR                                                  I 310
      WRITE (6,460) TCHYR                                                 I 320
      WRITE (6,380) IMOV                                                  I 330
      WRITE (6,220)                                                       I 340
c      do 20 ks=1,nsol                                                    I 341b
c        write(6,11)ks                                                    I 342b
  11  format(' Solute',i4)                                                I 343b
c      DO 20 IY=1,NMY                                                     SI 351
c      DO 10 IX=1,NMX                                                     SI 361
c   10 IC(IX)=NINT(CONC(IX,IY,ks))                                         I 371
c   20 WRITE (6,240) (IC(IX),IX=1,NMX)                                    SI 381
      do 21 ks=1,nsol                                                     I 344b
        write(6,11)ks                                                     I 345b
        do 21 iy=1,nmy                                                    I 346b
        write(6,241)(conc(ix,iy,ks),ix=1,nmx)                             I 347b
  21    continue                                                          I 348b
        do 24 ks=1,npop                                                   I 349b
        write(6,14)ks                                                     I 350b
        do 24 iy=1,nmy                                                    I 351b
        write(6,241)(z(ix,iy,ks),ix=1,nmx)                                I 352b
  24    continue                                                          I 353b
  14    format(' population',i4)                                          I 354b
 241    format(10E12.4)                                                   I 355b
 242    format(20i4)                                                      I 356b
        ntime=ntime+1                                                     I 357b
        write(10,499)tchd                                                 I 358b
 499    format(' Time = ', G10.3,' days')                                 I 359b
c        do 501 ix=2,nmx-1                                                I 360b
        do 501 ix=1,nmx                                                   I 361b
        irow=2                                                            I 362b
        write(10,500)ix,(conc(ix,irow,ks),ks=1,nsol),                     I 363b
     &(z(ix,irow,kb),kb=1,npop)                                           I 364b
 502    format (4x,8f10.6)                                                I 365b
 500    format(i4,15G10.3,2i4)                                            I 366b
 501    continue                                                          I 367b
C     ***************************************************************     I 390
      IF (N.EQ.0) GO TO 150                                               I 400
      IF (NPDELC.EQ.0) GO TO 50                                           I 410
C                                                                         I 420
C     ---PRINT CHANGES IN CONCENTRATION---                                I 430
      WRITE (6,230)                                                       I 440
      WRITE (6,170) N                                                     I 450
      WRITE (6,180) TIM(N)                                                I 460
      WRITE (6,190) SUMT                                                  I 470
      WRITE (6,450) SUMTCH                                                I 480
      WRITE (6,200) TCHD                                                  I 490
      WRITE (6,210) TMYR                                                  I 500
      WRITE (6,460) TCHYR                                                 I 510
      WRITE (6,380) IMOV                                                  I 520
      WRITE (6,220)                                                       I 530
      do 45 ks=1,nsol                                                     I 531b
        write(6,11)ks                                                     I 532b
      DO 40 IY=1,NMY                                                     SI 541
      DO 30 IX=1,NMX                                                     SI 551
   30 IC(IX)=NINT(CONC(IX,IY,ks)-CONINT(IX,IY,ks))                        I 571b
   40 WRITE (6,240) (IC(IX),IX=1,NMX)                                    SI 581
  45  continue                                                            I 582b
C     ***************************************************************     I 590
 50   continue                                                            I 591b
      do 85 ks=1,nsol                                                     I 592b
        err1=0.0                                                          I 593b
        err3=0.0                                                          I 594b
        write(6,11)ks                                                     I 595b
C     ---PRINT MASS BALANCE DATA FOR SOLUTE---                            I 600
      RESID=SUMIO(ks)-CSTM2(ks)+DMASS1(ks)+degloss(ks)+deggain(ks)        I 611R
      SUMIN=FLMIN(ks)-CMSIN(ks)                                           I 615b
      IF (SUMIN.EQ.0.0) GO TO 60                                          I 625
      ERR1=RESID*100.0/SUMIN                                              I 635
      IF (SUMIO(ks).GT.(STORMI(ks)+SORBI(ks))) GO TO 70                   I 637b
   60 IF (STORMI(ks).EQ.0.0) GO TO 70                                     I 650b
      ERR3=-100.0*(RESID)/(STORMI(ks)+SORBI(ks)-SUMIO(ks))                I 661b
   70 WRITE (6,220)                                                       I 670
      WRITE (6,250)                                                       I 680
      WRITE (6,220)                                                       I 690
      WRITE (6,260) FLMIN(ks)                                             I 700b
      WRITE (6,270) FLMOT(ks)                                             I 710b
      RECIN=-CMSIN(ks)                                                    I 720b
      RECOUT=-CMSOUT(ks)                                                  I 730b
      WRITE (6,290) RECIN                                                 I 740
      WRITE (6,280) RECOUT                                                I 750
      WRITE (6,295) DMASS1(ks)                                            I 751b
      WRITE (6,296) ADSORB(ks)                                            I 752b
      WRITE (6,298) SORBI(ks)                                             I 753b
      WRITE (6,300) SUMIO(ks)                                             I 760b
      WRITE (6,310) STORMI(ks)                                            I 770b
      WRITE (6,320) STORM(ks)                                             I 780b
      WRITE (6,330) CSTORM(ks)                                            I 790b
      WRITE (6,332) CSTM2(ks)                                             I 795b
      write (6,333) degloss(ks)                                           I 800b
      WRITE (6,334) deggain(ks)                                           I 805b
      WRITE (6,340)                                                       I 810
      WRITE (6,350) RESID                                                 I 820
      WRITE (6,360) ERR1                                                  I 830
   80 IF (STORMI(ks).EQ.0.0) GO TO 85                                     I 841b
      IF (SUMIN.NE.0.0.AND.SUMIO(ks).GT.(STORMI(ks)+SORBI(ks))) GO TO 85  I 846b
      WRITE (6,370)                                                       I 850
      WRITE (6,360) ERR3                                                  I 860
  85  continue                                                            I 865b
C     ***************************************************************     I 870
C     ---PRINT HYDROGRAPHS AFTER 50 STEPS OR END OF SIMULATION---         I 880
  100 IF (NUMOBS.LE.0) GO TO 150                                          I 921
      IF (S.GT.0.0) THEN                                                  I 923
       IF (IMOV.NE.NMOV.OR.                                               I 924
     1    (MOD(N,50).NE.0.AND.N.NE.NTIM.AND.IPRNT.EQ.0)) GO TO 150        I 925
      ELSE                                                                I 926
       IF (MOD(IMOV,50).NE.0.AND.IMOV.NE.NMOV) GO TO 150                  I 927
      END IF                                                              I 928
c      WRITE (6,390) TITLE                                                 I 931
c      WRITE (6,400) INT                                                   I 940
c      IF (S.GT.0.0) WRITE (6,410)                                         I 950
c      IF (S.EQ.0.0) WRITE (6,420)                                         I 960
C        ---TABULATE HYDROGRAPH DATA---                                   I 970
      MOZ=0                                                               I 980
      IF (S.GT.0.0) GO TO 110                                             I 990
      NTO=NMOV                                                            I1000
      IF (NMOV.GT.50) NTO=MOD(IMOV,50)                                    I1010
      GO TO 120                                                           I1020
  110 NTO=N                                                               I1031
      IF (N.GT.50) NTO=MOD(N,50)                                          I1041
  120 IF (NTO.EQ.0) NTO=50                                                I1050
      DO 140 J=1,NUMOBS                                                   I1060
        fnum=11+j                                                         I1065b
      TMYR=0.0                                                            I1070
      JX=IXOBS(J)                                                        SI1074
      JY=IYOBS(J)                                                        SI1076
c      WRITE (fnum,430) J,IXOBS(J),IYOBS(J)                               I1080b
      C1INT=0.0                                                          SI1082
      IX=JX-MX+1                                                         SI1083
      IY=JY-MY+1                                                         SI1084
      IF (JX.LT.MX.OR.JY.LT.MY.OR.JX.GT.MMX.OR.JY.GT.MMY) GO TO 125      SI1085
      C1INT=CONINT(IX,IY,1)                                              SI1086b
      GO TO 127                                                          SI1087
  125 WRITE (6,435)                                                      SI1088
c  127 WRITE (6,440) MOZ,WT(JX,JY),C1INT,                                SI1091b
c     1TMYR                                                               I1100b
  127 continue                                                            I1105b
      DO 130 M=1,NTO                                                      I1110
      TMYR=TMOBS(M)/TMFY                                                  I1120
      tmday=tmyr*365.25                                                   I1121b
        write(fnum,441)m,tmday,(tmcn(j,m,ks),ks=1,nsol),                  I1122b
     &(tmz(j,m,ns),ns=1,npop)                                             I1123b
  441 format(i3,f9.3,25E10.3)                                             I1124b
c  130 WRITE (6,440) M,TMWL(J,M),(TMCN(J,M,ks),ks=1,nsol),(tmz(j,m,ns),   I1125b
c     &  ns=1,npop),TMYR                                                  I1130
  130 continue                                                            I1135b
  140 CONTINUE                                                            I1140
C     ****************************************************************    I1150
  150 RETURN                                                              I1166
C     ****************************************************************    I1170
C                                                                         I1180
C                                                                         I1190
C                                                                         I1200
  160 FORMAT (1H1,13HCONCENTRATION/)                                      I1210
  170 FORMAT (1X,23HNUMBER OF TIME STEPS = ,1I5)                          I1220
  180 FORMAT (8X,16HDELTA T       = ,1G12.5)                              I1230
  190 FORMAT (8X,16HTIME(SECONDS) = ,1E12.5)                              I1240
  200 FORMAT (3X,21HCHEM.TIME(DAYS)    = ,1E12.5)                         I1250
  210 FORMAT (8X,16HTIME(YEARS)   = ,1E12.5)                              I1260
  220 FORMAT (1H )                                                        I1270
  230 FORMAT (1H1,23HCHANGE IN CONCENTRATION/)                            I1280
  240 FORMAT (1H0,40I3)                                                   I1290
  250 FORMAT (1H ,21HCHEMICAL MASS BALANCE)                               I1300
  260 FORMAT (8X,25HMASS IN BOUNDARIES     = ,1E12.5)                     I1310
  270 FORMAT (8X,25HMASS OUT BOUNDARIES    = ,1E12.5)                     I1320
  280 FORMAT (8X,25HMASS PUMPED OUT        = ,1E12.5)                     I1330
  290 FORMAT (8X,25HMASS PUMPED IN         = ,1E12.5)                     I1340
  295 FORMAT (8X,25HMASS LOST BY DECAY     = ,1E12.5)                     I1341R
  296 FORMAT (8X,25HMASS ADSORBED ON SOLIDS= ,1E12.5)                     I1342R
  298 FORMAT (8X,25HINITIAL MASS ADSORBED  = ,1E12.5)                     I1343R
  300 FORMAT (8X,25HINFLOW MINUS OUTFLOW   = ,1E12.5)                     I1350
  310 FORMAT (8X,25HINITIAL MASS DISSOLVED = ,1E12.5)                     I1361R
  320 FORMAT (8X,25HPRESENT MASS DISSOLVED = ,1E12.5)                     I1371R
  330 FORMAT (8X,25HCHANGE MASS DISSOLVED  = ,1E12.5)                     I1381R
  332 FORMAT (8X,25HCHANGE TOTL.MASS STORED= ,1E12.5)                     I1382R
  333 FORMAT (8x,25hmass lost by degradation=,1E12.5)                     I1383b
  334 format (8x,25hmass gain by production= ,1E12.5)                     I1384b
  340 FORMAT (1H ,5X,53HCOMPARE RESIDUAL WITH NET FLUX AND MASS ACCUMULA  I1390
     1TION:)                                                              I1400
  350 FORMAT (8X,25HMASS BALANCE RESIDUAL  = ,1E12.5)                     I1410
  360 FORMAT (8X,25HERROR  (AS PERCENT)    = ,1E12.5)                     I1420
  370 FORMAT (1H ,5X,55HCOMPARE INITIAL MASS STORED WITH CHANGE IN MASS   I1430
     1STORED:)                                                            I1440
  380 FORMAT (1X,23H NO. MOVES COMPLETED = ,1I5)                          I1450
  390 FORMAT (1H1,10A8//)                                                 I1460
  400 FORMAT (1H0,5X,65HTIME VERSUS HEAD AND CONCENTRATION AT SELECTED O  I1470
     1BSERVATION POINTS//15X,19HPUMPING PERIOD NO. ,I4////)               I1480
  410 FORMAT (1H0,16X,19HTRANSIENT  SOLUTION////)                         I1490
  420 FORMAT (1H0,15X,21HSTEADY-STATE SOLUTION////)                       I1500
  430 FORMAT (1H0,22HOBS.WELL NO.    X    Y,17X,1HN,6X,'HEAD (L)',        I1510b
     1'   CONC.(MG/L)    TIME (YEARS)'//4X,I3,7X,I4,1X,I4//)              I1520b
  435 FORMAT (1H ,3X,45H** NOTE **  THIS OBS. WELL IS LOCATED OUTSIDE/16 SI1525
     1X,24HOF THE TRANSPORT SUBGRID)                                     SI1526
  440 FORMAT (1H ,1X,I2,2X,10e10.3/(15x,10e10.3))                         I1531b
  450 FORMAT (1H ,2X,21HCHEM.TIME(SECONDS) = ,E12.5)                      I1540
  460 FORMAT (1H ,2X,21HCHEM.TIME(YEARS)   = ,E12.5)                      I1550
      END                                                                 I1560-
C     ***  RETRD2  *****************************************************  K  10
C                                                                         K  20
      SUBROUTINE RETRD2(CONC,RF2,RDCOEF,ks)                               K  30b
C                                                                         K  40
C     ******************************************************************  K  50
      INCLUDE 'dims.inc'                                                  K  51b
      DOUBLE PRECISION AA,BB,CC,QUADX                                     K  60
      COMMON /CHMR/ RF(NPS),DK(NPS),RHOB,THALF(NPS),DECAY(NPS),           K  62b
     &              ADSORB(NSL),degloss(NSL),deggain(NSL),                K  64b
     &              SORBI(NSL),DMASS1(NSL),CSTM2(NSL),                    K  66b
     1              EKF(NPS),XNF(NPS),XNFM1(NPS),FCTRF(NPS),EKL(NPS),     K  68b
     &              CEC(NPS),                                             K  70b
     &              EKLCEC(NPS),FCTRL(NPS),CINMAX(NPS),                   K  72b
     2              RF2MIN(NPS),RF2MAX(NPS),CZERO(NPS),IREACT(NPS),       K  74b
     &              EK(NPS),                                              K  76b
     &              EKCEC(NPS),FCTRE(NPS),CTOT(NPS),C3,C4(NPS),C5(NPS),   K  78b
     &              C6(NPS)                                               K  80b
C     ******************************************************************  K 100
C     ---COMPUTE NONLINEAR RETARDATION FACTOR (RF2) AND CORRECTION TERM   K 110
C          FOR DECAY OF SORBED SOLUTE (RDCOEF)---                         K 120
C                                                                         K 130
      RF2=1.0                                                             K 140
      RDCOEF=1.0                                                          K 150
      IF (IREACT(ks).LE.1) RETURN                                         K 160b
      C=CONC                                                              K 170
      IF (C.LE.CZERO(ks)) THEN                                            K 180b
       RF2=RF2MAX(ks)                                                     K 190b
       RDCOEF=RF2MAX(ks)                                                  K 200b
       RETURN                                                             K 210
      END IF                                                              K 220
C                                                                         K 230
C     ---FREUNDLICH ISOTHERM---                                           K 240
      IF (IREACT(ks).EQ.2) THEN                                           K 250b
       TERM=FCTRF(ks)*C**XNFM1(ks)                                        K 260b
       RF2=1.+TERM                                                        K 270
       RDCOEF=1.+TERM/XNF(ks)                                             K 280b
C                                                                         K 290
C     ---LANGMUIR ISOTHERM---                                             K 300
      ELSE IF (IREACT(ks).EQ.3) THEN                                      K 310b
       DINV=1./(1.+EKL(ks)*C)                                             K 320b
       TERM=FCTRL(ks)*DINV                                                K 330b
       RF2=1.+TERM*DINV                                                   K 340
       RDCOEF=1.+TERM                                                     K 350
C                                                                         K 360
C     ---MONOVALENT ION EXCHANGE---                                       K 370
      ELSE IF (IREACT(ks).EQ.4) THEN                                      K 380b
       RF2=1.+FCTRE(ks)/((C/CTOT(ks)*(EK(ks)-1.)+1.)**2)                  K 390b
       RDCOEF=1.+FCTRE(ks)*CTOT(ks)/((CTOT(ks)-C)+EK(ks)*C)               K 400b
C                                                                         K 410
C     ---DIVALENT ION EXCHANGE---                                         K 420
      ELSE IF (IREACT(ks).EQ.5) THEN                                      K 430b
       CTOT2=CTOT(ks)*0.5                                                 K 440b
       RF2=1.+FCTRE(ks)/((C/CTOT2*(EK(ks)-1.)+1.)**2)                     K 450b
       RDCOEF=1.+FCTRE(ks)*CTOT2/((CTOT2-C)+EK(ks)*C)                     K 460b
C                                                                         K 470
C     ---MONOVALENT-DIVALENT ION EXCHANGE---                              K 480
      ELSE IF (IREACT(ks).EQ.6) THEN                                      K 490b
       C2=C*C                                                             K 500
       AA=CTOT(ks)-C                                                      K 510b
       BB=C2*EK(ks)                                                       K 520b
       CC=-EKCEC(ks)*C2                                                   K 530b
       CBAR=QUADX(AA,BB,CC,1.D0)                                          K 540
       RDCOEF=1.+C3*CBAR/C                                                K 550
       DCBAR=(CBAR*CBAR-CBAR*2.*C*EK(ks)+2.*C*EKCEC(ks))/                 K 560b
     1       ((CTOT(ks)-C)*2.*CBAR+C2*EK(ks))                             K 570b
       RF2=1.+C3*DCBAR                                                    K 580
C                                                                         K 590
C     ---DIVALENT-MONOVALENT ION EXCHANGE---                              K 600
      ELSE                                                                K 610
       C2=C*C                                                             K 620
       AA=4.D0*EK(ks)*C                                                   K 630b
       BB=-4.D0*C4(ks)*C-C6(ks)+4.D0*C*CTOT(ks)-C2*4.D0                   K 640b
       CC=C5(ks)*C                                                        K 650b
       CBAR=QUADX(AA,BB,CC,-1.D0)                                         K 660
       RDCOEF=1.+C3*CBAR/C                                                K 670
       A=(-4.*CBAR*CBAR*EK(ks)-CBAR*(-4.*C4(ks)+4.*CTOT(ks)-8.*C)         K 675b
     &   -C5(ks))                                                         K 680b
       B=(4.*EK(ks)*C*(2.*CBAR-CEC(ks))-C6(ks)+4.*C*CTOT(ks)-4.*C2)       K 690b
       IF (B.EQ.0.0) THEN                                                 K 700
        RF2=1.+C3*1.E-10                                                  K 710
       ELSE                                                               K 720
        RF2=1.+C3*A/B                                                     K 730
       END IF                                                             K 740
      END IF                                                              K 750
      RETURN                                                              K 760
      END                                                                 K 770
C     ***  SORB2  ******************************************************  K 780
C                                                                         K 790
      FUNCTION SORB2(CONC,ks)                                             K 800b
C                                                                         K 810
C     ******************************************************************  K 820
      INCLUDE 'dims.inc'                                                  K 821b
      DOUBLE PRECISION AA,BB,CC,QUADX                                     K 830
      COMMON /CHMR/ RF(NPS),DK(NPS),RHOB,THALF(NPS),DECAY(NPS),           K 832b
     &              ADSORB(NSL),degloss(NSL),deggain(NSL),                K 834b
     &              SORBI(NSL),DMASS1(NSL),CSTM2(NSL),                    K 836b
     1              EKF(NPS),XNF(NPS),XNFM1(NPS),FCTRF(NPS),EKL(NPS),     K 838b
     &              CEC(NPS),                                             K 840b
     &              EKLCEC(NPS),FCTRL(NPS),CINMAX(NPS),                   K 842b
     2              RF2MIN(NPS),RF2MAX(NPS),CZERO(NPS),IREACT(NPS),       K 844b
     &              EK(NPS),                                              K 846b
     &              EKCEC(NPS),FCTRE(NPS),CTOT(NPS),C3,C4(NPS),C5(NPS),   K 848b
     &              C6(NPS)                                               K 850b
C     ******************************************************************  K 870
C     ---SORB2 IS SORBED CONCENTRATION CORRESPONDING TO CONC IN SOLUTION  K 880
C                                                                         K 890
      SORB2=0.0                                                           K 900
      IF (IREACT(ks).LE.1) RETURN                                         K 910b
      C=CONC                                                              K 920
      IF (C.LE.CZERO(ks)) RETURN                                          K 930b
C                                                                         K 940
C     ---FREUNDLICH ISOTHERM---                                           K 950
      IF (IREACT(ks).EQ.2) THEN                                           K 960b
       SORB2=EKF(ks)*C**XNF(ks)                                           K 970b
C                                                                         K 980
C     ---LANGMUIR ISOTHERM---                                             K 990
      ELSE IF (IREACT(ks).EQ.3) THEN                                      K1000b
       SORB2=EKLCEC(ks)*C/(1.+EKL(ks)*C)                                  K1010b
C                                                                         K1020
C     ---MONOVALENT ION EXCHANGE---                                       K1030
      ELSE IF (IREACT(ks).EQ.4) THEN                                      K1040b
       SORB2=EKCEC(ks)*C/(C*(EK(ks)-1.)+CTOT(ks))                         K1050b
C                                                                         K1060
C     ---DIVALENT ION EXCHANGE---                                         K1070
      ELSE IF (IREACT(ks).EQ.5) THEN                                      K1080b
       SORB2=EKCEC(ks)*C/(2.*C*(EK(ks)-1.)+CTOT(ks))                      K1090b
C                                                                         K1100
C     ---MONOVALENT-DIVALENT ION EXCHANGE---                              K1110
      ELSE IF (IREACT(ks).EQ.6) THEN                                      K1120b
       AA=CTOT(ks)-C                                                      K1130b
       C2=C*C                                                             K1140
       BB=C2*EK(ks)                                                       K1150b
       CC=-EKCEC(ks)*C2                                                   K1160b
       SORB2=QUADX(AA,BB,CC,1.D0)                                         K1170
C                                                                         K1180
C     ---DIVALENT-MONOVALENT ION EXCHANGE---                              K1190
      ELSE                                                                K1200
       AA=4.D0*EK(ks)*C                                                   K1210b
       C2=C*C                                                             K1220
       BB=-4.D0*C4(ks)*C-C6(ks)+4.D0*C*CTOT(ks)-C2*4.D0                   K1230b
       CC=C5(ks)*C                                                        K1240b
       SORB2=QUADX(AA,BB,CC,-1.D0)                                        K1250
      END IF                                                              K1260
      RETURN                                                              K1270
      END                                                                 K1280
C     ***  QUADX  ******************************************************  K1290
C                                                                         K1300
      DOUBLE PRECISION FUNCTION QUADX(A,B,C,D)                            K1310
C                                                                         K1320
C     ******************************************************************  K1330
      DOUBLE PRECISION A,B,C,D,T                                          K1340
C     ---SOLVE QUADRATIC EQUATION---                                      K1350
      T=B*B-4.D0*A*C                                                      K1360
      IF (T.LT.0.0) THEN                                                  K1370
       QUADX=-B/(2.D0*A)                                                  K1380
      ELSE                                                                K1390
       QUADX=(-B+D*DSQRT(T))/(2.D0*A)                                     K1400
      END IF                                                              K1410
      RETURN                                                              K1420
      END                                                                 K1430
c*****************************************************************        L  10b
        subroutine bio1(timv,conc)                                        L  20b
c                                                                         L  30b
c       this subroutine is for calculation of the uptake coefficients     L  40b
c         using the multiple monod formulation                            L  50b
c**************************************************************           L  60b
      INCLUDE 'dims.inc'                                                  L  70b
      double precision bioloss,biogain,up,uptake                          L  80b
      real ncinhib                                                        L  90b
      COMMON /PRMJ/ NTIM,NPMP,NPNT,NITP,N,NX,NY,NP(NPS),NREC,INT,NNX,     L 100b
     &              NNY,                                                  L 110b
     1              NUMOBS,NMOV,IMOV,NPMAX,ITMAX,NZCRIT,IPRNT,NPTPND,     L 120b
     2              NPNTMV,NPNTVL,NPNTD,NPNCHV,NPDELC,ICHK,nsol,npop,     L 130b
     3              npset,nconc(NPS),imob(NPS)                            L 140b
      COMMON /HEDA/ THCK(NXD,NYD),TMWL(NOB,500),TMOBS(500)                L 150b
      COMMON /HEDC/ MX,MY,MMX,MMY,NMX,NMY,MCHK                            L 160b
      common /inbio/ ibio,nproc,nsproc(NPR),iz(NPR),nzinhib,ncomp(NPR),   L 170b
     &               nnc(NPR),nhal(NPR),kscomp(NPR,NMC),ksnc(NPR,NMC),    L 180b
     &               kshal(NPR,NMC),ksproc(NPR,NSL),numnut,ksnut(NSL)     L 190b
      common /rbio/  z(NXC,NYC,NMC),vmax(NPR),                            L 200b
     &               yield(NPR),                                          L 210b
     &               upcoef(NPR,NSL),hfk(NPR,NSL),faccomp(NPR,NMC),       L 220b
     &               facnc(NPR,NMC),                                      L 230b
     &               fachal(NPR,NMC),death(NMC),yieldnut(NSL),            L 240b
     &               compinhib(NPR),ncinhib(NPR),                         L 250b
     &               zinhibfac(NMC),                                      L 260b
     &               halinhib(NPR),grow(NMC),zinit(NXC,NYC,NMC),          L 270b
     &               hfknut(NSL),relcoef(NSL),zinhib(NMC)                 L 280b
      common /dbio/  bioloss(NXC,NYC,NSL), biogain(NXC,NYC,NSL),          L
     &               up(NPR), uptake(NPR,NSL)                             L
      dimension conc(NXC,NYC,NSL)                                         L 290b
      dimension iznut(NMC)                                                L 300b
c                                                                         L 310b
        do 400 iy=1,nmy                                                   L 320b
          jy=iy+my-1                                                      L 330b
        do 400 ix=1,nmx                                                   L 340b
          jx=ix+mx-1                                                      L 350b
          if(thck(jx,jy).eq.0.0)go to 400                                 L 360b
        do 2, ib=1,npop                                                   L 370b
          grow(ib)=0.0                                                    L 380b
          zinhib(ib)=1.+zinhibfac(ib)*z(ix,iy,ib)                         L 390b
   2  continue                                                            L 400b
        do 4, ks=1,nsol                                                   L 410b
          bioloss(ix,iy,ks)=0.0d0                                         L 420b
          biogain(ix,iy,ks)=0.0d0                                         L 430b
        do 4, iproc=1,nproc                                               L 440b
          uptake(iproc,ks)=0.0d0                                          L 450b
   4  continue                                                            L 460b
c                                                                         L 470b
      do 100, iproc=1,nproc                                               L 480b
        compinhib(iproc)=1                                                L 490b
        ncinhib(iproc)=1                                                  L 500b
        halinhib(iproc)=0                                                 L 510b
        do 10 in=1,ncomp(iproc)                                           L 520b
          compinhib(iproc)=(compinhib(iproc)+                             L 530b
     &       conc(ix,iy,kscomp(iproc,in))/faccomp(iproc,in))              L 540b
  10    continue                                                          L 550b
        do 20 in=1,nnc(iproc)                                             L 560b
          ncinhib(iproc)=1./(ncinhib(iproc)+                              L 570b
     &       conc(ix,iy,ksnc(iproc,in))/facnc(iproc,in))                  L 580b
  20    continue                                                          L 590b
        do 30 in=1,nhal(iproc)                                            L 600b
          halinhib(iproc)=halinhib(iproc)+                                L 610b
     &      conc(ix,iy,kshal(iproc,in))**2/fachal(iproc,in)               L 620b
  30    continue                                                          L 630b
c                                                                         L 640b
        up(iproc)=vmax(iproc)*ncinhib(iproc)*z(ix,iy,iz(iproc))           L 650b
     &/zinhib(iz(iproc))                                                  L 660b
c                                                                         L 670b
        do 40 is=1,nsproc(iproc)                                          L 680b
          up(iproc)=up(iproc)*conc(ix,iy,ksproc(iproc,is))/               L 690b
     &      (hfk(iproc,is)*compinhib(iproc)+                              L 700b
     &      conc(ix,iy,ksproc(iproc,is))+halinhib(iproc))                 L 710b
  40    continue                                                          L 720b
c                                                                         L 730b
         do 48 ks=1,nsol                                                  L 740b
           if(upcoef(iproc,ks).le.0.0)go to 48                            L 750b
           uptaketemp=upcoef(iproc,ks)*up(iproc)                          L 760b
           if(uptaketemp.le.0.0)go to 48                                  L 770b
           if(uptaketemp*timv.gt.conc(ix,iy,ks))up(iproc)=                L 780b
     &up(iproc)*conc(ix,iy,ks)/(uptaketemp*timv)                          L 790b
           uptaketemp=upcoef(iproc,ks)*up(iproc)                          L 800b
           if(uptaketemp.le.0.0)go to 48                                  L 810b
           biouptemp=bioloss(ix,iy,ks)+biogain(ix,iy,ks)+uptaketemp       L 820b
           if(biouptemp*timv.gt.conc(ix,iy,ks))then                       L 830b
             conctemp=conc(ix,iy,ks)-                                     L 840b
     &                   (bioloss(ix,iy,ks)+biogain(ix,iy,ks))*timv       L 850b
             up(iproc)=up(iproc)*conctemp/(uptaketemp*timv)               L 860b
           end if                                                         L 870b
   48    continue                                                         L 880b
c                                                                         L 890b
      if(numnut.gt.0) then                                                L 900b
        do 55 inn=1,numnut                                                L 910b
          up(iproc)=up(iproc)*conc(ix,iy,ksnut(inn))/                     L 920b
     &    (hfknut(inn)+conc(ix,iy,ksnut(inn)))                            L 930b
  55    continue                                                          L 940b
        do 56 inn=1,numnut                                                L 950b
         if(up(iproc).ge.0.0) then                                        L 960b
           bioloss(ix,iy,ksnut(inn))=bioloss(ix,iy,ksnut(inn))+           L 970b
     &                 up(iproc)*(yield(iproc)/yieldnut(inn))             L 980b
         else                                                             L 990b
           bioloss(ix,iy,ksnut(inn))=biogain(ix,iy,ksnut(inn))+           L1000b
     &                 up(iproc)*(yield(iproc)/yieldnut(inn))             L1010b
         endif                                                            L1020b
  56   continue                                                           L1030b
      end if                                                              L1040b
c                                                                         L1050b
        do 50 ks=1,nsol                                                   L1060b
          uptake(iproc,ks)=upcoef(iproc,ks)*up(iproc)                     L1070b
          if(uptake(iproc,ks).ge.0.0) then                                L1080b
            bioloss(ix,iy,ks)=bioloss(ix,iy,ks)+uptake(iproc,ks)          L1090b
          else                                                            L1100b
            biogain(ix,iy,ks)=biogain(ix,iy,ks)+uptake(iproc,ks)          L1110b
          endif                                                           L1120b
c                                                                         L1130b
  50    continue                                                          L1140b
c                                                                         L1150b
      if(z(ix,iy,iz(iproc)).gt.0.0)grow(iz(iproc))=                       L1160b
     &   grow(iz(iproc))+yield(iproc)*                                    L1170b
     &   up(iproc)/z(ix,iy,iz(iproc))                                     L1180b
c                                                                         L1190b
 100  continue                                                            L1200b
c                                                                         L1210b
      do 300 ib=1,npop                                                    L1220b
        iznut(ib)=1                                                       L1230b
          dth=death(ib)                                                   L1240b
        z(ix,iy,ib)=z(ix,iy,ib)*exp((grow(ib)-dth)*timv)                  L1250b
        if(z(ix,iy,ib).lt.zinit(ix,iy,ib))then                            L1260b
          z(ix,iy,ib)=zinit(ix,iy,ib)                                     L1270b
          iznut(ib)=0                                                     L1280b
        end if                                                            L1290b
 300  continue                                                            L1300b
c                                                                         L1310b
      do 200 inn=1,numnut                                                 L1320b
      do 200 ib=1,npop                                                    L1330b
        if(iznut(ib).gt.0)biogain(ix,iy,ksnut(inn))=                      L1340b
     &    biogain(ix,iy,ksnut(inn))-(relcoef(inn)/yieldnut(inn))*         L1350b
     &    death(ib)*z(ix,iy,ib)                                           L1360b
 200  continue                                                            L1370b
c                                                                         L1380b
 400  continue                                                            L1390b
c                                                                         L1400b
        return                                                            L1410b
        end                                                               L1420b
c                                                                         L1430b
c*****************************************************************        M  10b
        subroutine bio2(timv,conc)                                        M  20b
c                                                                         M  30b
c       this subroutine is for calculation of the uptake coefficients     M  40b
c         using the minimum monod formulation                             M  50b
c**************************************************************           M  60b
      INCLUDE 'dims.inc'                                                  M  70b
      double precision bioloss,biogain,up,uptake                          M  80b
      real ncinhib                                                        M  90b
c                                                                         M 100b
      COMMON /PRMJ/ NTIM,NPMP,NPNT,NITP,N,NX,NY,NP(NPS),NREC,INT,NNX,     M 110b
     &              NNY,                                                  M 120b
     1              NUMOBS,NMOV,IMOV,NPMAX,ITMAX,NZCRIT,IPRNT,NPTPND,     M 130b
     2              NPNTMV,NPNTVL,NPNTD,NPNCHV,NPDELC,ICHK,nsol,npop,     M 140b
     3              npset,nconc(NPS),imob(NPS)                            M 150b
      COMMON /HEDA/ THCK(NXD,NYD),TMWL(NOB,500),TMOBS(500)                M 160b
      COMMON /HEDC/ MX,MY,MMX,MMY,NMX,NMY,MCHK                            M 170b
      common /inbio/ ibio,nproc,nsproc(NPR),iz(NPR),nzinhib,ncomp(NPR),   M 180b
     &               nnc(NPR),nhal(NPR),kscomp(NPR,NMC),ksnc(NPR,NMC),    M 190b
     &               kshal(NPR,NMC),ksproc(NPR,NSL),numnut,ksnut(NSL)     M 200b
      common /rbio/  z(NXC,NYC,NMC),vmax(NPR),                            M 210b
     &               yield(NPR),                                          M 220b
     &               upcoef(NPR,NSL),hfk(NPR,NSL),faccomp(NPR,NMC),       M 230b
     &               facnc(NPR,NMC),                                      M 240b
     &               fachal(NPR,NMC),death(NMC),yieldnut(NSL),            M 250b
     &               compinhib(NPR),ncinhib(NPR),                         M 260b
     &               zinhibfac(NMC),                                      M 270b
     &               halinhib(NPR),grow(NMC),zinit(NXC,NYC,NMC),          M 280b
     &               hfknut(NSL),relcoef(NSL),zinhib(NMC)                 M 290b
      common /dbio/  bioloss(NXC,NYC,NSL), biogain(NXC,NYC,NSL),          M
     &               up(NPR), uptake(NPR,NSL)                             M
      dimension conc(NXC,NYC,NSL)                                         M 300b
      dimension nlimit(NXC,NYC,NPR),iznut(NMC)                            M 310b
c                                                                         M 320b
        do 400 iy=1,nmy                                                   M 330b
          jy=iy+my-1                                                      M 340b
        do 400 ix=1,nmx                                                   M 350b
          jx=ix+mx-1                                                      M 360b
c                                                                         M 370b
          if(thck(jx,jy).eq.0.0)go to 400                                 M 380b
        do 2, ib=1,npop                                                   M 390b
          grow(ib)=0.0                                                    M 400b
          zinhib(ib)=1.+zinhibfac(ib)*z(ix,iy,ib)                         M 410b
   2  continue                                                            M 420b
        do 4, ks=1,nsol                                                   M 430b
          bioloss(ix,iy,ks)=0.0d0                                         M 440b
          biogain(ix,iy,ks)=0.0d0                                         M 450b
        do 4, iproc=1,nproc                                               M 460b
          uptake(iproc,ks)=0.0d0                                          M 470b
   4  continue                                                            M 480b
c                                                                         M 490b
      do 100, iproc=1,nproc                                               M 500b
        compinhib(iproc)=1                                                M 510b
        ncinhib(iproc)=1                                                  M 520b
        halinhib(iproc)=0                                                 M 530b
        do 10 in=1,ncomp(iproc)                                           M 540b
          compinhib(iproc)=compinhib(iproc)*(1.+                          M 550b
     &       conc(ix,iy,kscomp(iproc,in))/faccomp(iproc,in))              M 560b
  10    continue                                                          M 570b
        do 20 in=1,nnc(iproc)                                             M 580b
          ncinhib(iproc)=ncinhib(iproc)/(1.+                              M 590b
     &       conc(ix,iy,ksnc(iproc,in))/facnc(iproc,in))                  M 600b
  20    continue                                                          M 610b
        do 30 in=1,nhal(iproc)                                            M 620b
          halinhib(iproc)=halinhib(iproc)+                                M 630b
     &      conc(ix,iy,kshal(iproc,in))**2/fachal(iproc,in)               M 640b
  30    continue                                                          M 650b
c                                                                         M 660b
        constant=vmax(iproc)*ncinhib(iproc)*z(ix,iy,iz(iproc))            M 670b
     &/zinhib(iz(iproc))                                                  M 680b
c                                                                         M 690b
        up(iproc)=constant*100.                                           M 700b
        do 40 is=1,nsproc(iproc)                                          M 710b
          upval=constant*                                                 M 720b
     &conc(ix,iy,ksproc(iproc,is))/                                       M 730b
     &      (hfk(iproc,is)*compinhib(iproc)+                              M 740b
     &      conc(ix,iy,ksproc(iproc,is))+halinhib(iproc))                 M 750b
        if(upval.lt.up(iproc))then                                        M 760b
          up(iproc)=upval                                                 M 770b
          nlimit(ix,iy,iproc)=ksproc(iproc,is)                            M 780b
        end if                                                            M 790b
  40    continue                                                          M 800b
c                                                                         M 810b
      if(numnut.gt.0)then                                                 M 820b
        do 55 inn=1,numnut                                                M 830b
          upnut=constant*                                                 M 840b
     &conc(ix,iy,ksnut(inn))/(hfknut(inn)+                                M 850b
     &conc(ix,iy,ksnut(inn)))                                             M 860b
          if(upnut.lt.up(iproc))up(iproc)=upnut                           M 870b
c                                                                         M 880b
c the following statements will work only for numnut=1                    M 890b
         if(up(iproc).ge.0.0) then                                        M 900b
           bioloss(ix,iy,ksnut(inn))=bioloss(ix,iy,ksnut(inn))+           M 910b
     &                 up(iproc)*(yield(iproc)/yieldnut(inn))             M 920b
         else                                                             M 930b
           biogain(ix,iy,ksnut(inn))=biogain(ix,iy,ksnut(inn))+           M 940b
     &                 up(iproc)*(yield(iproc)/yieldnut(inn))             M 950b
         endif                                                            M 960b
  55    continue                                                          M 970b
      end if                                                              M 980b
c                                                                         M 990b
        do 50 ks=1,nsol                                                   M1000b
          uptake(iproc,ks)=upcoef(iproc,ks)*up(iproc)                     M1010b
          if(uptake(iproc,ks).ge.0.0) then                                M1020b
            bioloss(ix,iy,ks)=bioloss(ix,iy,ks)+uptake(iproc,ks)          M1030b
          else                                                            M1040b
            biogain(ix,iy,ks)=biogain(ix,iy,ks)+uptake(iproc,ks)          M1050b
          endif                                                           M1060b
  50    continue                                                          M1070b
c                                                                         M1080b
      if(z(ix,iy,iz(iproc)).gt.0.0)grow(iz(iproc))=grow(iz(iproc))+       M1090b
     &   yield(iproc)*                                                    M1100b
     &   up(iproc)/z(ix,iy,iz(iproc))                                     M1110b
 100  continue                                                            M1120b
c                                                                         M1130b
      do 300 ib=1,npop                                                    M1140b
        iznut(ib)=1                                                       M1150b
        z(ix,iy,ib)=z(ix,iy,ib)*exp((grow(ib)-death(ib))*timv)            M1160b
        if(z(ix,iy,ib).lt.zinit(ix,iy,ib))then                            M1170b
          z(ix,iy,ib)=zinit(ix,iy,ib)                                     M1180b
          iznut(ib)=0                                                     M1190b
        end if                                                            M1200b
 300  continue                                                            M1210b
c                                                                         M1220b
      do 200 inn=1,numnut                                                 M1230b
      do 200 ib=1,npop                                                    M1240b
        if(iznut(ib).gt.0)biogain(ix,iy,ksnut(inn))=                      M1250b
     &    biogain(ix,iy,ksnut(inn))-(relcoef(inn)/yieldnut(inn))*         M1260b
     &    death(ib)*z(ix,iy,ib)                                           M1270b
 200  continue                                                            M1280b
c                                                                         M1290b
 400  continue                                                            M1300b
c                                                                         M1310b
        return                                                            M1320b
        end                                                               M1330b
